"""
Default ConfigUI for LOG-0003-200G data recorders 
"""

from base64 import b64decode

DEFAULT_CONFIG_UI = b64decode(
    b'd3dSSkAoRYFQBYdHZW5lcmFsQAXzUAWLRGV2aWNlIE5hbWVQAYMI/39RJIFAUBXYQSBjdX'
    b'N0b20gbmFtZSBmb3IgdGhlIHJlY29yZGVyLiBOb3QgdGhlIHNhbWUgYXMgdGhlIHZvbHVt'
    b'ZSBsYWJlbC4gNjQgY2hhcmFjdGVycyBtYXhpbXVtLkAF81AFjERldmljZSBOb3Rlc1ABgw'
    b'n/f1EkggEAUBXSQ3VzdG9tIG5vdGVzIGFib3V0IHRoZSByZWNvcmRlciAocG9zaXRpb24s'
    b'IHVzZXIgSUQsIGV0Yy4pLiAyNTYgY2hhcmFjdGVycyBtYXhpbXVtLlE0gQNABfpQBZNSZW'
    b'NvcmRpbmcgRGlyZWN0b3J5UAGDFP9/UQSGUkVDT1JEUSSBCFAUk0NvbmZpZ1sweDE2RkY3'
    b'Rl09PTBQFbhEaXJlY3RvcnkgZm9yIHNlcmlhbGl6ZWQgcmVjb3JkaW5ncy4gOCBjaGFyYW'
    b'N0ZXIgbWF4aW11bUAFQKJQBZVSZWNvcmRpbmcgRmlsZSBQcmVmaXhQAYMV/39RJIEIUBXn'
    b'UHJlZml4IGZvciBzZXJpYWxpemVkIHJlY29yZGluZyBuYW1lcy4gSWYgYmxhbmssIGRldm'
    b'ljZSBzZXJpYWwgbnVtYmVyIHdpbGwgYmUgdXNlZC4gOCBjaGFyYWN0ZXIgbWF4aW11bVAU'
    b'k0NvbmZpZ1sweDE2RkY3Rl09PTBAB0E8UAWPRmlsZSBOYW1lIFN0eWxlUAGDFv9/UQGBAF'
    b'AVQPxUaW1lLUJhc2VkIGZpbGUgbmFtZXMgdXNlIGEgZGlyZWN0b3J5IGJhc2VkIG9uIHRo'
    b'ZSBkYXRlLCBhbmQgZmlsZSBuYW1lIGJhc2VkIG9uIHRoZSBzZWNvbmRzIHNpbmNlIG1pZG'
    b'5pZ2h0LgpTZXJpYWxpemVkIGZpbGUgbmFtZXMgdXNlIHRoZSBzcGVjaWZpZWQgZGlyZWN0'
    b'b3J5IGFuZCBmaWxlIG5hbWUgcHJlZml4LCBmb2xsb3dlZCBieSBhIG51bWJlci4gCk51bW'
    b'JlciBpcyByZXNldCB3aGVuIGRpcmVjdG9yeSBvciBwcmVmaXggY2hhbmdlcy5BB41QBYpU'
    b'aW1lIEJhc2VkQQeNUAWKU2VyaWFsaXplZEAHQJlQBYtCdXR0b24gTW9kZVABgxD/f1EBgQ'
    b'BQFb9PbmUgU2Vjb25kIFByZXNzIHdpbGwgZGlzYWJsZSAzLXNlY29uZCBwcmVzcyBmb3Ig'
    b'YmF0dGVyeSBjaGVjay5BB5dQBZRJbW1lZGlhdGUgU3RhcnQvU3RvcEEHolAFn09uZSBTZW'
    b'NvbmQgUHJlc3MgZm9yIFN0YXJ0L1N0b3BAF0EUUAWOUGx1Zy1JbiBBY3Rpb25QAYMK/39R'
    b'AYEBUBWtU2V0IGFjdGlvbiBmb3IgZGV2aWNlIHdoZW4gcGx1Z2dlZCBpbiB0byBVU0IuQQ'
    b'e1UAWySW1tZWRpYXRlbHkgc3RvcCByZWNvcmRpbmcgYW5kIGFwcGVhciBhcyBVU0IgZHJp'
    b'dmVBB7NQBbBDb21wbGV0ZSByZWNvcmRpbmcgYmVmb3JlIGFwcGVhcmluZyBhcyBVU0IgZH'
    b'JpdmVBB7BQBa1JZ25vcmU6IHN0b3AgcmVjb3JkaW5nIHdoZW4gYnV0dG9uIGlzIHByZXNz'
    b'ZWRBB6VQBaJTdGFydCByZWNvcmRpbmcgd2hlbiBVU0IgY29ubmVjdGVkQCPnUAGDC/9/UB'
    b'XeRW50ZXIgbG9jYWwgdGltZXpvbmUncyBvZmZzZXQgZnJvbSBVVEMgdGltZS4gSW1wYWN0'
    b'cyB0aW1lc3RhbXAgaW5mb3JtYXRpb24gb24gcmVjb3JkaW5nIGZpbGVzLkAvgEAPgEBPgE'
    b'AoR25QBYhUcmlnZ2Vyc0AHQNpQBYxUcmlnZ2VyIE1vZGVQAYMS/39RAYEAUBVAj0RlbGF5'
    b'IFRoZW4gVHJpZ2dlcjogV2FpdCBzcGVjaWZpZWQgdGltZSwgdGhlbiB3YWl0IGZvciB0cm'
    b'lnZ2VyCkRlbGF5IE9yIFRyaWdnZXI6IEFjcXVpcmUgYWZ0ZXIgd2FpdCBvciBvbiB0cmln'
    b'Z2VyLiBCYXR0ZXJ5IGxpZmUgbWF5IGJlIHJlZHVjZWQuQQeVUAWSRGVsYXkgVGhlbiBUcm'
    b'lnZ2VyQQeTUAWQRGVsYXkgT3IgVHJpZ2dlckAy9FAFjVN0YXJ0IGF0IFRpbWVQAYMP/39Q'
    b'FdtXYWl0IHVudGlsIHNldCB0aW1lIGJlZm9yZSBldmFsdWF0aW5nIG90aGVyIHRyaWdnZX'
    b'IgY29uZGl0aW9ucywgaW5jbHVkaW5nIGEgcmVjb3JkaW5nIGRlbGF5QBGuUAWUUmVjb3Jk'
    b'aW5nIFRpbWUgTGltaXRQAYMN/39RIYT////wUCWHU2Vjb25kc0ARQJBQBZhSZWNvcmRpbm'
    b'cgRGVsYXkvSW50ZXJ2YWxQAYMM/39RAYEAUCWHU2Vjb25kc1EhgwFRgFAV2FRpbWUgYmVm'
    b'b3JlIHN0YXJ0aW5nIGEgcmVjb3JkaW5nLCBhbmQgdGltZSBiZXR3ZWVuIHJlY29yZGluZ3'
    b'MgaWYgJ1JldHJpZ2dlcicgaXMgY2hlY2tlZC5AEa9QBZlSZWNvcmRpbmcgRmlsZSBTaXpl'
    b'IExpbWl0UAGDEf9/USGE////8FAlg0tpQkAQQJdQBYlSZXRyaWdnZXJQAYMO/39QFLBDb2'
    b'5maWdbMHhERkY3Rl09PW51bGwgYW5kIENvbmZpZ1sweDExRkY3Rl09PW51bGxQFc9XaGVu'
    b'IHNldCwgU2xhbSBTdGljayB3aWxsIHJlLWFybSBhZnRlciByZWNvcmRpbmcgdGltZSBvci'
    b'BzaXplIGxpbWl0IGlzIHJlYWNoZWQuQBBAqFAFnldhaXQgZm9yIEFsbCBTZW5zb3IgQ29u'
    b'ZGl0aW9uc1ABgxP/f1AV/ldoZW4gc2V0LCByZWNvcmRpbmcgd2lsbCBvbmx5IHN0YXJ0IH'
    b'doZW4gYWxsIHRyaWdnZXJzIGFyZSBtZXQsIG90aGVyd2lzZSByZWNvcmRpbmcgd2lsbCBz'
    b'dGFydCB3aGVuIGFueSBzZW5zb3IgY29uZGl0aW9uIGlzIG1ldEAYQQpQBZBQcmVzc3VyZS'
    b'BUcmlnZ2VyUAGDBQAkUQCBAFAUmUNvbmZpZ1sweDAxRkYyNF0gJiAxID09IDBAguVQBZVQ'
    b'cmVzc3VyZSBUcmlnZ2VyLCBMb3dQAYMDACRRAYMBX5BQJYJQYVEhgwHUwFAVs1NldCB0by'
    b'BzdGFydCBzYW1wbGluZyB3aGVuIG91dHNpZGUgcHJlc3N1cmUgd2luZG93LkCC5lAFllBy'
    b'ZXNzdXJlIFRyaWdnZXIsIEhpZ2hQAYMEACRRAYMBrbBQJYJQYVEhgwHUwFAVs1NldCB0by'
    b'BzdGFydCBzYW1wbGluZyB3aGVuIG91dHNpZGUgcHJlc3N1cmUgd2luZG93LkAYQRdQBZNU'
    b'ZW1wZXJhdHVyZSBUcmlnZ2VyUAGDBQEkUQCBAFAUmUNvbmZpZ1sweDAxRkYyNF0gJiAyID'
    b'09IDBAY+pQBZhUZW1wZXJhdHVyZSBUcmlnZ2VyLCBMb3dQAYMDASRRAoH2UCWBQ1ESgdhR'
    b'IoFQUBW2U2V0IHRvIHN0YXJ0IHNhbXBsaW5nIHdoZW4gb3V0c2lkZSB0ZW1wZXJhdHVyZS'
    b'B3aW5kb3cuQGPrUAWZVGVtcGVyYXR1cmUgVHJpZ2dlciwgSGlnaFABgwQBJFECgSNQJYFD'
    b'URKB2FEigVBQFbZTZXQgdG8gc3RhcnQgc2FtcGxpbmcgd2hlbiBvdXRzaWRlIHRlbXBlcm'
    b'F0dXJlIHdpbmRvdy5AGEGdUAWbQWNjZWxlcmF0aW9uIFRyaWdnZXIgKDIwMGcpUAGDB/8g'
    b'UBXUTG93IHBvd2VyIHRyaWdnZXIgdXNpbmcgZGlnaXRhbCBhY2NlbGVyb21ldGVyIHdpdG'
    b'ggREMgcmVzcG9uc2UuIE5vIHByZS10cmlnZ2VyIGRhdGEuUQCBAFARgwX/CFAkgFAUlENv'
    b'bmZpZ1sweDFmZjIwXSA9PSAwQENAsVAFlkFjY2VsZXJhdGlvbiBUaHJlc2hvbGRQAYME/y'
    b'BRAYFQUgOIP+j1wo9cKPZRI4hAaQAAAAAAAFETgFAV8kxvdyBwb3dlciB0cmlnZ2VyLiBU'
    b'aGUgbWluaW11bSBhY2NlbGVyYXRpb24gKHBvc2l0aXZlIG9yIG5lZ2F0aXZlKSB0byB0cm'
    b'lnZ2VyIGEgcmVjb3JkaW5nLiBNdXN0IGJlIGdyZWF0ZXIgdGhhbiAwLkAnxlABgwX/IFEB'
    b'gQdBB5FQBY5YIEF4aXMgVHJpZ2dlckEHkVAFjlkgQXhpcyBUcmlnZ2VyQQeRUAWOWiBBeG'
    b'lzIFRyaWdnZXJAD4BAT4BAKEVGUAWMTWVhc3VyZW1lbnRzQAhAu1AFnDIwMGcgREMgQWNj'
    b'ZWxlcmF0aW9uIChDaCAzMilAJ59QAYMB/yBRAYEBQQeSUAWPRW5hYmxlIEFsbCBBeGVzQB'
    b'f3UAWLU2FtcGxlIFJhdGVQAYMC/yBRAYIBkFAlgkh6UBSTbm90IENvbmZpZ1sweDFmZjIw'
    b'XUEHhVEBggyAQQeFUQGCBkBBB4VRAYIDIEEHhVEBggGQQQeEUQGByEEHhFEBgWRBB4RRAY'
    b'EyQQeEUQGBGUEHhFEBgQxACEEwUAWoQ29udHJvbCBQYWQgVGVtcGVyYXR1cmUvUHJlc3N1'
    b'cmUgKENoIDU5KUAnQJtRAYEDUAGDAf87UBWlRW5hYmxlL0Rpc2FibGUgc2Vuc29ycyBvbi'
    b'Bjb250cm9sIHBhZEEHnFAFmUVuYWJsZSBQcmVzc3VyZSAoQ2ggNTkuMClBB59QBZxFbmFi'
    b'bGUgVGVtcGVyYXR1cmUgKENoIDU5LjEpQQelUAWiRW5hYmxlIFJlbGF0aXZlIEh1bWlkaX'
    b'R5IChDaCA1OS4yKUAR41AFi1NhbXBsZSBSYXRlUAGDAv87UBSUQ29uZmlnWzB4MWZmM0Jd'
    b'ID09IDBQFaRTZXQgc2FtcGxlIGZyZXF1ZW5jeSBmcm9tIDEgdG8gMTAgSHpRAYEKUCWCSH'
    b'pREYEBUSGBCkAIQclQBZlJbmVydGlhbCBNZWFzdXJlbWVudCBVbml0QAdAklAFkEFjcXVp'
    b'c2l0aW9uIE1vZGVQAYMB/ytRAYEQQQeKUAWDT2ZmUQGBAEEHqFAFoUFic29sdXRlIE9yaW'
    b'VudGF0aW9uIChRdWF0ZXJuaW9uKVEBgQhBB6hQBaFSZWxhdGl2ZSBPcmllbnRhdGlvbiAo'
    b'UXVhdGVybmlvbilRAYEQQQePUAWIUm90YXRpb25RAYECQAFAhlAFlU9yaWVudGF0aW9uIE'
    b'RhdGEgUmF0ZVABgwIIK1EBgWRQJYJIelERgQFRIYHIUBW9U2FtcGxlIHJhdGUgZm9yIGRp'
    b'cmVjdGlvbmFsIGRhdGEgZnJvbSAxIHRvIDIwMCBIei4gQ2hhbm5lbCA2NVAUlENvbmZpZ1'
    b'sweDAxRkYyQl0gPCA4QAFAiVAFklJvdGF0aW9uIERhdGEgUmF0ZVABgwICK1EBgWRQJYJI'
    b'elERgQFRIYHIUBW+U2V0IHNhbXBsZSByYXRlIGZvciByb3RhdGlvbiBkYXRhIGZyb20gMS'
    b'B0byAyMDAgSHouIENoYW5uZWwgNDdQFJlDb25maWdbMHgwMUZGMkJdICYgMiA9PSAwQAhA'
    b'8VAFpUludGVybmFsIFRlbXBlcmF0dXJlL1ByZXNzdXJlIChDaCAzNilAJ0DFUQGBA1ABgw'
    b'H/JFAV90VuYWJsZS9EaXNhYmxlIHNsb3dlciBpbnRlcm5hbCBlbnZpcm9ubWVudGFsIHNl'
    b'bnNvcnMuIE5PVEU6IFRlbXBlcmF0dXJlIGlzIHJlcXVpcmVkIGZvciBtYWluIGFjY2VsZX'
    b'JvbWV0ZXIgbWVhc3VyZW1lbnRzQQecUAWZRW5hYmxlIFByZXNzdXJlIChDaCAzNi4wKUEH'
    b'n1AFnEVuYWJsZSBUZW1wZXJhdHVyZSAoQ2ggMzYuMSlACPlQBaBDb250cm9sIFBhZCBMaW'
    b'dodCBTZW5zb3IgKENoIDc2KUAn01EBgQFQAYMB/0xQFaNFbmFibGUvRGlzYWJsZSBsaWdo'
    b'dCBzZW5zb3IgYXQgNCBIekEHoFAFnUVuYWJsZSBMaWdodCBTZW5zb3IgKENoIDc2LjApQA'
    b'+AQE+ASgiASiiASkiA'
)
