"""
Default ConfigUI for S3-D16 data recorders 
"""

from base64 import b64decode

DEFAULT_CONFIG_UI = b64decode(
    b'd3dSSEAoRYFQBYdHZW5lcmFsQAXzUAWLRGV2aWNlIE5hbWVQAYMI/39RJIFAUBXYQSBjdX'
    b'N0b20gbmFtZSBmb3IgdGhlIHJlY29yZGVyLiBOb3QgdGhlIHNhbWUgYXMgdGhlIHZvbHVt'
    b'ZSBsYWJlbC4gNjQgY2hhcmFjdGVycyBtYXhpbXVtLkAF81AFjERldmljZSBOb3Rlc1ABgw'
    b'n/f1EkggEAUBXSQ3VzdG9tIG5vdGVzIGFib3V0IHRoZSByZWNvcmRlciAocG9zaXRpb24s'
    b'IHVzZXIgSUQsIGV0Yy4pLiAyNTYgY2hhcmFjdGVycyBtYXhpbXVtLlE0gQNABfpQBZNSZW'
    b'NvcmRpbmcgRGlyZWN0b3J5UAGDFP9/UQSGUkVDT1JEUSSBCFAUk0NvbmZpZ1sweDE2RkY3'
    b'Rl09PTBQFbhEaXJlY3RvcnkgZm9yIHNlcmlhbGl6ZWQgcmVjb3JkaW5ncy4gOCBjaGFyYW'
    b'N0ZXIgbWF4aW11bUAFQKJQBZVSZWNvcmRpbmcgRmlsZSBQcmVmaXhQAYMV/39RJIEIUBXn'
    b'UHJlZml4IGZvciBzZXJpYWxpemVkIHJlY29yZGluZyBuYW1lcy4gSWYgYmxhbmssIGRldm'
    b'ljZSBzZXJpYWwgbnVtYmVyIHdpbGwgYmUgdXNlZC4gOCBjaGFyYWN0ZXIgbWF4aW11bVAU'
    b'k0NvbmZpZ1sweDE2RkY3Rl09PTBAB0E8UAWPRmlsZSBOYW1lIFN0eWxlUAGDFv9/UQGBAF'
    b'AVQPxUaW1lLUJhc2VkIGZpbGUgbmFtZXMgdXNlIGEgZGlyZWN0b3J5IGJhc2VkIG9uIHRo'
    b'ZSBkYXRlLCBhbmQgZmlsZSBuYW1lIGJhc2VkIG9uIHRoZSBzZWNvbmRzIHNpbmNlIG1pZG'
    b'5pZ2h0LgpTZXJpYWxpemVkIGZpbGUgbmFtZXMgdXNlIHRoZSBzcGVjaWZpZWQgZGlyZWN0'
    b'b3J5IGFuZCBmaWxlIG5hbWUgcHJlZml4LCBmb2xsb3dlZCBieSBhIG51bWJlci4gCk51bW'
    b'JlciBpcyByZXNldCB3aGVuIGRpcmVjdG9yeSBvciBwcmVmaXggY2hhbmdlcy5BB41QBYpU'
    b'aW1lIEJhc2VkQQeNUAWKU2VyaWFsaXplZEAHQJlQBYtCdXR0b24gTW9kZVABgxD/f1EBgQ'
    b'BQFb9PbmUgU2Vjb25kIFByZXNzIHdpbGwgZGlzYWJsZSAzLXNlY29uZCBwcmVzcyBmb3Ig'
    b'YmF0dGVyeSBjaGVjay5BB5dQBZRJbW1lZGlhdGUgU3RhcnQvU3RvcEEHolAFn09uZSBTZW'
    b'NvbmQgUHJlc3MgZm9yIFN0YXJ0L1N0b3BAF0EUUAWOUGx1Zy1JbiBBY3Rpb25QAYMK/39R'
    b'AYEBUBWtU2V0IGFjdGlvbiBmb3IgZGV2aWNlIHdoZW4gcGx1Z2dlZCBpbiB0byBVU0IuQQ'
    b'e1UAWySW1tZWRpYXRlbHkgc3RvcCByZWNvcmRpbmcgYW5kIGFwcGVhciBhcyBVU0IgZHJp'
    b'dmVBB7NQBbBDb21wbGV0ZSByZWNvcmRpbmcgYmVmb3JlIGFwcGVhcmluZyBhcyBVU0IgZH'
    b'JpdmVBB7BQBa1JZ25vcmU6IHN0b3AgcmVjb3JkaW5nIHdoZW4gYnV0dG9uIGlzIHByZXNz'
    b'ZWRBB6VQBaJTdGFydCByZWNvcmRpbmcgd2hlbiBVU0IgY29ubmVjdGVkQCPnUAGDC/9/UB'
    b'XeRW50ZXIgbG9jYWwgdGltZXpvbmUncyBvZmZzZXQgZnJvbSBVVEMgdGltZS4gSW1wYWN0'
    b'cyB0aW1lc3RhbXAgaW5mb3JtYXRpb24gb24gcmVjb3JkaW5nIGZpbGVzLkAvgEAPgEBPgE'
    b'AoR21QBYhUcmlnZ2Vyc0AHQNpQBYxUcmlnZ2VyIE1vZGVQAYMS/39RAYEAUBVAj0RlbGF5'
    b'IFRoZW4gVHJpZ2dlcjogV2FpdCBzcGVjaWZpZWQgdGltZSwgdGhlbiB3YWl0IGZvciB0cm'
    b'lnZ2VyCkRlbGF5IE9yIFRyaWdnZXI6IEFjcXVpcmUgYWZ0ZXIgd2FpdCBvciBvbiB0cmln'
    b'Z2VyLiBCYXR0ZXJ5IGxpZmUgbWF5IGJlIHJlZHVjZWQuQQeVUAWSRGVsYXkgVGhlbiBUcm'
    b'lnZ2VyQQeTUAWQRGVsYXkgT3IgVHJpZ2dlckAy9FAFjVN0YXJ0IGF0IFRpbWVQAYMP/39Q'
    b'FdtXYWl0IHVudGlsIHNldCB0aW1lIGJlZm9yZSBldmFsdWF0aW5nIG90aGVyIHRyaWdnZX'
    b'IgY29uZGl0aW9ucywgaW5jbHVkaW5nIGEgcmVjb3JkaW5nIGRlbGF5QBGuUAWUUmVjb3Jk'
    b'aW5nIFRpbWUgTGltaXRQAYMN/39RIYT////wUCWHU2Vjb25kc0ARQJBQBZhSZWNvcmRpbm'
    b'cgRGVsYXkvSW50ZXJ2YWxQAYMM/39RAYEAUCWHU2Vjb25kc1EhgwFRgFAV2FRpbWUgYmVm'
    b'b3JlIHN0YXJ0aW5nIGEgcmVjb3JkaW5nLCBhbmQgdGltZSBiZXR3ZWVuIHJlY29yZGluZ3'
    b'MgaWYgJ1JldHJpZ2dlcicgaXMgY2hlY2tlZC5AEa9QBZlSZWNvcmRpbmcgRmlsZSBTaXpl'
    b'IExpbWl0UAGDEf9/USGE////8FAlg0tpQkAQQJdQBYlSZXRyaWdnZXJQAYMO/39QFLBDb2'
    b'5maWdbMHhERkY3Rl09PW51bGwgYW5kIENvbmZpZ1sweDExRkY3Rl09PW51bGxQFc9XaGVu'
    b'IHNldCwgU2xhbSBTdGljayB3aWxsIHJlLWFybSBhZnRlciByZWNvcmRpbmcgdGltZSBvci'
    b'BzaXplIGxpbWl0IGlzIHJlYWNoZWQuQBBAqFAFnldhaXQgZm9yIEFsbCBTZW5zb3IgQ29u'
    b'ZGl0aW9uc1ABgxP/f1AV/ldoZW4gc2V0LCByZWNvcmRpbmcgd2lsbCBvbmx5IHN0YXJ0IH'
    b'doZW4gYWxsIHRyaWdnZXJzIGFyZSBtZXQsIG90aGVyd2lzZSByZWNvcmRpbmcgd2lsbCBz'
    b'dGFydCB3aGVuIGFueSBzZW5zb3IgY29uZGl0aW9uIGlzIG1ldEAYQQpQBZBQcmVzc3VyZS'
    b'BUcmlnZ2VyUAGDBQAkUQCBAFAUmUNvbmZpZ1sweDAxRkYyNF0gJiAxID09IDBAguVQBZVQ'
    b'cmVzc3VyZSBUcmlnZ2VyLCBMb3dQAYMDACRRAYMBX5BQJYJQYVEhgwHUwFAVs1NldCB0by'
    b'BzdGFydCBzYW1wbGluZyB3aGVuIG91dHNpZGUgcHJlc3N1cmUgd2luZG93LkCC5lAFllBy'
    b'ZXNzdXJlIFRyaWdnZXIsIEhpZ2hQAYMEACRRAYMBrbBQJYJQYVEhgwHUwFAVs1NldCB0by'
    b'BzdGFydCBzYW1wbGluZyB3aGVuIG91dHNpZGUgcHJlc3N1cmUgd2luZG93LkAYQRdQBZNU'
    b'ZW1wZXJhdHVyZSBUcmlnZ2VyUAGDBQEkUQCBAFAUmUNvbmZpZ1sweDAxRkYyNF0gJiAyID'
    b'09IDBAY+pQBZhUZW1wZXJhdHVyZSBUcmlnZ2VyLCBMb3dQAYMDASRRAoH2UCWBQ1ESgdhR'
    b'IoFQUBW2U2V0IHRvIHN0YXJ0IHNhbXBsaW5nIHdoZW4gb3V0c2lkZSB0ZW1wZXJhdHVyZS'
    b'B3aW5kb3cuQGPrUAWZVGVtcGVyYXR1cmUgVHJpZ2dlciwgSGlnaFABgwQBJFECgSNQJYFD'
    b'URKB2FEigVBQFbZTZXQgdG8gc3RhcnQgc2FtcGxpbmcgd2hlbiBvdXRzaWRlIHRlbXBlcm'
    b'F0dXJlIHdpbmRvdy5AGEGcUAWaQWNjZWxlcmF0aW9uIFRyaWdnZXIgKDE2ZylQAYMH/yBQ'
    b'FdRMb3cgcG93ZXIgdHJpZ2dlciB1c2luZyBkaWdpdGFsIGFjY2VsZXJvbWV0ZXIgd2l0aC'
    b'BEQyByZXNwb25zZS4gTm8gcHJlLXRyaWdnZXIgZGF0YS5RAIEAUBGDBf8IUCSAUBSUQ29u'
    b'ZmlnWzB4MWZmMjBdID09IDBAQ0CxUAWWQWNjZWxlcmF0aW9uIFRocmVzaG9sZFABgwT/IF'
    b'EBgVBSA4g/sBAQEBAQEFEjiEAwAAAAAAAAUROAUBXyTG93IHBvd2VyIHRyaWdnZXIuIFRo'
    b'ZSBtaW5pbXVtIGFjY2VsZXJhdGlvbiAocG9zaXRpdmUgb3IgbmVnYXRpdmUpIHRvIHRyaW'
    b'dnZXIgYSByZWNvcmRpbmcuIE11c3QgYmUgZ3JlYXRlciB0aGFuIDAuQCfGUAGDBf8gUQGB'
    b'B0EHkVAFjlggQXhpcyBUcmlnZ2VyQQeRUAWOWSBBeGlzIFRyaWdnZXJBB5FQBY5aIEF4aX'
    b'MgVHJpZ2dlckAPgEBPgEAoRUVQBYxNZWFzdXJlbWVudHNACEC6UAWbMTZnIERDIEFjY2Vs'
    b'ZXJhdGlvbiAoQ2ggMzIpQCefUAGDAf8gUQGBAUEHklAFj0VuYWJsZSBBbGwgQXhlc0AX91'
    b'AFi1NhbXBsZSBSYXRlUAGDAv8gUQGCAZBQJYJIelAUk25vdCBDb25maWdbMHgxZmYyMF1B'
    b'B4VRAYIMgEEHhVEBggZAQQeFUQGCAyBBB4VRAYIBkEEHhFEBgchBB4RRAYFkQQeEUQGBMk'
    b'EHhFEBgRlBB4RRAYEMQAhBMFAFqENvbnRyb2wgUGFkIFRlbXBlcmF0dXJlL1ByZXNzdXJl'
    b'IChDaCA1OSlAJ0CbUQGBA1ABgwH/O1AVpUVuYWJsZS9EaXNhYmxlIHNlbnNvcnMgb24gY2'
    b'9udHJvbCBwYWRBB5xQBZlFbmFibGUgUHJlc3N1cmUgKENoIDU5LjApQQefUAWcRW5hYmxl'
    b'IFRlbXBlcmF0dXJlIChDaCA1OS4xKUEHpVAFokVuYWJsZSBSZWxhdGl2ZSBIdW1pZGl0eS'
    b'AoQ2ggNTkuMilAEeNQBYtTYW1wbGUgUmF0ZVABgwL/O1AUlENvbmZpZ1sweDFmZjNCXSA9'
    b'PSAwUBWkU2V0IHNhbXBsZSBmcmVxdWVuY3kgZnJvbSAxIHRvIDEwIEh6UQGBClAlgkh6UR'
    b'GBAVEhgQpACEHJUAWZSW5lcnRpYWwgTWVhc3VyZW1lbnQgVW5pdEAHQJJQBZBBY3F1aXNp'
    b'dGlvbiBNb2RlUAGDAf8rUQGBEEEHilAFg09mZlEBgQBBB6hQBaFBYnNvbHV0ZSBPcmllbn'
    b'RhdGlvbiAoUXVhdGVybmlvbilRAYEIQQeoUAWhUmVsYXRpdmUgT3JpZW50YXRpb24gKFF1'
    b'YXRlcm5pb24pUQGBEEEHj1AFiFJvdGF0aW9uUQGBAkABQIZQBZVPcmllbnRhdGlvbiBEYX'
    b'RhIFJhdGVQAYMCCCtRAYFkUCWCSHpREYEBUSGByFAVvVNhbXBsZSByYXRlIGZvciBkaXJl'
    b'Y3Rpb25hbCBkYXRhIGZyb20gMSB0byAyMDAgSHouIENoYW5uZWwgNjVQFJRDb25maWdbMH'
    b'gwMUZGMkJdIDwgOEABQIlQBZJSb3RhdGlvbiBEYXRhIFJhdGVQAYMCAitRAYFkUCWCSHpR'
    b'EYEBUSGByFAVvlNldCBzYW1wbGUgcmF0ZSBmb3Igcm90YXRpb24gZGF0YSBmcm9tIDEgdG'
    b'8gMjAwIEh6LiBDaGFubmVsIDQ3UBSZQ29uZmlnWzB4MDFGRjJCXSAmIDIgPT0gMEAIQPFQ'
    b'BaVJbnRlcm5hbCBUZW1wZXJhdHVyZS9QcmVzc3VyZSAoQ2ggMzYpQCdAxVEBgQNQAYMB/y'
    b'RQFfdFbmFibGUvRGlzYWJsZSBzbG93ZXIgaW50ZXJuYWwgZW52aXJvbm1lbnRhbCBzZW5z'
    b'b3JzLiBOT1RFOiBUZW1wZXJhdHVyZSBpcyByZXF1aXJlZCBmb3IgbWFpbiBhY2NlbGVyb2'
    b'1ldGVyIG1lYXN1cmVtZW50c0EHnFAFmUVuYWJsZSBQcmVzc3VyZSAoQ2ggMzYuMClBB59Q'
    b'BZxFbmFibGUgVGVtcGVyYXR1cmUgKENoIDM2LjEpQAj5UAWgQ29udHJvbCBQYWQgTGlnaH'
    b'QgU2Vuc29yIChDaCA3NilAJ9NRAYEBUAGDAf9MUBWjRW5hYmxlL0Rpc2FibGUgbGlnaHQg'
    b'c2Vuc29yIGF0IDQgSHpBB6BQBZ1FbmFibGUgTGlnaHQgU2Vuc29yIChDaCA3Ni4wKUAPgE'
    b'BPgEoIgEoogEpIgA=='
)
