"""
Default ConfigUI for S5-E2000D40 data recorders 
"""

from base64 import b64decode

DEFAULT_CONFIG_UI = b64decode(
    b'd3dViUAoRZNQBYdHZW5lcmFsQAXzUAWLRGV2aWNlIE5hbWVQAYMI/39RJIFAUBXYQSBjdX'
    b'N0b20gbmFtZSBmb3IgdGhlIHJlY29yZGVyLiBOb3QgdGhlIHNhbWUgYXMgdGhlIHZvbHVt'
    b'ZSBsYWJlbC4gNjQgY2hhcmFjdGVycyBtYXhpbXVtLkAF81AFjERldmljZSBOb3Rlc1ABgw'
    b'n/f1EkggEAUBXSQ3VzdG9tIG5vdGVzIGFib3V0IHRoZSByZWNvcmRlciAocG9zaXRpb24s'
    b'IHVzZXIgSUQsIGV0Yy4pLiAyNTYgY2hhcmFjdGVycyBtYXhpbXVtLlE0gQNABftQBZNSZW'
    b'NvcmRpbmcgRGlyZWN0b3J5UAGDFP9/UQSGUkVDT1JEUSSBEFAUk0NvbmZpZ1sweDE2RkY3'
    b'Rl09PTBQFblEaXJlY3RvcnkgZm9yIHNlcmlhbGl6ZWQgcmVjb3JkaW5ncy4gMTYgY2hhcm'
    b'FjdGVyIG1heGltdW1ABUCjUAWVUmVjb3JkaW5nIEZpbGUgUHJlZml4UAGDFf9/USSBEFAV'
    b'6FByZWZpeCBmb3Igc2VyaWFsaXplZCByZWNvcmRpbmcgbmFtZXMuIElmIGJsYW5rLCBkZX'
    b'ZpY2Ugc2VyaWFsIG51bWJlciB3aWxsIGJlIHVzZWQuIDE2IGNoYXJhY3RlciBtYXhpbXVt'
    b'UBSTQ29uZmlnWzB4MTZGRjdGXT09MEAHQTxQBY9GaWxlIE5hbWUgU3R5bGVQAYMW/39RAY'
    b'EBUBVA/FRpbWUtQmFzZWQgZmlsZSBuYW1lcyB1c2UgYSBkaXJlY3RvcnkgYmFzZWQgb24g'
    b'dGhlIGRhdGUsIGFuZCBmaWxlIG5hbWUgYmFzZWQgb24gdGhlIHNlY29uZHMgc2luY2UgbW'
    b'lkbmlnaHQuClNlcmlhbGl6ZWQgZmlsZSBuYW1lcyB1c2UgdGhlIHNwZWNpZmllZCBkaXJl'
    b'Y3RvcnkgYW5kIGZpbGUgbmFtZSBwcmVmaXgsIGZvbGxvd2VkIGJ5IGEgbnVtYmVyLiAKTn'
    b'VtYmVyIGlzIHJlc2V0IHdoZW4gZGlyZWN0b3J5IG9yIHByZWZpeCBjaGFuZ2VzLkEHjVAF'
    b'ilRpbWUgQmFzZWRBB41QBYpTZXJpYWxpemVkQAdAqVAFi0J1dHRvbiBNb2RlUAGDEP9/UQ'
    b'GBAFAVv09uZSBTZWNvbmQgUHJlc3Mgd2lsbCBkaXNhYmxlIDMtc2Vjb25kIHByZXNzIGZv'
    b'ciBiYXR0ZXJ5IGNoZWNrLkEHl1AFlEltbWVkaWF0ZSBTdGFydC9TdG9wQQeiUAWfT25lIF'
    b'NlY29uZCBQcmVzcyBmb3IgU3RhcnQvU3RvcEEHjVAFilN0YXJ0LU9ubHlAF0EUUAWOUGx1'
    b'Zy1JbiBBY3Rpb25QAYMK/39RAYEBUBWtU2V0IGFjdGlvbiBmb3IgZGV2aWNlIHdoZW4gcG'
    b'x1Z2dlZCBpbiB0byBVU0IuQQe1UAWySW1tZWRpYXRlbHkgc3RvcCByZWNvcmRpbmcgYW5k'
    b'IGFwcGVhciBhcyBVU0IgZHJpdmVBB7NQBbBDb21wbGV0ZSByZWNvcmRpbmcgYmVmb3JlIG'
    b'FwcGVhcmluZyBhcyBVU0IgZHJpdmVBB7BQBa1JZ25vcmU6IHN0b3AgcmVjb3JkaW5nIHdo'
    b'ZW4gYnV0dG9uIGlzIHByZXNzZWRBB6VQBaJTdGFydCByZWNvcmRpbmcgd2hlbiBVU0IgY2'
    b'9ubmVjdGVkQCPnUAGDC/9/UBXeRW50ZXIgbG9jYWwgdGltZXpvbmUncyBvZmZzZXQgZnJv'
    b'bSBVVEMgdGltZS4gSW1wYWN0cyB0aW1lc3RhbXAgaW5mb3JtYXRpb24gb24gcmVjb3JkaW'
    b'5nIGZpbGVzLkAvgEAPgEBPgEAoSOlQBYhUcmlnZ2Vyc0AHQNpQBYxUcmlnZ2VyIE1vZGVQ'
    b'AYMS/39RAYEAUBVAj0RlbGF5IFRoZW4gVHJpZ2dlcjogV2FpdCBzcGVjaWZpZWQgdGltZS'
    b'wgdGhlbiB3YWl0IGZvciB0cmlnZ2VyCkRlbGF5IE9yIFRyaWdnZXI6IEFjcXVpcmUgYWZ0'
    b'ZXIgd2FpdCBvciBvbiB0cmlnZ2VyLiBCYXR0ZXJ5IGxpZmUgbWF5IGJlIHJlZHVjZWQuQQ'
    b'eVUAWSRGVsYXkgVGhlbiBUcmlnZ2VyQQeTUAWQRGVsYXkgT3IgVHJpZ2dlckAy9FAFjVN0'
    b'YXJ0IGF0IFRpbWVQAYMP/39QFdtXYWl0IHVudGlsIHNldCB0aW1lIGJlZm9yZSBldmFsdW'
    b'F0aW5nIG90aGVyIHRyaWdnZXIgY29uZGl0aW9ucywgaW5jbHVkaW5nIGEgcmVjb3JkaW5n'
    b'IGRlbGF5QBGuUAWUUmVjb3JkaW5nIFRpbWUgTGltaXRQAYMN/39RIYT////wUCWHU2Vjb2'
    b'5kc0ARQJBQBZhSZWNvcmRpbmcgRGVsYXkvSW50ZXJ2YWxQAYMM/39RAYEAUCWHU2Vjb25k'
    b'c1EhgwFRgFAV2FRpbWUgYmVmb3JlIHN0YXJ0aW5nIGEgcmVjb3JkaW5nLCBhbmQgdGltZS'
    b'BiZXR3ZWVuIHJlY29yZGluZ3MgaWYgJ1JldHJpZ2dlcicgaXMgY2hlY2tlZC5AEa9QBZlS'
    b'ZWNvcmRpbmcgRmlsZSBTaXplIExpbWl0UAGDEf9/USGE////8FAlg0tpQkAQQJdQBYlSZX'
    b'RyaWdnZXJQAYMO/39QFLBDb25maWdbMHhERkY3Rl09PW51bGwgYW5kIENvbmZpZ1sweDEx'
    b'RkY3Rl09PW51bGxQFc9XaGVuIHNldCwgU2xhbSBTdGljayB3aWxsIHJlLWFybSBhZnRlci'
    b'ByZWNvcmRpbmcgdGltZSBvciBzaXplIGxpbWl0IGlzIHJlYWNoZWQuQBBAqFAFnldhaXQg'
    b'Zm9yIEFsbCBTZW5zb3IgQ29uZGl0aW9uc1ABgxP/f1AV/ldoZW4gc2V0LCByZWNvcmRpbm'
    b'cgd2lsbCBvbmx5IHN0YXJ0IHdoZW4gYWxsIHRyaWdnZXJzIGFyZSBtZXQsIG90aGVyd2lz'
    b'ZSByZWNvcmRpbmcgd2lsbCBzdGFydCB3aGVuIGFueSBzZW5zb3IgY29uZGl0aW9uIGlzIG'
    b'1ldEAYQO5QBZBQcmVzc3VyZSBUcmlnZ2VyUAGDBQAkUQCBAECC5VAFlVByZXNzdXJlIFRy'
    b'aWdnZXIsIExvd1ABgwMAJFEBgwFfkFAlglBhUSGDAdTAUBWzU2V0IHRvIHN0YXJ0IHNhbX'
    b'BsaW5nIHdoZW4gb3V0c2lkZSBwcmVzc3VyZSB3aW5kb3cuQILmUAWWUHJlc3N1cmUgVHJp'
    b'Z2dlciwgSGlnaFABgwQAJFEBgwGtsFAlglBhUSGDAdTAUBWzU2V0IHRvIHN0YXJ0IHNhbX'
    b'BsaW5nIHdoZW4gb3V0c2lkZSBwcmVzc3VyZSB3aW5kb3cuQBhA+1AFk1RlbXBlcmF0dXJl'
    b'IFRyaWdnZXJQAYMFASRRAIEAQGPqUAWYVGVtcGVyYXR1cmUgVHJpZ2dlciwgTG93UAGDAw'
    b'EkUQKB9lAlgUNREoHYUSKBUFAVtlNldCB0byBzdGFydCBzYW1wbGluZyB3aGVuIG91dHNp'
    b'ZGUgdGVtcGVyYXR1cmUgd2luZG93LkBj61AFmVRlbXBlcmF0dXJlIFRyaWdnZXIsIEhpZ2'
    b'hQAYMEASRRAoEjUCWBQ1ESgdhRIoFQUBW2U2V0IHRvIHN0YXJ0IHNhbXBsaW5nIHdoZW4g'
    b'b3V0c2lkZSB0ZW1wZXJhdHVyZSB3aW5kb3cuQBhBqVAFnEFjY2VsZXJhdGlvbiBUcmlnZ2'
    b'VyICgyMDAwZylQAYMF/whQEYMH/yBRAIEAUCSAUBSVQ29uZmlnWzB4MDFGRjA4XSA9PSAw'
    b'QENAq1AFmUFjY2VsZXJhdGlvbiBUcmlnZ2VyLCBMb3dQAYMD/whRAoL5mlETiMCfQAAAAA'
    b'AAUSOIQJ9AAAAAAABQFeBIaWdoIHBvd2VyIHRyaWdnZXIgd2l0aCBwcmUtdHJpZ2dlciBk'
    b'YXRhLiBOb3QgcmVjb21tZW5kZWQgZm9yIGxvbmcgd2FpdHMgd2l0aG91dCBleHRlcm5hbC'
    b'Bwb3dlci5SA4g/r0AfQB9ILkBDQKxQBZpBY2NlbGVyYXRpb24gVHJpZ2dlciwgSGlnaFAB'
    b'gwT/CFECggZmUROIwJ9AAAAAAABRI4hAn0AAAAAAAFAV4EhpZ2ggcG93ZXIgdHJpZ2dlci'
    b'B3aXRoIHByZS10cmlnZ2VyIGRhdGEuIE5vdCByZWNvbW1lbmRlZCBmb3IgbG9uZyB3YWl0'
    b'cyB3aXRob3V0IGV4dGVybmFsIHBvd2VyLlIDiD+vQB9AH0guQBhBo1AFmkFjY2VsZXJhdG'
    b'lvbiBUcmlnZ2VyICg0MGcpUAGDB/9QUBXUTG93IHBvd2VyIHRyaWdnZXIgdXNpbmcgZGln'
    b'aXRhbCBhY2NlbGVyb21ldGVyIHdpdGggREMgcmVzcG9uc2UuIE5vIHByZS10cmlnZ2VyIG'
    b'RhdGEuUQCBAFARgwX/CFARgwf/IFAkgFAUlENvbmZpZ1sweDFmZjUwXSA9PSAwQENAslAF'
    b'lkFjY2VsZXJhdGlvbiBUaHJlc2hvbGRQAYME/1BRAYIgAFIDiD9EABQAFAAUUSOIQEQAAA'
    b'AAAABRE4BQFfJMb3cgcG93ZXIgdHJpZ2dlci4gVGhlIG1pbmltdW0gYWNjZWxlcmF0aW9u'
    b'IChwb3NpdGl2ZSBvciBuZWdhdGl2ZSkgdG8gdHJpZ2dlciBhIHJlY29yZGluZy4gTXVzdC'
    b'BiZSBncmVhdGVyIHRoYW4gMC5AJ8ZQAYMF/1BRAYEHQQeRUAWOWCBBeGlzIFRyaWdnZXJB'
    b'B5FQBY5ZIEF4aXMgVHJpZ2dlckEHkVAFjlogQXhpcyBUcmlnZ2VyQA+AQE+AQChG+FAFjE'
    b'1lYXN1cmVtZW50c0AIQkJQBZkyMDAwZyBBY2NlbGVyYXRpb24gKENoIDgpUCSAQCdAgVEB'
    b'gQdQAYMB/whQFaBFbmFibGUvRGlzYWJsZSBhY2NlbGVyYXRpb24gYXhlc0EHmVAFlkVuYW'
    b'JsZSBYIEF4aXMgKENoIDguMClBB5lQBZZFbmFibGUgWSBBeGlzIChDaCA4LjEpQQeZUAWW'
    b'RW5hYmxlIFogQXhpcyAoQ2ggOC4yKUARQJpQBYtTYW1wbGUgUmF0ZVABgwL/CFAV2FNldC'
    b'BtYWluIGFjY2VsZXJhdGlvbiBzYW1wbGUgcmF0ZSBmcm9tIDEwIHRvIDIwMDAwIEh6LgpI'
    b'aWdoZXIgcmF0ZSByZWR1Y2VzIGJhdHRlcnkgbGlmZS5QFJVDb25maWdbMHgwMUZGMDhdID'
    b'09IDBRAYITiFAlgkh6URGBClEhgk4gQBFA/FAFo092ZXJyaWRlIEFudGlhbGlhc2luZyBG'
    b'aWx0ZXIgQ3V0b2ZmUAGDCP8IUQGCA+hQJYJIelEhgmGoUBVApURlZmF1bHQsIHdoZW4gbm'
    b'90IGNoZWNrZWQsIG9mIG9uZS1maWZ0aCBzYW1wbGUgZnJlcXVlbmN5LiBDdXQtb2ZmIGZy'
    b'ZXF1ZW5jeSBoYXMgMjklIGF0dGVudWF0aW9uLgo1dGggb3JkZXIgQnV0dGVyd29ydGguIF'
    b'NvbWUgYXR0ZW51YXRpb24gYXQgNjAlIG9mIGN1dC1vZmYgZnJlcXVlbmN5LlAUlUNvbmZp'
    b'Z1sweDAxRkYwOF0gPT0gMEAIQRxQBZs0MGcgREMgQWNjZWxlcmF0aW9uIChDaCA4MClAJ5'
    b'9QAYMB/1BRAYEBQQeSUAWPRW5hYmxlIEFsbCBBeGVzQBdA2FAFi1NhbXBsZSBSYXRlUAGD'
    b'Av9QUQGCAfRQJYJIelAV3kxvdyBwYXNzIGZpbHRlciBpcyBzZXQgdG8gMjUlIG9mIGRhdG'
    b'EgcmF0ZSwgc28gYSBkYXRhIHJhdGUgb2YgMjAwMEh6IGhhcyBhIExQIGZpbHRlciBhdCA1'
    b'MDAgSHpQFJNub3QgQ29uZmlnWzB4MWZmNTBdQQeFUQGCD6BBB4VRAYIH0EEHhVEBggPoQQ'
    b'eFUQGCAfRBB4RRAYH6QQeEUQGBfUEHhFEBgT9BB4RRAYEgQQeEUQGBEEAIQTBQBahDb250'
    b'cm9sIFBhZCBUZW1wZXJhdHVyZS9QcmVzc3VyZSAoQ2ggNTkpQCdAm1EBgQNQAYMB/ztQFa'
    b'VFbmFibGUvRGlzYWJsZSBzZW5zb3JzIG9uIGNvbnRyb2wgcGFkQQecUAWZRW5hYmxlIFBy'
    b'ZXNzdXJlIChDaCA1OS4wKUEHn1AFnEVuYWJsZSBUZW1wZXJhdHVyZSAoQ2ggNTkuMSlBB6'
    b'VQBaJFbmFibGUgUmVsYXRpdmUgSHVtaWRpdHkgKENoIDU5LjIpQBHjUAWLU2FtcGxlIFJh'
    b'dGVQAYMC/ztQFJRDb25maWdbMHgxZmYzQl0gPT0gMFAVpFNldCBzYW1wbGUgZnJlcXVlbm'
    b'N5IGZyb20gMSB0byAxMCBIelEBgQpQJYJIelERgQFRIYEKQAhBzVAFmUluZXJ0aWFsIE1l'
    b'YXN1cmVtZW50IFVuaXRAB0CWUAWQQWNxdWlzaXRpb24gTW9kZVABgwH/K1AlgSBRAYEQQQ'
    b'eKUAWDT2ZmUQGBAEEHqFAFoUFic29sdXRlIE9yaWVudGF0aW9uIChRdWF0ZXJuaW9uKVEB'
    b'gQhBB6hQBaFSZWxhdGl2ZSBPcmllbnRhdGlvbiAoUXVhdGVybmlvbilRAYEQQQePUAWIUm'
    b'90YXRpb25RAYECQAFAhlAFlU9yaWVudGF0aW9uIERhdGEgUmF0ZVABgwIIK1EBgWRQJYJI'
    b'elERgQFRIYHIUBW9U2FtcGxlIHJhdGUgZm9yIGRpcmVjdGlvbmFsIGRhdGEgZnJvbSAxIH'
    b'RvIDIwMCBIei4gQ2hhbm5lbCA2NVAUlENvbmZpZ1sweDAxRkYyQl0gPCA4QAFAiVAFklJv'
    b'dGF0aW9uIERhdGEgUmF0ZVABgwICK1EBgWRQJYJIelERgQFRIYHIUBW+U2V0IHNhbXBsZS'
    b'ByYXRlIGZvciByb3RhdGlvbiBkYXRhIGZyb20gMSB0byAyMDAgSHouIENoYW5uZWwgNDdQ'
    b'FJlDb25maWdbMHgwMUZGMkJdICYgMiA9PSAwQAj1UAWgQ29udHJvbCBQYWQgTGlnaHQgU2'
    b'Vuc29yIChDaCA3NilAJ89QAYMB/0xQFaNFbmFibGUvRGlzYWJsZSBsaWdodCBzZW5zb3Ig'
    b'YXQgNCBIekEHoFAFnUVuYWJsZSBMaWdodCBTZW5zb3IgKENoIDc2LjApQA+AQE+ASgiASi'
    b'iASkiA'
)
