"""
Default ConfigUI for W8-E2000D40 data recorders 
"""

from base64 import b64decode

DEFAULT_CONFIG_UI = b64decode(
    b'd3dZHkAoSDxQBYdHZW5lcmFsQAXzUAWLRGV2aWNlIE5hbWVQAYMI/39RJIFAUBXYQSBjdX'
    b'N0b20gbmFtZSBmb3IgdGhlIHJlY29yZGVyLiBOb3QgdGhlIHNhbWUgYXMgdGhlIHZvbHVt'
    b'ZSBsYWJlbC4gNjQgY2hhcmFjdGVycyBtYXhpbXVtLkAF81AFjERldmljZSBOb3Rlc1ABgw'
    b'n/f1EkggEAUBXSQ3VzdG9tIG5vdGVzIGFib3V0IHRoZSByZWNvcmRlciAocG9zaXRpb24s'
    b'IHVzZXIgSUQsIGV0Yy4pLiAyNTYgY2hhcmFjdGVycyBtYXhpbXVtLlE0gQNABUCZUAWVQ3'
    b'VzdG9tIFJlY29yZGluZyBUYWdzUAGDF/9/UQSAUSSBQFAV8UtleXdvcmRzIGZvciBvcmdh'
    b'bml6aW5nIGFuZCBpZGVudGlmeWluZyByZWNvcmRpbmdzLCBzZXBhcmF0ZWQgYnkgY29tbW'
    b'Egb3Igc3BhY2UuIExpbWl0IGlzIDIwIHRhZ3MsIDY0IGNoYXJhY3RlcnMuQAX7UAWTUmVj'
    b'b3JkaW5nIERpcmVjdG9yeVABgxT/f1EEhlJFQ09SRFEkgRBQFJNDb25maWdbMHgxNkZGN0'
    b'ZdPT0wUBW5RGlyZWN0b3J5IGZvciBzZXJpYWxpemVkIHJlY29yZGluZ3MuIDE2IGNoYXJh'
    b'Y3RlciBtYXhpbXVtQAVAo1AFlVJlY29yZGluZyBGaWxlIFByZWZpeFABgxX/f1EkgRBQFe'
    b'hQcmVmaXggZm9yIHNlcmlhbGl6ZWQgcmVjb3JkaW5nIG5hbWVzLiBJZiBibGFuaywgZGV2'
    b'aWNlIHNlcmlhbCBudW1iZXIgd2lsbCBiZSB1c2VkLiAxNiBjaGFyYWN0ZXIgbWF4aW11bV'
    b'AUk0NvbmZpZ1sweDE2RkY3Rl09PTBAB0E8UAWPRmlsZSBOYW1lIFN0eWxlUAGDFv9/UQGB'
    b'AVAVQPxUaW1lLUJhc2VkIGZpbGUgbmFtZXMgdXNlIGEgZGlyZWN0b3J5IGJhc2VkIG9uIH'
    b'RoZSBkYXRlLCBhbmQgZmlsZSBuYW1lIGJhc2VkIG9uIHRoZSBzZWNvbmRzIHNpbmNlIG1p'
    b'ZG5pZ2h0LgpTZXJpYWxpemVkIGZpbGUgbmFtZXMgdXNlIHRoZSBzcGVjaWZpZWQgZGlyZW'
    b'N0b3J5IGFuZCBmaWxlIG5hbWUgcHJlZml4LCBmb2xsb3dlZCBieSBhIG51bWJlci4gCk51'
    b'bWJlciBpcyByZXNldCB3aGVuIGRpcmVjdG9yeSBvciBwcmVmaXggY2hhbmdlcy5BB41QBY'
    b'pUaW1lIEJhc2VkQQeNUAWKU2VyaWFsaXplZEAHQKlQBYtCdXR0b24gTW9kZVABgxD/f1EB'
    b'gQBQFb9PbmUgU2Vjb25kIFByZXNzIHdpbGwgZGlzYWJsZSAzLXNlY29uZCBwcmVzcyBmb3'
    b'IgYmF0dGVyeSBjaGVjay5BB5dQBZRJbW1lZGlhdGUgU3RhcnQvU3RvcEEHolAFn09uZSBT'
    b'ZWNvbmQgUHJlc3MgZm9yIFN0YXJ0L1N0b3BBB41QBYpTdGFydC1Pbmx5QBdBFFAFjlBsdW'
    b'ctSW4gQWN0aW9uUAGDCv9/UQGBAVAVrVNldCBhY3Rpb24gZm9yIGRldmljZSB3aGVuIHBs'
    b'dWdnZWQgaW4gdG8gVVNCLkEHtVAFskltbWVkaWF0ZWx5IHN0b3AgcmVjb3JkaW5nIGFuZC'
    b'BhcHBlYXIgYXMgVVNCIGRyaXZlQQezUAWwQ29tcGxldGUgcmVjb3JkaW5nIGJlZm9yZSBh'
    b'cHBlYXJpbmcgYXMgVVNCIGRyaXZlQQewUAWtSWdub3JlOiBzdG9wIHJlY29yZGluZyB3aG'
    b'VuIGJ1dHRvbiBpcyBwcmVzc2VkQQelUAWiU3RhcnQgcmVjb3JkaW5nIHdoZW4gVVNCIGNv'
    b'bm5lY3RlZEAj51ABgwv/f1AV3kVudGVyIGxvY2FsIHRpbWV6b25lJ3Mgb2Zmc2V0IGZyb2'
    b'0gVVRDIHRpbWUuIEltcGFjdHMgdGltZXN0YW1wIGluZm9ybWF0aW9uIG9uIHJlY29yZGlu'
    b'ZyBmaWxlcy5AL4BAGEIIUAWMRW5hYmxlIFdpLUZpUAGDGP9/UQGBAUAn7FABgxn/f1EBgQ'
    b'FBB6lQBaZVcGxvYWQgcmVjb3JkaW5nIHRvIGNsb3VkIGFmdGVyIGZpbmlzaFAVs1NlbGVj'
    b'dCB0byB1cGxvYWQgZWFjaCBmaWxlIHdoZW4gcmVjb3JkaW5nIGNvbXBsZXRlc0AnQLZQAY'
    b'Ma/39RAYEAQQejUAWgRGVsZXRlIGZyb20gc3RvcmFnZSBhZnRlciB1cGxvYWRQFUCCUmVj'
    b'b3JkaW5nIGZpbGUgd2lsbCBiZSBkZWxldGVkIGFmdGVyIGEgc3VjY2Vzc2Z1bCB1cGxvYW'
    b'QsIGFuZCBtb3ZlZCB0byBhIHN1YmZvbGRlciBsYWJlbGVkICdmYWlsZWQnIGluIHRoZSBj'
    b'YXNlIG9mIGEgZmFpbGVkIHVwbG9hZEAnQMJQAYMd/39RAYEAQQepUAWmS2VlcCB0aGUgV2'
    b'ktRmkgbW9kdWxlIG9uIGFuZCBjb25uZWN0ZWRQFUCISWYgY2hlY2tlZCwgdGhlIFdpLUZp'
    b'IG1vZHVsZSB3aWxsIHN0YXkgb24gYW5kIGNvbm5lY3RlZC4gIEFsbG93cyBmb3IgZmFzdG'
    b'VyIHVwbG9hZCB0aW1lcyB3aXRoIHRoZSBleHBlbnNlIG9mIGluY3JlYXNlZCBwb3dlciBj'
    b'b25zdW1wdGlvbkAPgEBPgEAoSOlQBYhUcmlnZ2Vyc0AHQNpQBYxUcmlnZ2VyIE1vZGVQAY'
    b'MS/39RAYEAUBVAj0RlbGF5IFRoZW4gVHJpZ2dlcjogV2FpdCBzcGVjaWZpZWQgdGltZSwg'
    b'dGhlbiB3YWl0IGZvciB0cmlnZ2VyCkRlbGF5IE9yIFRyaWdnZXI6IEFjcXVpcmUgYWZ0ZX'
    b'Igd2FpdCBvciBvbiB0cmlnZ2VyLiBCYXR0ZXJ5IGxpZmUgbWF5IGJlIHJlZHVjZWQuQQeV'
    b'UAWSRGVsYXkgVGhlbiBUcmlnZ2VyQQeTUAWQRGVsYXkgT3IgVHJpZ2dlckAy9FAFjVN0YX'
    b'J0IGF0IFRpbWVQAYMP/39QFdtXYWl0IHVudGlsIHNldCB0aW1lIGJlZm9yZSBldmFsdWF0'
    b'aW5nIG90aGVyIHRyaWdnZXIgY29uZGl0aW9ucywgaW5jbHVkaW5nIGEgcmVjb3JkaW5nIG'
    b'RlbGF5QBGuUAWUUmVjb3JkaW5nIFRpbWUgTGltaXRQAYMN/39RIYT////wUCWHU2Vjb25k'
    b'c0ARQJBQBZhSZWNvcmRpbmcgRGVsYXkvSW50ZXJ2YWxQAYMM/39RAYEAUCWHU2Vjb25kc1'
    b'EhgwFRgFAV2FRpbWUgYmVmb3JlIHN0YXJ0aW5nIGEgcmVjb3JkaW5nLCBhbmQgdGltZSBi'
    b'ZXR3ZWVuIHJlY29yZGluZ3MgaWYgJ1JldHJpZ2dlcicgaXMgY2hlY2tlZC5AEa9QBZlSZW'
    b'NvcmRpbmcgRmlsZSBTaXplIExpbWl0UAGDEf9/USGE////8FAlg0tpQkAQQJdQBYlSZXRy'
    b'aWdnZXJQAYMO/39QFLBDb25maWdbMHhERkY3Rl09PW51bGwgYW5kIENvbmZpZ1sweDExRk'
    b'Y3Rl09PW51bGxQFc9XaGVuIHNldCwgU2xhbSBTdGljayB3aWxsIHJlLWFybSBhZnRlciBy'
    b'ZWNvcmRpbmcgdGltZSBvciBzaXplIGxpbWl0IGlzIHJlYWNoZWQuQBBAqFAFnldhaXQgZm'
    b'9yIEFsbCBTZW5zb3IgQ29uZGl0aW9uc1ABgxP/f1AV/ldoZW4gc2V0LCByZWNvcmRpbmcg'
    b'd2lsbCBvbmx5IHN0YXJ0IHdoZW4gYWxsIHRyaWdnZXJzIGFyZSBtZXQsIG90aGVyd2lzZS'
    b'ByZWNvcmRpbmcgd2lsbCBzdGFydCB3aGVuIGFueSBzZW5zb3IgY29uZGl0aW9uIGlzIG1l'
    b'dEAYQO5QBZBQcmVzc3VyZSBUcmlnZ2VyUAGDBQAkUQCBAECC5VAFlVByZXNzdXJlIFRyaW'
    b'dnZXIsIExvd1ABgwMAJFEBgwFfkFAlglBhUSGDAdTAUBWzU2V0IHRvIHN0YXJ0IHNhbXBs'
    b'aW5nIHdoZW4gb3V0c2lkZSBwcmVzc3VyZSB3aW5kb3cuQILmUAWWUHJlc3N1cmUgVHJpZ2'
    b'dlciwgSGlnaFABgwQAJFEBgwGtsFAlglBhUSGDAdTAUBWzU2V0IHRvIHN0YXJ0IHNhbXBs'
    b'aW5nIHdoZW4gb3V0c2lkZSBwcmVzc3VyZSB3aW5kb3cuQBhA+1AFk1RlbXBlcmF0dXJlIF'
    b'RyaWdnZXJQAYMFASRRAIEAQGPqUAWYVGVtcGVyYXR1cmUgVHJpZ2dlciwgTG93UAGDAwEk'
    b'UQKB9lAlgUNREoHYUSKBUFAVtlNldCB0byBzdGFydCBzYW1wbGluZyB3aGVuIG91dHNpZG'
    b'UgdGVtcGVyYXR1cmUgd2luZG93LkBj61AFmVRlbXBlcmF0dXJlIFRyaWdnZXIsIEhpZ2hQ'
    b'AYMEASRRAoEjUCWBQ1ESgdhRIoFQUBW2U2V0IHRvIHN0YXJ0IHNhbXBsaW5nIHdoZW4gb3'
    b'V0c2lkZSB0ZW1wZXJhdHVyZSB3aW5kb3cuQBhBqVAFnEFjY2VsZXJhdGlvbiBUcmlnZ2Vy'
    b'ICgyMDAwZylQAYMF/whQEYMH/yBRAIEAUCSAUBSVQ29uZmlnWzB4MDFGRjA4XSA9PSAwQE'
    b'NAq1AFmUFjY2VsZXJhdGlvbiBUcmlnZ2VyLCBMb3dQAYMD/whRAoL5mlETiMCfQAAAAAAA'
    b'USOIQJ9AAAAAAABQFeBIaWdoIHBvd2VyIHRyaWdnZXIgd2l0aCBwcmUtdHJpZ2dlciBkYX'
    b'RhLiBOb3QgcmVjb21tZW5kZWQgZm9yIGxvbmcgd2FpdHMgd2l0aG91dCBleHRlcm5hbCBw'
    b'b3dlci5SA4g/r0AfQB9ILkBDQKxQBZpBY2NlbGVyYXRpb24gVHJpZ2dlciwgSGlnaFABgw'
    b'T/CFECggZmUROIwJ9AAAAAAABRI4hAn0AAAAAAAFAV4EhpZ2ggcG93ZXIgdHJpZ2dlciB3'
    b'aXRoIHByZS10cmlnZ2VyIGRhdGEuIE5vdCByZWNvbW1lbmRlZCBmb3IgbG9uZyB3YWl0cy'
    b'B3aXRob3V0IGV4dGVybmFsIHBvd2VyLlIDiD+vQB9AH0guQBhBo1AFmkFjY2VsZXJhdGlv'
    b'biBUcmlnZ2VyICg0MGcpUAGDB/9QUBXUTG93IHBvd2VyIHRyaWdnZXIgdXNpbmcgZGlnaX'
    b'RhbCBhY2NlbGVyb21ldGVyIHdpdGggREMgcmVzcG9uc2UuIE5vIHByZS10cmlnZ2VyIGRh'
    b'dGEuUQCBAFARgwX/CFARgwf/IFAkgFAUlENvbmZpZ1sweDFmZjUwXSA9PSAwQENAslAFlk'
    b'FjY2VsZXJhdGlvbiBUaHJlc2hvbGRQAYME/1BRAYIgAFIDiD9EABQAFAAUUSOIQEQAAAAA'
    b'AABRE4BQFfJMb3cgcG93ZXIgdHJpZ2dlci4gVGhlIG1pbmltdW0gYWNjZWxlcmF0aW9uIC'
    b'hwb3NpdGl2ZSBvciBuZWdhdGl2ZSkgdG8gdHJpZ2dlciBhIHJlY29yZGluZy4gTXVzdCBi'
    b'ZSBncmVhdGVyIHRoYW4gMC5AJ8ZQAYMF/1BRAYEHQQeRUAWOWCBBeGlzIFRyaWdnZXJBB5'
    b'FQBY5ZIEF4aXMgVHJpZ2dlckEHkVAFjlogQXhpcyBUcmlnZ2VyQA+AQE+AQChH5FAFjE1l'
    b'YXN1cmVtZW50c0AIQlxQBZkyMDAwZyBBY2NlbGVyYXRpb24gKENoIDgpUCSAQCdAm1EBgQ'
    b'9QAYMB/whQFaBFbmFibGUvRGlzYWJsZSBhY2NlbGVyYXRpb24gYXhlc0EHmFAFkUVuYWJs'
    b'ZSBYIChDaCA4LjApUQGBAEEHmFAFkUVuYWJsZSBZIChDaCA4LjEpUQGBAUEHmFAFkUVuYW'
    b'JsZSBaIChDaCA4LjIpUQGBAkEHmlAFk0VuYWJsZSBNaWMgKENoIDguMylRAYEDQBFAmlAF'
    b'i1NhbXBsZSBSYXRlUAGDAv8IUBXYU2V0IG1haW4gYWNjZWxlcmF0aW9uIHNhbXBsZSByYX'
    b'RlIGZyb20gMTAgdG8gMjAwMDAgSHouCkhpZ2hlciByYXRlIHJlZHVjZXMgYmF0dGVyeSBs'
    b'aWZlLlAUlUNvbmZpZ1sweDAxRkYwOF0gPT0gMFEBghOIUCWCSHpREYEKUSGCTiBAEUD8UA'
    b'WjT3ZlcnJpZGUgQW50aWFsaWFzaW5nIEZpbHRlciBDdXRvZmZQAYMI/whRAYID6FAlgkh6'
    b'USGCYahQFUClRGVmYXVsdCwgd2hlbiBub3QgY2hlY2tlZCwgb2Ygb25lLWZpZnRoIHNhbX'
    b'BsZSBmcmVxdWVuY3kuIEN1dC1vZmYgZnJlcXVlbmN5IGhhcyAyOSUgYXR0ZW51YXRpb24u'
    b'CjV0aCBvcmRlciBCdXR0ZXJ3b3J0aC4gU29tZSBhdHRlbnVhdGlvbiBhdCA2MCUgb2YgY3'
    b'V0LW9mZiBmcmVxdWVuY3kuUBSVQ29uZmlnWzB4MDFGRjA4XSA9PSAwQAhBHFAFmzQwZyBE'
    b'QyBBY2NlbGVyYXRpb24gKENoIDgwKUAnn1ABgwH/UFEBgQFBB5JQBY9FbmFibGUgQWxsIE'
    b'F4ZXNAF0DYUAWLU2FtcGxlIFJhdGVQAYMC/1BRAYIB9FAlgkh6UBXeTG93IHBhc3MgZmls'
    b'dGVyIGlzIHNldCB0byAyNSUgb2YgZGF0YSByYXRlLCBzbyBhIGRhdGEgcmF0ZSBvZiAyMD'
    b'AwSHogaGFzIGEgTFAgZmlsdGVyIGF0IDUwMCBIelAUk25vdCBDb25maWdbMHgxZmY1MF1B'
    b'B4VRAYIPoEEHhVEBggfQQQeFUQGCA+hBB4VRAYIB9EEHhFEBgfpBB4RRAYF9QQeEUQGBP0'
    b'EHhFEBgSBBB4RRAYEQQAhBMFAFqENvbnRyb2wgUGFkIFRlbXBlcmF0dXJlL1ByZXNzdXJl'
    b'IChDaCA1OSlAJ0CbUQGBA1ABgwH/O1AVpUVuYWJsZS9EaXNhYmxlIHNlbnNvcnMgb24gY2'
    b'9udHJvbCBwYWRBB5xQBZlFbmFibGUgUHJlc3N1cmUgKENoIDU5LjApQQefUAWcRW5hYmxl'
    b'IFRlbXBlcmF0dXJlIChDaCA1OS4xKUEHpVAFokVuYWJsZSBSZWxhdGl2ZSBIdW1pZGl0eS'
    b'AoQ2ggNTkuMilAEeNQBYtTYW1wbGUgUmF0ZVABgwL/O1AUlENvbmZpZ1sweDFmZjNCXSA9'
    b'PSAwUBWkU2V0IHNhbXBsZSBmcmVxdWVuY3kgZnJvbSAxIHRvIDEwIEh6UQGBClAlgkh6UR'
    b'GBAVEhgQpACEHNUAWZSW5lcnRpYWwgTWVhc3VyZW1lbnQgVW5pdEAHQJZQBZBBY3F1aXNp'
    b'dGlvbiBNb2RlUAGDAf8rUCWBIFEBgRBBB4pQBYNPZmZRAYEAQQeoUAWhQWJzb2x1dGUgT3'
    b'JpZW50YXRpb24gKFF1YXRlcm5pb24pUQGBCEEHqFAFoVJlbGF0aXZlIE9yaWVudGF0aW9u'
    b'IChRdWF0ZXJuaW9uKVEBgRBBB49QBYhSb3RhdGlvblEBgQJAAUCGUAWVT3JpZW50YXRpb2'
    b'4gRGF0YSBSYXRlUAGDAggrUQGBZFAlgkh6URGBAVEhgchQFb1TYW1wbGUgcmF0ZSBmb3Ig'
    b'ZGlyZWN0aW9uYWwgZGF0YSBmcm9tIDEgdG8gMjAwIEh6LiBDaGFubmVsIDY1UBSUQ29uZm'
    b'lnWzB4MDFGRjJCXSA8IDhAAUCJUAWSUm90YXRpb24gRGF0YSBSYXRlUAGDAgIrUQGBZFAl'
    b'gkh6URGBAVEhgchQFb5TZXQgc2FtcGxlIHJhdGUgZm9yIHJvdGF0aW9uIGRhdGEgZnJvbS'
    b'AxIHRvIDIwMCBIei4gQ2hhbm5lbCA0N1AUmUNvbmZpZ1sweDAxRkYyQl0gJiAyID09IDBA'
    b'CECQUAWgQ29udHJvbCBQYWQgTGlnaHQgU2Vuc29yIChDaCA3NilAJ+pQAYMB/0xQFb5Fbm'
    b'FibGUvRGlzYWJsZSBsaWdodCBzZW5zb3IgYXQgNCBIeiAtIE5PVEU6IERJU0FCTEVEIEZP'
    b'UiBBTFBIQUEHoFAFnUVuYWJsZSBMaWdodCBTZW5zb3IgKENoIDc2LjApQAhAslAFk0JNRz'
    b'I1MCBHeXJvIChDaCA4NClAJ59QAYMB/1RRAYEAQQeSUAWPRW5hYmxlIEFsbCBBeGVzQBf3'
    b'UAWLU2FtcGxlIFJhdGVQAYMC/1RRAYIBkFAlgkh6UBSTbm90IENvbmZpZ1sweDFmZjU0XU'
    b'EHhVEBggyAQQeFUQGCBkBBB4VRAYIDIEEHhVEBggGQQQeEUQGByEEHhFEBgWRBB4RRAYEy'
    b'QQeEUQGBGUEHhFEBgQxAD4BAT4BKCIBKKIBKSIA='
)
