"""
Default ConfigUI for LOG-0004-02kG-DC data recorders 
"""

from base64 import b64decode

DEFAULT_CONFIG_UI = b64decode(
    b'd3dVDkAoRYFQBYdHZW5lcmFsQAXzUAWLRGV2aWNlIE5hbWVQAYMI/39RJIFAUBXYQSBjdX'
    b'N0b20gbmFtZSBmb3IgdGhlIHJlY29yZGVyLiBOb3QgdGhlIHNhbWUgYXMgdGhlIHZvbHVt'
    b'ZSBsYWJlbC4gNjQgY2hhcmFjdGVycyBtYXhpbXVtLkAF81AFjERldmljZSBOb3Rlc1ABgw'
    b'n/f1EkggEAUBXSQ3VzdG9tIG5vdGVzIGFib3V0IHRoZSByZWNvcmRlciAocG9zaXRpb24s'
    b'IHVzZXIgSUQsIGV0Yy4pLiAyNTYgY2hhcmFjdGVycyBtYXhpbXVtLlE0gQNABfpQBZNSZW'
    b'NvcmRpbmcgRGlyZWN0b3J5UAGDFP9/UQSGUkVDT1JEUSSBCFAUk0NvbmZpZ1sweDE2RkY3'
    b'Rl09PTBQFbhEaXJlY3RvcnkgZm9yIHNlcmlhbGl6ZWQgcmVjb3JkaW5ncy4gOCBjaGFyYW'
    b'N0ZXIgbWF4aW11bUAFQKJQBZVSZWNvcmRpbmcgRmlsZSBQcmVmaXhQAYMV/39RJIEIUBXn'
    b'UHJlZml4IGZvciBzZXJpYWxpemVkIHJlY29yZGluZyBuYW1lcy4gSWYgYmxhbmssIGRldm'
    b'ljZSBzZXJpYWwgbnVtYmVyIHdpbGwgYmUgdXNlZC4gOCBjaGFyYWN0ZXIgbWF4aW11bVAU'
    b'k0NvbmZpZ1sweDE2RkY3Rl09PTBAB0E8UAWPRmlsZSBOYW1lIFN0eWxlUAGDFv9/UQGBAF'
    b'AVQPxUaW1lLUJhc2VkIGZpbGUgbmFtZXMgdXNlIGEgZGlyZWN0b3J5IGJhc2VkIG9uIHRo'
    b'ZSBkYXRlLCBhbmQgZmlsZSBuYW1lIGJhc2VkIG9uIHRoZSBzZWNvbmRzIHNpbmNlIG1pZG'
    b'5pZ2h0LgpTZXJpYWxpemVkIGZpbGUgbmFtZXMgdXNlIHRoZSBzcGVjaWZpZWQgZGlyZWN0'
    b'b3J5IGFuZCBmaWxlIG5hbWUgcHJlZml4LCBmb2xsb3dlZCBieSBhIG51bWJlci4gCk51bW'
    b'JlciBpcyByZXNldCB3aGVuIGRpcmVjdG9yeSBvciBwcmVmaXggY2hhbmdlcy5BB41QBYpU'
    b'aW1lIEJhc2VkQQeNUAWKU2VyaWFsaXplZEAHQJlQBYtCdXR0b24gTW9kZVABgxD/f1EBgQ'
    b'BQFb9PbmUgU2Vjb25kIFByZXNzIHdpbGwgZGlzYWJsZSAzLXNlY29uZCBwcmVzcyBmb3Ig'
    b'YmF0dGVyeSBjaGVjay5BB5dQBZRJbW1lZGlhdGUgU3RhcnQvU3RvcEEHolAFn09uZSBTZW'
    b'NvbmQgUHJlc3MgZm9yIFN0YXJ0L1N0b3BAF0EUUAWOUGx1Zy1JbiBBY3Rpb25QAYMK/39R'
    b'AYEBUBWtU2V0IGFjdGlvbiBmb3IgZGV2aWNlIHdoZW4gcGx1Z2dlZCBpbiB0byBVU0IuQQ'
    b'e1UAWySW1tZWRpYXRlbHkgc3RvcCByZWNvcmRpbmcgYW5kIGFwcGVhciBhcyBVU0IgZHJp'
    b'dmVBB7NQBbBDb21wbGV0ZSByZWNvcmRpbmcgYmVmb3JlIGFwcGVhcmluZyBhcyBVU0IgZH'
    b'JpdmVBB7BQBa1JZ25vcmU6IHN0b3AgcmVjb3JkaW5nIHdoZW4gYnV0dG9uIGlzIHByZXNz'
    b'ZWRBB6VQBaJTdGFydCByZWNvcmRpbmcgd2hlbiBVU0IgY29ubmVjdGVkQCPnUAGDC/9/UB'
    b'XeRW50ZXIgbG9jYWwgdGltZXpvbmUncyBvZmZzZXQgZnJvbSBVVEMgdGltZS4gSW1wYWN0'
    b'cyB0aW1lc3RhbXAgaW5mb3JtYXRpb24gb24gcmVjb3JkaW5nIGZpbGVzLkAvgEAPgEBPgE'
    b'AoSOJQBYhUcmlnZ2Vyc0AHQNpQBYxUcmlnZ2VyIE1vZGVQAYMS/39RAYEAUBVAj0RlbGF5'
    b'IFRoZW4gVHJpZ2dlcjogV2FpdCBzcGVjaWZpZWQgdGltZSwgdGhlbiB3YWl0IGZvciB0cm'
    b'lnZ2VyCkRlbGF5IE9yIFRyaWdnZXI6IEFjcXVpcmUgYWZ0ZXIgd2FpdCBvciBvbiB0cmln'
    b'Z2VyLiBCYXR0ZXJ5IGxpZmUgbWF5IGJlIHJlZHVjZWQuQQeVUAWSRGVsYXkgVGhlbiBUcm'
    b'lnZ2VyQQeTUAWQRGVsYXkgT3IgVHJpZ2dlckAy9FAFjVN0YXJ0IGF0IFRpbWVQAYMP/39Q'
    b'FdtXYWl0IHVudGlsIHNldCB0aW1lIGJlZm9yZSBldmFsdWF0aW5nIG90aGVyIHRyaWdnZX'
    b'IgY29uZGl0aW9ucywgaW5jbHVkaW5nIGEgcmVjb3JkaW5nIGRlbGF5QBGuUAWUUmVjb3Jk'
    b'aW5nIFRpbWUgTGltaXRQAYMN/39RIYT////wUCWHU2Vjb25kc0ARQJBQBZhSZWNvcmRpbm'
    b'cgRGVsYXkvSW50ZXJ2YWxQAYMM/39RAYEAUCWHU2Vjb25kc1EhgwFRgFAV2FRpbWUgYmVm'
    b'b3JlIHN0YXJ0aW5nIGEgcmVjb3JkaW5nLCBhbmQgdGltZSBiZXR3ZWVuIHJlY29yZGluZ3'
    b'MgaWYgJ1JldHJpZ2dlcicgaXMgY2hlY2tlZC5AEa9QBZlSZWNvcmRpbmcgRmlsZSBTaXpl'
    b'IExpbWl0UAGDEf9/USGE////8FAlg0tpQkAQQJdQBYlSZXRyaWdnZXJQAYMO/39QFLBDb2'
    b'5maWdbMHhERkY3Rl09PW51bGwgYW5kIENvbmZpZ1sweDExRkY3Rl09PW51bGxQFc9XaGVu'
    b'IHNldCwgU2xhbSBTdGljayB3aWxsIHJlLWFybSBhZnRlciByZWNvcmRpbmcgdGltZSBvci'
    b'BzaXplIGxpbWl0IGlzIHJlYWNoZWQuQBBAqFAFnldhaXQgZm9yIEFsbCBTZW5zb3IgQ29u'
    b'ZGl0aW9uc1ABgxP/f1AV/ldoZW4gc2V0LCByZWNvcmRpbmcgd2lsbCBvbmx5IHN0YXJ0IH'
    b'doZW4gYWxsIHRyaWdnZXJzIGFyZSBtZXQsIG90aGVyd2lzZSByZWNvcmRpbmcgd2lsbCBz'
    b'dGFydCB3aGVuIGFueSBzZW5zb3IgY29uZGl0aW9uIGlzIG1ldEAYQO5QBZBQcmVzc3VyZS'
    b'BUcmlnZ2VyUAGDBQAkUQCBAECC5VAFlVByZXNzdXJlIFRyaWdnZXIsIExvd1ABgwMAJFEB'
    b'gwFfkFAlglBhUSGDAdTAUBWzU2V0IHRvIHN0YXJ0IHNhbXBsaW5nIHdoZW4gb3V0c2lkZS'
    b'BwcmVzc3VyZSB3aW5kb3cuQILmUAWWUHJlc3N1cmUgVHJpZ2dlciwgSGlnaFABgwQAJFEB'
    b'gwGtsFAlglBhUSGDAdTAUBWzU2V0IHRvIHN0YXJ0IHNhbXBsaW5nIHdoZW4gb3V0c2lkZS'
    b'BwcmVzc3VyZSB3aW5kb3cuQBhA+1AFk1RlbXBlcmF0dXJlIFRyaWdnZXJQAYMFASRRAIEA'
    b'QGPqUAWYVGVtcGVyYXR1cmUgVHJpZ2dlciwgTG93UAGDAwEkUQKB9lAlgUNREoHYUSKBUF'
    b'AVtlNldCB0byBzdGFydCBzYW1wbGluZyB3aGVuIG91dHNpZGUgdGVtcGVyYXR1cmUgd2lu'
    b'ZG93LkBj61AFmVRlbXBlcmF0dXJlIFRyaWdnZXIsIEhpZ2hQAYMEASRRAoEjUCWBQ1ESgd'
    b'hRIoFQUBW2U2V0IHRvIHN0YXJ0IHNhbXBsaW5nIHdoZW4gb3V0c2lkZSB0ZW1wZXJhdHVy'
    b'ZSB3aW5kb3cuQBhBqVAFnEFjY2VsZXJhdGlvbiBUcmlnZ2VyICgyMDAwZylQAYMF/whQEY'
    b'MH/yBRAIEAUCSAUBSVQ29uZmlnWzB4MDFGRjA4XSA9PSAwQENAq1AFmUFjY2VsZXJhdGlv'
    b'biBUcmlnZ2VyLCBMb3dQAYMD/whRAoL5mlETiMCfQAAAAAAAUSOIQJ9AAAAAAABQFeBIaW'
    b'doIHBvd2VyIHRyaWdnZXIgd2l0aCBwcmUtdHJpZ2dlciBkYXRhLiBOb3QgcmVjb21tZW5k'
    b'ZWQgZm9yIGxvbmcgd2FpdHMgd2l0aG91dCBleHRlcm5hbCBwb3dlci5SA4g/r0AfQB9ILk'
    b'BDQKxQBZpBY2NlbGVyYXRpb24gVHJpZ2dlciwgSGlnaFABgwT/CFECggZmUROIwJ9AAAAA'
    b'AABRI4hAn0AAAAAAAFAV4EhpZ2ggcG93ZXIgdHJpZ2dlciB3aXRoIHByZS10cmlnZ2VyIG'
    b'RhdGEuIE5vdCByZWNvbW1lbmRlZCBmb3IgbG9uZyB3YWl0cyB3aXRob3V0IGV4dGVybmFs'
    b'IHBvd2VyLlIDiD+vQB9AH0guQBhBnFAFmkFjY2VsZXJhdGlvbiBUcmlnZ2VyICgxNmcpUA'
    b'GDB/8gUBXUTG93IHBvd2VyIHRyaWdnZXIgdXNpbmcgZGlnaXRhbCBhY2NlbGVyb21ldGVy'
    b'IHdpdGggREMgcmVzcG9uc2UuIE5vIHByZS10cmlnZ2VyIGRhdGEuUQCBAFARgwX/CFAkgF'
    b'AUlENvbmZpZ1sweDFmZjIwXSA9PSAwQENAsVAFlkFjY2VsZXJhdGlvbiBUaHJlc2hvbGRQ'
    b'AYME/yBRAYFQUgOIP7AQEBAQEBBRI4hAMAAAAAAAAFETgFAV8kxvdyBwb3dlciB0cmlnZ2'
    b'VyLiBUaGUgbWluaW11bSBhY2NlbGVyYXRpb24gKHBvc2l0aXZlIG9yIG5lZ2F0aXZlKSB0'
    b'byB0cmlnZ2VyIGEgcmVjb3JkaW5nLiBNdXN0IGJlIGdyZWF0ZXIgdGhhbiAwLkAnxlABgw'
    b'X/IFEBgQdBB5FQBY5YIEF4aXMgVHJpZ2dlckEHkVAFjlkgQXhpcyBUcmlnZ2VyQQeRUAWO'
    b'WiBBeGlzIFRyaWdnZXJAD4BAT4BAKEaWUAWMTWVhc3VyZW1lbnRzQAhCQlAFmTIwMDBnIE'
    b'FjY2VsZXJhdGlvbiAoQ2ggOClQJIBAJ0CBUQGBB1ABgwH/CFAVoEVuYWJsZS9EaXNhYmxl'
    b'IGFjY2VsZXJhdGlvbiBheGVzQQeZUAWWRW5hYmxlIFggQXhpcyAoQ2ggOC4wKUEHmVAFlk'
    b'VuYWJsZSBZIEF4aXMgKENoIDguMSlBB5lQBZZFbmFibGUgWiBBeGlzIChDaCA4LjIpQBFA'
    b'mlAFi1NhbXBsZSBSYXRlUAGDAv8IUBXYU2V0IG1haW4gYWNjZWxlcmF0aW9uIHNhbXBsZS'
    b'ByYXRlIGZyb20gMTAgdG8gMjAwMDAgSHouCkhpZ2hlciByYXRlIHJlZHVjZXMgYmF0dGVy'
    b'eSBsaWZlLlAUlUNvbmZpZ1sweDAxRkYwOF0gPT0gMFEBghOIUCWCSHpREYEKUSGCTiBAEU'
    b'D8UAWjT3ZlcnJpZGUgQW50aWFsaWFzaW5nIEZpbHRlciBDdXRvZmZQAYMI/whRAYID6FAl'
    b'gkh6USGCE4hQFUClRGVmYXVsdCwgd2hlbiBub3QgY2hlY2tlZCwgb2Ygb25lLWZpZnRoIH'
    b'NhbXBsZSBmcmVxdWVuY3kuIEN1dC1vZmYgZnJlcXVlbmN5IGhhcyAyOSUgYXR0ZW51YXRp'
    b'b24uCjV0aCBvcmRlciBCdXR0ZXJ3b3J0aC4gU29tZSBhdHRlbnVhdGlvbiBhdCA2MCUgb2'
    b'YgY3V0LW9mZiBmcmVxdWVuY3kuUBSVQ29uZmlnWzB4MDFGRjA4XSA9PSAwQAhAulAFmzE2'
    b'ZyBEQyBBY2NlbGVyYXRpb24gKENoIDMyKUAnn1ABgwH/IFEBgQFBB5JQBY9FbmFibGUgQW'
    b'xsIEF4ZXNAF/dQBYtTYW1wbGUgUmF0ZVABgwL/IFEBggGQUCWCSHpQFJNub3QgQ29uZmln'
    b'WzB4MWZmMjBdQQeFUQGCDIBBB4VRAYIGQEEHhVEBggMgQQeFUQGCAZBBB4RRAYHIQQeEUQ'
    b'GBZEEHhFEBgTJBB4RRAYEZQQeEUQGBDEAIQTBQBahDb250cm9sIFBhZCBUZW1wZXJhdHVy'
    b'ZS9QcmVzc3VyZSAoQ2ggNTkpQCdAm1EBgQNQAYMB/ztQFaVFbmFibGUvRGlzYWJsZSBzZW'
    b'5zb3JzIG9uIGNvbnRyb2wgcGFkQQecUAWZRW5hYmxlIFByZXNzdXJlIChDaCA1OS4wKUEH'
    b'n1AFnEVuYWJsZSBUZW1wZXJhdHVyZSAoQ2ggNTkuMSlBB6VQBaJFbmFibGUgUmVsYXRpdm'
    b'UgSHVtaWRpdHkgKENoIDU5LjIpQBHjUAWLU2FtcGxlIFJhdGVQAYMC/ztQFJRDb25maWdb'
    b'MHgxZmYzQl0gPT0gMFAVpFNldCBzYW1wbGUgZnJlcXVlbmN5IGZyb20gMSB0byAxMCBIel'
    b'EBgQpQJYJIelERgQFRIYEKQAhByVAFmUluZXJ0aWFsIE1lYXN1cmVtZW50IFVuaXRAB0CS'
    b'UAWQQWNxdWlzaXRpb24gTW9kZVABgwH/K1EBgRBBB4pQBYNPZmZRAYEAQQeoUAWhQWJzb2'
    b'x1dGUgT3JpZW50YXRpb24gKFF1YXRlcm5pb24pUQGBCEEHqFAFoVJlbGF0aXZlIE9yaWVu'
    b'dGF0aW9uIChRdWF0ZXJuaW9uKVEBgRBBB49QBYhSb3RhdGlvblEBgQJAAUCGUAWVT3JpZW'
    b'50YXRpb24gRGF0YSBSYXRlUAGDAggrUQGBZFAlgkh6URGBAVEhgchQFb1TYW1wbGUgcmF0'
    b'ZSBmb3IgZGlyZWN0aW9uYWwgZGF0YSBmcm9tIDEgdG8gMjAwIEh6LiBDaGFubmVsIDY1UB'
    b'SUQ29uZmlnWzB4MDFGRjJCXSA8IDhAAUCJUAWSUm90YXRpb24gRGF0YSBSYXRlUAGDAgIr'
    b'UQGBZFAlgkh6URGBAVEhgchQFb5TZXQgc2FtcGxlIHJhdGUgZm9yIHJvdGF0aW9uIGRhdG'
    b'EgZnJvbSAxIHRvIDIwMCBIei4gQ2hhbm5lbCA0N1AUmUNvbmZpZ1sweDAxRkYyQl0gJiAy'
    b'ID09IDBACPlQBaBDb250cm9sIFBhZCBMaWdodCBTZW5zb3IgKENoIDc2KUAn01EBgQFQAY'
    b'MB/0xQFaNFbmFibGUvRGlzYWJsZSBsaWdodCBzZW5zb3IgYXQgNCBIekEHoFAFnUVuYWJs'
    b'ZSBMaWdodCBTZW5zb3IgKENoIDc2LjApQA+AQE+ASgiASiiASkiA'
)
