"""
Default ConfigUI for W8-D40 data recorders 
"""

from base64 import b64decode

DEFAULT_CONFIG_UI = b64decode(
    b'd3dYR0AoSDxQBYdHZW5lcmFsQAXzUAWLRGV2aWNlIE5hbWVQAYMI/39RJIFAUBXYQSBjdX'
    b'N0b20gbmFtZSBmb3IgdGhlIHJlY29yZGVyLiBOb3QgdGhlIHNhbWUgYXMgdGhlIHZvbHVt'
    b'ZSBsYWJlbC4gNjQgY2hhcmFjdGVycyBtYXhpbXVtLkAF81AFjERldmljZSBOb3Rlc1ABgw'
    b'n/f1EkggEAUBXSQ3VzdG9tIG5vdGVzIGFib3V0IHRoZSByZWNvcmRlciAocG9zaXRpb24s'
    b'IHVzZXIgSUQsIGV0Yy4pLiAyNTYgY2hhcmFjdGVycyBtYXhpbXVtLlE0gQNABUCZUAWVQ3'
    b'VzdG9tIFJlY29yZGluZyBUYWdzUAGDF/9/UQSAUSSBQFAV8UtleXdvcmRzIGZvciBvcmdh'
    b'bml6aW5nIGFuZCBpZGVudGlmeWluZyByZWNvcmRpbmdzLCBzZXBhcmF0ZWQgYnkgY29tbW'
    b'Egb3Igc3BhY2UuIExpbWl0IGlzIDIwIHRhZ3MsIDY0IGNoYXJhY3RlcnMuQAX7UAWTUmVj'
    b'b3JkaW5nIERpcmVjdG9yeVABgxT/f1EEhlJFQ09SRFEkgRBQFJNDb25maWdbMHgxNkZGN0'
    b'ZdPT0wUBW5RGlyZWN0b3J5IGZvciBzZXJpYWxpemVkIHJlY29yZGluZ3MuIDE2IGNoYXJh'
    b'Y3RlciBtYXhpbXVtQAVAo1AFlVJlY29yZGluZyBGaWxlIFByZWZpeFABgxX/f1EkgRBQFe'
    b'hQcmVmaXggZm9yIHNlcmlhbGl6ZWQgcmVjb3JkaW5nIG5hbWVzLiBJZiBibGFuaywgZGV2'
    b'aWNlIHNlcmlhbCBudW1iZXIgd2lsbCBiZSB1c2VkLiAxNiBjaGFyYWN0ZXIgbWF4aW11bV'
    b'AUk0NvbmZpZ1sweDE2RkY3Rl09PTBAB0E8UAWPRmlsZSBOYW1lIFN0eWxlUAGDFv9/UQGB'
    b'AVAVQPxUaW1lLUJhc2VkIGZpbGUgbmFtZXMgdXNlIGEgZGlyZWN0b3J5IGJhc2VkIG9uIH'
    b'RoZSBkYXRlLCBhbmQgZmlsZSBuYW1lIGJhc2VkIG9uIHRoZSBzZWNvbmRzIHNpbmNlIG1p'
    b'ZG5pZ2h0LgpTZXJpYWxpemVkIGZpbGUgbmFtZXMgdXNlIHRoZSBzcGVjaWZpZWQgZGlyZW'
    b'N0b3J5IGFuZCBmaWxlIG5hbWUgcHJlZml4LCBmb2xsb3dlZCBieSBhIG51bWJlci4gCk51'
    b'bWJlciBpcyByZXNldCB3aGVuIGRpcmVjdG9yeSBvciBwcmVmaXggY2hhbmdlcy5BB41QBY'
    b'pUaW1lIEJhc2VkQQeNUAWKU2VyaWFsaXplZEAHQKlQBYtCdXR0b24gTW9kZVABgxD/f1EB'
    b'gQBQFb9PbmUgU2Vjb25kIFByZXNzIHdpbGwgZGlzYWJsZSAzLXNlY29uZCBwcmVzcyBmb3'
    b'IgYmF0dGVyeSBjaGVjay5BB5dQBZRJbW1lZGlhdGUgU3RhcnQvU3RvcEEHolAFn09uZSBT'
    b'ZWNvbmQgUHJlc3MgZm9yIFN0YXJ0L1N0b3BBB41QBYpTdGFydC1Pbmx5QBdBFFAFjlBsdW'
    b'ctSW4gQWN0aW9uUAGDCv9/UQGBAVAVrVNldCBhY3Rpb24gZm9yIGRldmljZSB3aGVuIHBs'
    b'dWdnZWQgaW4gdG8gVVNCLkEHtVAFskltbWVkaWF0ZWx5IHN0b3AgcmVjb3JkaW5nIGFuZC'
    b'BhcHBlYXIgYXMgVVNCIGRyaXZlQQezUAWwQ29tcGxldGUgcmVjb3JkaW5nIGJlZm9yZSBh'
    b'cHBlYXJpbmcgYXMgVVNCIGRyaXZlQQewUAWtSWdub3JlOiBzdG9wIHJlY29yZGluZyB3aG'
    b'VuIGJ1dHRvbiBpcyBwcmVzc2VkQQelUAWiU3RhcnQgcmVjb3JkaW5nIHdoZW4gVVNCIGNv'
    b'bm5lY3RlZEAj51ABgwv/f1AV3kVudGVyIGxvY2FsIHRpbWV6b25lJ3Mgb2Zmc2V0IGZyb2'
    b'0gVVRDIHRpbWUuIEltcGFjdHMgdGltZXN0YW1wIGluZm9ybWF0aW9uIG9uIHJlY29yZGlu'
    b'ZyBmaWxlcy5AL4BAGEIIUAWMRW5hYmxlIFdpLUZpUAGDGP9/UQGBAUAn7FABgxn/f1EBgQ'
    b'FBB6lQBaZVcGxvYWQgcmVjb3JkaW5nIHRvIGNsb3VkIGFmdGVyIGZpbmlzaFAVs1NlbGVj'
    b'dCB0byB1cGxvYWQgZWFjaCBmaWxlIHdoZW4gcmVjb3JkaW5nIGNvbXBsZXRlc0AnQLZQAY'
    b'Ma/39RAYEAQQejUAWgRGVsZXRlIGZyb20gc3RvcmFnZSBhZnRlciB1cGxvYWRQFUCCUmVj'
    b'b3JkaW5nIGZpbGUgd2lsbCBiZSBkZWxldGVkIGFmdGVyIGEgc3VjY2Vzc2Z1bCB1cGxvYW'
    b'QsIGFuZCBtb3ZlZCB0byBhIHN1YmZvbGRlciBsYWJlbGVkICdmYWlsZWQnIGluIHRoZSBj'
    b'YXNlIG9mIGEgZmFpbGVkIHVwbG9hZEAnQMJQAYMd/39RAYEAQQepUAWmS2VlcCB0aGUgV2'
    b'ktRmkgbW9kdWxlIG9uIGFuZCBjb25uZWN0ZWRQFUCISWYgY2hlY2tlZCwgdGhlIFdpLUZp'
    b'IG1vZHVsZSB3aWxsIHN0YXkgb24gYW5kIGNvbm5lY3RlZC4gIEFsbG93cyBmb3IgZmFzdG'
    b'VyIHVwbG9hZCB0aW1lcyB3aXRoIHRoZSBleHBlbnNlIG9mIGluY3JlYXNlZCBwb3dlciBj'
    b'b25zdW1wdGlvbkAPgEBPgEAoR3RQBYhUcmlnZ2Vyc0AHQNpQBYxUcmlnZ2VyIE1vZGVQAY'
    b'MS/39RAYEAUBVAj0RlbGF5IFRoZW4gVHJpZ2dlcjogV2FpdCBzcGVjaWZpZWQgdGltZSwg'
    b'dGhlbiB3YWl0IGZvciB0cmlnZ2VyCkRlbGF5IE9yIFRyaWdnZXI6IEFjcXVpcmUgYWZ0ZX'
    b'Igd2FpdCBvciBvbiB0cmlnZ2VyLiBCYXR0ZXJ5IGxpZmUgbWF5IGJlIHJlZHVjZWQuQQeV'
    b'UAWSRGVsYXkgVGhlbiBUcmlnZ2VyQQeTUAWQRGVsYXkgT3IgVHJpZ2dlckAy9FAFjVN0YX'
    b'J0IGF0IFRpbWVQAYMP/39QFdtXYWl0IHVudGlsIHNldCB0aW1lIGJlZm9yZSBldmFsdWF0'
    b'aW5nIG90aGVyIHRyaWdnZXIgY29uZGl0aW9ucywgaW5jbHVkaW5nIGEgcmVjb3JkaW5nIG'
    b'RlbGF5QBGuUAWUUmVjb3JkaW5nIFRpbWUgTGltaXRQAYMN/39RIYT////wUCWHU2Vjb25k'
    b'c0ARQJBQBZhSZWNvcmRpbmcgRGVsYXkvSW50ZXJ2YWxQAYMM/39RAYEAUCWHU2Vjb25kc1'
    b'EhgwFRgFAV2FRpbWUgYmVmb3JlIHN0YXJ0aW5nIGEgcmVjb3JkaW5nLCBhbmQgdGltZSBi'
    b'ZXR3ZWVuIHJlY29yZGluZ3MgaWYgJ1JldHJpZ2dlcicgaXMgY2hlY2tlZC5AEa9QBZlSZW'
    b'NvcmRpbmcgRmlsZSBTaXplIExpbWl0UAGDEf9/USGE////8FAlg0tpQkAQQJdQBYlSZXRy'
    b'aWdnZXJQAYMO/39QFLBDb25maWdbMHhERkY3Rl09PW51bGwgYW5kIENvbmZpZ1sweDExRk'
    b'Y3Rl09PW51bGxQFc9XaGVuIHNldCwgU2xhbSBTdGljayB3aWxsIHJlLWFybSBhZnRlciBy'
    b'ZWNvcmRpbmcgdGltZSBvciBzaXplIGxpbWl0IGlzIHJlYWNoZWQuQBBAqFAFnldhaXQgZm'
    b'9yIEFsbCBTZW5zb3IgQ29uZGl0aW9uc1ABgxP/f1AV/ldoZW4gc2V0LCByZWNvcmRpbmcg'
    b'd2lsbCBvbmx5IHN0YXJ0IHdoZW4gYWxsIHRyaWdnZXJzIGFyZSBtZXQsIG90aGVyd2lzZS'
    b'ByZWNvcmRpbmcgd2lsbCBzdGFydCB3aGVuIGFueSBzZW5zb3IgY29uZGl0aW9uIGlzIG1l'
    b'dEAYQQpQBZBQcmVzc3VyZSBUcmlnZ2VyUAGDBQAkUQCBAFAUmUNvbmZpZ1sweDAxRkYyNF'
    b'0gJiAxID09IDBAguVQBZVQcmVzc3VyZSBUcmlnZ2VyLCBMb3dQAYMDACRRAYMBX5BQJYJQ'
    b'YVEhgwHUwFAVs1NldCB0byBzdGFydCBzYW1wbGluZyB3aGVuIG91dHNpZGUgcHJlc3N1cm'
    b'Ugd2luZG93LkCC5lAFllByZXNzdXJlIFRyaWdnZXIsIEhpZ2hQAYMEACRRAYMBrbBQJYJQ'
    b'YVEhgwHUwFAVs1NldCB0byBzdGFydCBzYW1wbGluZyB3aGVuIG91dHNpZGUgcHJlc3N1cm'
    b'Ugd2luZG93LkAYQRdQBZNUZW1wZXJhdHVyZSBUcmlnZ2VyUAGDBQEkUQCBAFAUmUNvbmZp'
    b'Z1sweDAxRkYyNF0gJiAyID09IDBAY+pQBZhUZW1wZXJhdHVyZSBUcmlnZ2VyLCBMb3dQAY'
    b'MDASRRAoH2UCWBQ1ESgdhRIoFQUBW2U2V0IHRvIHN0YXJ0IHNhbXBsaW5nIHdoZW4gb3V0'
    b'c2lkZSB0ZW1wZXJhdHVyZSB3aW5kb3cuQGPrUAWZVGVtcGVyYXR1cmUgVHJpZ2dlciwgSG'
    b'lnaFABgwQBJFECgSNQJYFDURKB2FEigVBQFbZTZXQgdG8gc3RhcnQgc2FtcGxpbmcgd2hl'
    b'biBvdXRzaWRlIHRlbXBlcmF0dXJlIHdpbmRvdy5AGEGjUAWaQWNjZWxlcmF0aW9uIFRyaW'
    b'dnZXIgKDQwZylQAYMH/1BQFdRMb3cgcG93ZXIgdHJpZ2dlciB1c2luZyBkaWdpdGFsIGFj'
    b'Y2VsZXJvbWV0ZXIgd2l0aCBEQyByZXNwb25zZS4gTm8gcHJlLXRyaWdnZXIgZGF0YS5RAI'
    b'EAUBGDBf8IUBGDB/8gUCSAUBSUQ29uZmlnWzB4MWZmNTBdID09IDBAQ0CyUAWWQWNjZWxl'
    b'cmF0aW9uIFRocmVzaG9sZFABgwT/UFEBgiAAUgOIP0QAFAAUABRRI4hARAAAAAAAAFETgF'
    b'AV8kxvdyBwb3dlciB0cmlnZ2VyLiBUaGUgbWluaW11bSBhY2NlbGVyYXRpb24gKHBvc2l0'
    b'aXZlIG9yIG5lZ2F0aXZlKSB0byB0cmlnZ2VyIGEgcmVjb3JkaW5nLiBNdXN0IGJlIGdyZW'
    b'F0ZXIgdGhhbiAwLkAnxlABgwX/UFEBgQdBB5FQBY5YIEF4aXMgVHJpZ2dlckEHkVAFjlkg'
    b'QXhpcyBUcmlnZ2VyQQeRUAWOWiBBeGlzIFRyaWdnZXJAD4BAT4BAKEiCUAWMTWVhc3VyZW'
    b'1lbnRzQAhCBVAFlEFuYWxvZyBJbnB1dHMgKENoIDgpUCSAQCfKUQGBD1ABgwH/CFAVoEVu'
    b'YWJsZS9EaXNhYmxlIGFjY2VsZXJhdGlvbiBheGVzQQeaUAWTRW5hYmxlIE1pYyAoQ2ggOC'
    b'4zKVEBgQNAEUCaUAWLU2FtcGxlIFJhdGVQAYMC/whQFdhTZXQgbWFpbiBhY2NlbGVyYXRp'
    b'b24gc2FtcGxlIHJhdGUgZnJvbSAxMCB0byAyMDAwMCBIei4KSGlnaGVyIHJhdGUgcmVkdW'
    b'NlcyBiYXR0ZXJ5IGxpZmUuUBSVQ29uZmlnWzB4MDFGRjA4XSA9PSAwUQGCE4hQJYJIelER'
    b'gQpRIYJOIEARQPxQBaNPdmVycmlkZSBBbnRpYWxpYXNpbmcgRmlsdGVyIEN1dG9mZlABgw'
    b'j/CFEBggPoUCWCSHpRIYJhqFAVQKVEZWZhdWx0LCB3aGVuIG5vdCBjaGVja2VkLCBvZiBv'
    b'bmUtZmlmdGggc2FtcGxlIGZyZXF1ZW5jeS4gQ3V0LW9mZiBmcmVxdWVuY3kgaGFzIDI5JS'
    b'BhdHRlbnVhdGlvbi4KNXRoIG9yZGVyIEJ1dHRlcndvcnRoLiBTb21lIGF0dGVudWF0aW9u'
    b'IGF0IDYwJSBvZiBjdXQtb2ZmIGZyZXF1ZW5jeS5QFJVDb25maWdbMHgwMUZGMDhdID09ID'
    b'BACEEcUAWbNDBnIERDIEFjY2VsZXJhdGlvbiAoQ2ggODApQCefUAGDAf9QUQGBAUEHklAF'
    b'j0VuYWJsZSBBbGwgQXhlc0AXQNhQBYtTYW1wbGUgUmF0ZVABgwL/UFEBggH0UCWCSHpQFd'
    b'5Mb3cgcGFzcyBmaWx0ZXIgaXMgc2V0IHRvIDI1JSBvZiBkYXRhIHJhdGUsIHNvIGEgZGF0'
    b'YSByYXRlIG9mIDIwMDBIeiBoYXMgYSBMUCBmaWx0ZXIgYXQgNTAwIEh6UBSTbm90IENvbm'
    b'ZpZ1sweDFmZjUwXUEHhVEBgg+gQQeFUQGCB9BBB4VRAYID6EEHhVEBggH0QQeEUQGB+kEH'
    b'hFEBgX1BB4RRAYE/QQeEUQGBIEEHhFEBgRBACEEwUAWoQ29udHJvbCBQYWQgVGVtcGVyYX'
    b'R1cmUvUHJlc3N1cmUgKENoIDU5KUAnQJtRAYEDUAGDAf87UBWlRW5hYmxlL0Rpc2FibGUg'
    b'c2Vuc29ycyBvbiBjb250cm9sIHBhZEEHnFAFmUVuYWJsZSBQcmVzc3VyZSAoQ2ggNTkuMC'
    b'lBB59QBZxFbmFibGUgVGVtcGVyYXR1cmUgKENoIDU5LjEpQQelUAWiRW5hYmxlIFJlbGF0'
    b'aXZlIEh1bWlkaXR5IChDaCA1OS4yKUAR41AFi1NhbXBsZSBSYXRlUAGDAv87UBSUQ29uZm'
    b'lnWzB4MWZmM0JdID09IDBQFaRTZXQgc2FtcGxlIGZyZXF1ZW5jeSBmcm9tIDEgdG8gMTAg'
    b'SHpRAYEKUCWCSHpREYEBUSGBCkAIQc1QBZlJbmVydGlhbCBNZWFzdXJlbWVudCBVbml0QA'
    b'dAllAFkEFjcXVpc2l0aW9uIE1vZGVQAYMB/ytQJYEgUQGBEEEHilAFg09mZlEBgQBBB6hQ'
    b'BaFBYnNvbHV0ZSBPcmllbnRhdGlvbiAoUXVhdGVybmlvbilRAYEIQQeoUAWhUmVsYXRpdm'
    b'UgT3JpZW50YXRpb24gKFF1YXRlcm5pb24pUQGBEEEHj1AFiFJvdGF0aW9uUQGBAkABQIZQ'
    b'BZVPcmllbnRhdGlvbiBEYXRhIFJhdGVQAYMCCCtRAYFkUCWCSHpREYEBUSGByFAVvVNhbX'
    b'BsZSByYXRlIGZvciBkaXJlY3Rpb25hbCBkYXRhIGZyb20gMSB0byAyMDAgSHouIENoYW5u'
    b'ZWwgNjVQFJRDb25maWdbMHgwMUZGMkJdIDwgOEABQIlQBZJSb3RhdGlvbiBEYXRhIFJhdG'
    b'VQAYMCAitRAYFkUCWCSHpREYEBUSGByFAVvlNldCBzYW1wbGUgcmF0ZSBmb3Igcm90YXRp'
    b'b24gZGF0YSBmcm9tIDEgdG8gMjAwIEh6LiBDaGFubmVsIDQ3UBSZQ29uZmlnWzB4MDFGRj'
    b'JCXSAmIDIgPT0gMEAIQPFQBaVJbnRlcm5hbCBUZW1wZXJhdHVyZS9QcmVzc3VyZSAoQ2gg'
    b'MzYpQCdAxVEBgQNQAYMB/yRQFfdFbmFibGUvRGlzYWJsZSBzbG93ZXIgaW50ZXJuYWwgZW'
    b'52aXJvbm1lbnRhbCBzZW5zb3JzLiBOT1RFOiBUZW1wZXJhdHVyZSBpcyByZXF1aXJlZCBm'
    b'b3IgbWFpbiBhY2NlbGVyb21ldGVyIG1lYXN1cmVtZW50c0EHnFAFmUVuYWJsZSBQcmVzc3'
    b'VyZSAoQ2ggMzYuMClBB59QBZxFbmFibGUgVGVtcGVyYXR1cmUgKENoIDM2LjEpQAhAkFAF'
    b'oENvbnRyb2wgUGFkIExpZ2h0IFNlbnNvciAoQ2ggNzYpQCfqUAGDAf9MUBW+RW5hYmxlL0'
    b'Rpc2FibGUgbGlnaHQgc2Vuc29yIGF0IDQgSHogLSBOT1RFOiBESVNBQkxFRCBGT1IgQUxQ'
    b'SEFBB6BQBZ1FbmFibGUgTGlnaHQgU2Vuc29yIChDaCA3Ni4wKUAIQLJQBZNCTUcyNTAgR3'
    b'lybyAoQ2ggODQpQCefUAGDAf9UUQGBAEEHklAFj0VuYWJsZSBBbGwgQXhlc0AX91AFi1Nh'
    b'bXBsZSBSYXRlUAGDAv9UUQGCAZBQJYJIelAUk25vdCBDb25maWdbMHgxZmY1NF1BB4VRAY'
    b'IMgEEHhVEBggZAQQeFUQGCAyBBB4VRAYIBkEEHhFEBgchBB4RRAYFkQQeEUQGBMkEHhFEB'
    b'gRlBB4RRAYEMQA+AQE+ASgiASiiASkiA'
)
