"""
Default ConfigUI for S2-D40D200 data recorders 
"""

from base64 import b64decode

DEFAULT_CONFIG_UI = b64decode(
    b'd3dV4kAoRjBQBYdHZW5lcmFsQAXzUAWLRGV2aWNlIE5hbWVQAYMI/39RJIFAUBXYQSBjdX'
    b'N0b20gbmFtZSBmb3IgdGhlIHJlY29yZGVyLiBOb3QgdGhlIHNhbWUgYXMgdGhlIHZvbHVt'
    b'ZSBsYWJlbC4gNjQgY2hhcmFjdGVycyBtYXhpbXVtLkAF81AFjERldmljZSBOb3Rlc1ABgw'
    b'n/f1EkggEAUBXSQ3VzdG9tIG5vdGVzIGFib3V0IHRoZSByZWNvcmRlciAocG9zaXRpb24s'
    b'IHVzZXIgSUQsIGV0Yy4pLiAyNTYgY2hhcmFjdGVycyBtYXhpbXVtLlE0gQNABUCZUAWVQ3'
    b'VzdG9tIFJlY29yZGluZyBUYWdzUAGDF/9/UQSAUSSBQFAV8UtleXdvcmRzIGZvciBvcmdh'
    b'bml6aW5nIGFuZCBpZGVudGlmeWluZyByZWNvcmRpbmdzLCBzZXBhcmF0ZWQgYnkgY29tbW'
    b'Egb3Igc3BhY2UuIExpbWl0IGlzIDIwIHRhZ3MsIDY0IGNoYXJhY3RlcnMuQAX7UAWTUmVj'
    b'b3JkaW5nIERpcmVjdG9yeVABgxT/f1EEhlJFQ09SRFEkgRBQFJNDb25maWdbMHgxNkZGN0'
    b'ZdPT0wUBW5RGlyZWN0b3J5IGZvciBzZXJpYWxpemVkIHJlY29yZGluZ3MuIDE2IGNoYXJh'
    b'Y3RlciBtYXhpbXVtQAVAo1AFlVJlY29yZGluZyBGaWxlIFByZWZpeFABgxX/f1EkgRBQFe'
    b'hQcmVmaXggZm9yIHNlcmlhbGl6ZWQgcmVjb3JkaW5nIG5hbWVzLiBJZiBibGFuaywgZGV2'
    b'aWNlIHNlcmlhbCBudW1iZXIgd2lsbCBiZSB1c2VkLiAxNiBjaGFyYWN0ZXIgbWF4aW11bV'
    b'AUk0NvbmZpZ1sweDE2RkY3Rl09PTBAB0E8UAWPRmlsZSBOYW1lIFN0eWxlUAGDFv9/UQGB'
    b'AVAVQPxUaW1lLUJhc2VkIGZpbGUgbmFtZXMgdXNlIGEgZGlyZWN0b3J5IGJhc2VkIG9uIH'
    b'RoZSBkYXRlLCBhbmQgZmlsZSBuYW1lIGJhc2VkIG9uIHRoZSBzZWNvbmRzIHNpbmNlIG1p'
    b'ZG5pZ2h0LgpTZXJpYWxpemVkIGZpbGUgbmFtZXMgdXNlIHRoZSBzcGVjaWZpZWQgZGlyZW'
    b'N0b3J5IGFuZCBmaWxlIG5hbWUgcHJlZml4LCBmb2xsb3dlZCBieSBhIG51bWJlci4gCk51'
    b'bWJlciBpcyByZXNldCB3aGVuIGRpcmVjdG9yeSBvciBwcmVmaXggY2hhbmdlcy5BB41QBY'
    b'pUaW1lIEJhc2VkQQeNUAWKU2VyaWFsaXplZEAHQKlQBYtCdXR0b24gTW9kZVABgxD/f1EB'
    b'gQBQFb9PbmUgU2Vjb25kIFByZXNzIHdpbGwgZGlzYWJsZSAzLXNlY29uZCBwcmVzcyBmb3'
    b'IgYmF0dGVyeSBjaGVjay5BB5dQBZRJbW1lZGlhdGUgU3RhcnQvU3RvcEEHolAFn09uZSBT'
    b'ZWNvbmQgUHJlc3MgZm9yIFN0YXJ0L1N0b3BBB41QBYpTdGFydC1Pbmx5QBdBFFAFjlBsdW'
    b'ctSW4gQWN0aW9uUAGDCv9/UQGBAVAVrVNldCBhY3Rpb24gZm9yIGRldmljZSB3aGVuIHBs'
    b'dWdnZWQgaW4gdG8gVVNCLkEHtVAFskltbWVkaWF0ZWx5IHN0b3AgcmVjb3JkaW5nIGFuZC'
    b'BhcHBlYXIgYXMgVVNCIGRyaXZlQQezUAWwQ29tcGxldGUgcmVjb3JkaW5nIGJlZm9yZSBh'
    b'cHBlYXJpbmcgYXMgVVNCIGRyaXZlQQewUAWtSWdub3JlOiBzdG9wIHJlY29yZGluZyB3aG'
    b'VuIGJ1dHRvbiBpcyBwcmVzc2VkQQelUAWiU3RhcnQgcmVjb3JkaW5nIHdoZW4gVVNCIGNv'
    b'bm5lY3RlZEAj51ABgwv/f1AV3kVudGVyIGxvY2FsIHRpbWV6b25lJ3Mgb2Zmc2V0IGZyb2'
    b'0gVVRDIHRpbWUuIEltcGFjdHMgdGltZXN0YW1wIGluZm9ybWF0aW9uIG9uIHJlY29yZGlu'
    b'ZyBmaWxlcy5AL4BAD4BAT4BAKEkbUAWIVHJpZ2dlcnNAB0DaUAWMVHJpZ2dlciBNb2RlUA'
    b'GDEv9/UQGBAFAVQI9EZWxheSBUaGVuIFRyaWdnZXI6IFdhaXQgc3BlY2lmaWVkIHRpbWUs'
    b'IHRoZW4gd2FpdCBmb3IgdHJpZ2dlcgpEZWxheSBPciBUcmlnZ2VyOiBBY3F1aXJlIGFmdG'
    b'VyIHdhaXQgb3Igb24gdHJpZ2dlci4gQmF0dGVyeSBsaWZlIG1heSBiZSByZWR1Y2VkLkEH'
    b'lVAFkkRlbGF5IFRoZW4gVHJpZ2dlckEHk1AFkERlbGF5IE9yIFRyaWdnZXJAMvRQBY1TdG'
    b'FydCBhdCBUaW1lUAGDD/9/UBXbV2FpdCB1bnRpbCBzZXQgdGltZSBiZWZvcmUgZXZhbHVh'
    b'dGluZyBvdGhlciB0cmlnZ2VyIGNvbmRpdGlvbnMsIGluY2x1ZGluZyBhIHJlY29yZGluZy'
    b'BkZWxheUARrlAFlFJlY29yZGluZyBUaW1lIExpbWl0UAGDDf9/USGE////8FAlh1NlY29u'
    b'ZHNAEUCQUAWYUmVjb3JkaW5nIERlbGF5L0ludGVydmFsUAGDDP9/UQGBAFAlh1NlY29uZH'
    b'NRIYMBUYBQFdhUaW1lIGJlZm9yZSBzdGFydGluZyBhIHJlY29yZGluZywgYW5kIHRpbWUg'
    b'YmV0d2VlbiByZWNvcmRpbmdzIGlmICdSZXRyaWdnZXInIGlzIGNoZWNrZWQuQBGvUAWZUm'
    b'Vjb3JkaW5nIEZpbGUgU2l6ZSBMaW1pdFABgxH/f1EhhP////BQJYNLaUJAEECXUAWJUmV0'
    b'cmlnZ2VyUAGDDv9/UBSwQ29uZmlnWzB4REZGN0ZdPT1udWxsIGFuZCBDb25maWdbMHgxMU'
    b'ZGN0ZdPT1udWxsUBXPV2hlbiBzZXQsIFNsYW0gU3RpY2sgd2lsbCByZS1hcm0gYWZ0ZXIg'
    b'cmVjb3JkaW5nIHRpbWUgb3Igc2l6ZSBsaW1pdCBpcyByZWFjaGVkLkAQQKhQBZ5XYWl0IG'
    b'ZvciBBbGwgU2Vuc29yIENvbmRpdGlvbnNQAYMT/39QFf5XaGVuIHNldCwgcmVjb3JkaW5n'
    b'IHdpbGwgb25seSBzdGFydCB3aGVuIGFsbCB0cmlnZ2VycyBhcmUgbWV0LCBvdGhlcndpc2'
    b'UgcmVjb3JkaW5nIHdpbGwgc3RhcnQgd2hlbiBhbnkgc2Vuc29yIGNvbmRpdGlvbiBpcyBt'
    b'ZXRAGEEKUAWQUHJlc3N1cmUgVHJpZ2dlclABgwUAJFEAgQBQFJlDb25maWdbMHgwMUZGMj'
    b'RdICYgMSA9PSAwQILlUAWVUHJlc3N1cmUgVHJpZ2dlciwgTG93UAGDAwAkUQGDAV+QUCWC'
    b'UGFRIYMB1MBQFbNTZXQgdG8gc3RhcnQgc2FtcGxpbmcgd2hlbiBvdXRzaWRlIHByZXNzdX'
    b'JlIHdpbmRvdy5AguZQBZZQcmVzc3VyZSBUcmlnZ2VyLCBIaWdoUAGDBAAkUQGDAa2wUCWC'
    b'UGFRIYMB1MBQFbNTZXQgdG8gc3RhcnQgc2FtcGxpbmcgd2hlbiBvdXRzaWRlIHByZXNzdX'
    b'JlIHdpbmRvdy5AGEEXUAWTVGVtcGVyYXR1cmUgVHJpZ2dlclABgwUBJFEAgQBQFJlDb25m'
    b'aWdbMHgwMUZGMjRdICYgMiA9PSAwQGPqUAWYVGVtcGVyYXR1cmUgVHJpZ2dlciwgTG93UA'
    b'GDAwEkUQKB9lAlgUNREoHYUSKBUFAVtlNldCB0byBzdGFydCBzYW1wbGluZyB3aGVuIG91'
    b'dHNpZGUgdGVtcGVyYXR1cmUgd2luZG93LkBj61AFmVRlbXBlcmF0dXJlIFRyaWdnZXIsIE'
    b'hpZ2hQAYMEASRRAoEjUCWBQ1ESgdhRIoFQUBW2U2V0IHRvIHN0YXJ0IHNhbXBsaW5nIHdo'
    b'ZW4gb3V0c2lkZSB0ZW1wZXJhdHVyZSB3aW5kb3cuQBhBo1AFm0FjY2VsZXJhdGlvbiBUcm'
    b'lnZ2VyICgyMDBnKVABgwf/IFAV1ExvdyBwb3dlciB0cmlnZ2VyIHVzaW5nIGRpZ2l0YWwg'
    b'YWNjZWxlcm9tZXRlciB3aXRoIERDIHJlc3BvbnNlLiBObyBwcmUtdHJpZ2dlciBkYXRhLl'
    b'EAgQBQEYMF/whQEYMH/1BQJIBQFJRDb25maWdbMHgxZmYyMF0gPT0gMEBDQLFQBZZBY2Nl'
    b'bGVyYXRpb24gVGhyZXNob2xkUAGDBP8gUQGBUFIDiD/o9cKPXCj2USOIQGkAAAAAAABRE4'
    b'BQFfJMb3cgcG93ZXIgdHJpZ2dlci4gVGhlIG1pbmltdW0gYWNjZWxlcmF0aW9uIChwb3Np'
    b'dGl2ZSBvciBuZWdhdGl2ZSkgdG8gdHJpZ2dlciBhIHJlY29yZGluZy4gTXVzdCBiZSBncm'
    b'VhdGVyIHRoYW4gMC5AJ8ZQAYMF/yBRAYEHQQeRUAWOWCBBeGlzIFRyaWdnZXJBB5FQBY5Z'
    b'IEF4aXMgVHJpZ2dlckEHkVAFjlogQXhpcyBUcmlnZ2VyQBhBo1AFmkFjY2VsZXJhdGlvbi'
    b'BUcmlnZ2VyICg0MGcpUAGDB/9QUBXUTG93IHBvd2VyIHRyaWdnZXIgdXNpbmcgZGlnaXRh'
    b'bCBhY2NlbGVyb21ldGVyIHdpdGggREMgcmVzcG9uc2UuIE5vIHByZS10cmlnZ2VyIGRhdG'
    b'EuUQCBAFARgwX/CFARgwf/IFAkgFAUlENvbmZpZ1sweDFmZjUwXSA9PSAwQENAslAFlkFj'
    b'Y2VsZXJhdGlvbiBUaHJlc2hvbGRQAYME/1BRAYIgAFIDiD9EABQAFAAUUSOIQEQAAAAAAA'
    b'BRE4BQFfJMb3cgcG93ZXIgdHJpZ2dlci4gVGhlIG1pbmltdW0gYWNjZWxlcmF0aW9uIChw'
    b'b3NpdGl2ZSBvciBuZWdhdGl2ZSkgdG8gdHJpZ2dlciBhIHJlY29yZGluZy4gTXVzdCBiZS'
    b'BncmVhdGVyIHRoYW4gMC5AJ8ZQAYMF/1BRAYEHQQeRUAWOWCBBeGlzIFRyaWdnZXJBB5FQ'
    b'BY5ZIEF4aXMgVHJpZ2dlckEHkVAFjlogQXhpcyBUcmlnZ2VyQA+AQE+AQChGglAFjE1lYX'
    b'N1cmVtZW50c0AIQLtQBZwyMDBnIERDIEFjY2VsZXJhdGlvbiAoQ2ggMzIpQCefUAGDAf8g'
    b'UQGBAUEHklAFj0VuYWJsZSBBbGwgQXhlc0AX91AFi1NhbXBsZSBSYXRlUAGDAv8gUQGCAZ'
    b'BQJYJIelAUk25vdCBDb25maWdbMHgxZmYyMF1BB4VRAYIMgEEHhVEBggZAQQeFUQGCAyBB'
    b'B4VRAYIBkEEHhFEBgchBB4RRAYFkQQeEUQGBMkEHhFEBgRlBB4RRAYEMQAhBHFAFmzQwZy'
    b'BEQyBBY2NlbGVyYXRpb24gKENoIDgwKUAnn1ABgwH/UFEBgQFBB5JQBY9FbmFibGUgQWxs'
    b'IEF4ZXNAF0DYUAWLU2FtcGxlIFJhdGVQAYMC/1BRAYIB9FAlgkh6UBXeTG93IHBhc3MgZm'
    b'lsdGVyIGlzIHNldCB0byAyNSUgb2YgZGF0YSByYXRlLCBzbyBhIGRhdGEgcmF0ZSBvZiAy'
    b'MDAwSHogaGFzIGEgTFAgZmlsdGVyIGF0IDUwMCBIelAUk25vdCBDb25maWdbMHgxZmY1MF'
    b'1BB4VRAYIPoEEHhVEBggfQQQeFUQGCA+hBB4VRAYIB9EEHhFEBgfpBB4RRAYF9QQeEUQGB'
    b'P0EHhFEBgSBBB4RRAYEQQAhBMFAFqENvbnRyb2wgUGFkIFRlbXBlcmF0dXJlL1ByZXNzdX'
    b'JlIChDaCA1OSlAJ0CbUQGBA1ABgwH/O1AVpUVuYWJsZS9EaXNhYmxlIHNlbnNvcnMgb24g'
    b'Y29udHJvbCBwYWRBB5xQBZlFbmFibGUgUHJlc3N1cmUgKENoIDU5LjApQQefUAWcRW5hYm'
    b'xlIFRlbXBlcmF0dXJlIChDaCA1OS4xKUEHpVAFokVuYWJsZSBSZWxhdGl2ZSBIdW1pZGl0'
    b'eSAoQ2ggNTkuMilAEeNQBYtTYW1wbGUgUmF0ZVABgwL/O1AUlENvbmZpZ1sweDFmZjNCXS'
    b'A9PSAwUBWkU2V0IHNhbXBsZSBmcmVxdWVuY3kgZnJvbSAxIHRvIDEwIEh6UQGBClAlgkh6'
    b'URGBAVEhgQpACEHNUAWZSW5lcnRpYWwgTWVhc3VyZW1lbnQgVW5pdEAHQJZQBZBBY3F1aX'
    b'NpdGlvbiBNb2RlUAGDAf8rUCWBIFEBgRBBB4pQBYNPZmZRAYEAQQeoUAWhQWJzb2x1dGUg'
    b'T3JpZW50YXRpb24gKFF1YXRlcm5pb24pUQGBCEEHqFAFoVJlbGF0aXZlIE9yaWVudGF0aW'
    b'9uIChRdWF0ZXJuaW9uKVEBgRBBB49QBYhSb3RhdGlvblEBgQJAAUCGUAWVT3JpZW50YXRp'
    b'b24gRGF0YSBSYXRlUAGDAggrUQGBZFAlgkh6URGBAVEhgchQFb1TYW1wbGUgcmF0ZSBmb3'
    b'IgZGlyZWN0aW9uYWwgZGF0YSBmcm9tIDEgdG8gMjAwIEh6LiBDaGFubmVsIDY1UBSUQ29u'
    b'ZmlnWzB4MDFGRjJCXSA8IDhAAUCJUAWSUm90YXRpb24gRGF0YSBSYXRlUAGDAgIrUQGBZF'
    b'Algkh6URGBAVEhgchQFb5TZXQgc2FtcGxlIHJhdGUgZm9yIHJvdGF0aW9uIGRhdGEgZnJv'
    b'bSAxIHRvIDIwMCBIei4gQ2hhbm5lbCA0N1AUmUNvbmZpZ1sweDAxRkYyQl0gJiAyID09ID'
    b'BACEDxUAWlSW50ZXJuYWwgVGVtcGVyYXR1cmUvUHJlc3N1cmUgKENoIDM2KUAnQMVRAYED'
    b'UAGDAf8kUBX3RW5hYmxlL0Rpc2FibGUgc2xvd2VyIGludGVybmFsIGVudmlyb25tZW50YW'
    b'wgc2Vuc29ycy4gTk9URTogVGVtcGVyYXR1cmUgaXMgcmVxdWlyZWQgZm9yIG1haW4gYWNj'
    b'ZWxlcm9tZXRlciBtZWFzdXJlbWVudHNBB5xQBZlFbmFibGUgUHJlc3N1cmUgKENoIDM2Lj'
    b'ApQQefUAWcRW5hYmxlIFRlbXBlcmF0dXJlIChDaCAzNi4xKUAIQJBQBaBDb250cm9sIFBh'
    b'ZCBMaWdodCBTZW5zb3IgKENoIDc2KUAn6lABgwH/TFAVvkVuYWJsZS9EaXNhYmxlIGxpZ2'
    b'h0IHNlbnNvciBhdCA0IEh6IC0gTk9URTogRElTQUJMRUQgRk9SIEFMUEhBQQegUAWdRW5h'
    b'YmxlIExpZ2h0IFNlbnNvciAoQ2ggNzYuMClAD4BAT4BKCIBKKIBKSIA='
)
