"""
Default ConfigUI for LOG-0002-025G-DC data recorders 
"""

from base64 import b64decode

DEFAULT_CONFIG_UI = b64decode(
    b'd3dVCkAoRYFQBYdHZW5lcmFsQAXzUAWLRGV2aWNlIE5hbWVQAYMI/39RJIFAUBXYQSBjdX'
    b'N0b20gbmFtZSBmb3IgdGhlIHJlY29yZGVyLiBOb3QgdGhlIHNhbWUgYXMgdGhlIHZvbHVt'
    b'ZSBsYWJlbC4gNjQgY2hhcmFjdGVycyBtYXhpbXVtLkAF81AFjERldmljZSBOb3Rlc1ABgw'
    b'n/f1EkggEAUBXSQ3VzdG9tIG5vdGVzIGFib3V0IHRoZSByZWNvcmRlciAocG9zaXRpb24s'
    b'IHVzZXIgSUQsIGV0Yy4pLiAyNTYgY2hhcmFjdGVycyBtYXhpbXVtLlE0gQNABfpQBZNSZW'
    b'NvcmRpbmcgRGlyZWN0b3J5UAGDFP9/UQSGUkVDT1JEUSSBCFAUk0NvbmZpZ1sweDE2RkY3'
    b'Rl09PTBQFbhEaXJlY3RvcnkgZm9yIHNlcmlhbGl6ZWQgcmVjb3JkaW5ncy4gOCBjaGFyYW'
    b'N0ZXIgbWF4aW11bUAFQKJQBZVSZWNvcmRpbmcgRmlsZSBQcmVmaXhQAYMV/39RJIEIUBXn'
    b'UHJlZml4IGZvciBzZXJpYWxpemVkIHJlY29yZGluZyBuYW1lcy4gSWYgYmxhbmssIGRldm'
    b'ljZSBzZXJpYWwgbnVtYmVyIHdpbGwgYmUgdXNlZC4gOCBjaGFyYWN0ZXIgbWF4aW11bVAU'
    b'k0NvbmZpZ1sweDE2RkY3Rl09PTBAB0E8UAWPRmlsZSBOYW1lIFN0eWxlUAGDFv9/UQGBAF'
    b'AVQPxUaW1lLUJhc2VkIGZpbGUgbmFtZXMgdXNlIGEgZGlyZWN0b3J5IGJhc2VkIG9uIHRo'
    b'ZSBkYXRlLCBhbmQgZmlsZSBuYW1lIGJhc2VkIG9uIHRoZSBzZWNvbmRzIHNpbmNlIG1pZG'
    b'5pZ2h0LgpTZXJpYWxpemVkIGZpbGUgbmFtZXMgdXNlIHRoZSBzcGVjaWZpZWQgZGlyZWN0'
    b'b3J5IGFuZCBmaWxlIG5hbWUgcHJlZml4LCBmb2xsb3dlZCBieSBhIG51bWJlci4gCk51bW'
    b'JlciBpcyByZXNldCB3aGVuIGRpcmVjdG9yeSBvciBwcmVmaXggY2hhbmdlcy5BB41QBYpU'
    b'aW1lIEJhc2VkQQeNUAWKU2VyaWFsaXplZEAHQJlQBYtCdXR0b24gTW9kZVABgxD/f1EBgQ'
    b'BQFb9PbmUgU2Vjb25kIFByZXNzIHdpbGwgZGlzYWJsZSAzLXNlY29uZCBwcmVzcyBmb3Ig'
    b'YmF0dGVyeSBjaGVjay5BB5dQBZRJbW1lZGlhdGUgU3RhcnQvU3RvcEEHolAFn09uZSBTZW'
    b'NvbmQgUHJlc3MgZm9yIFN0YXJ0L1N0b3BAF0EUUAWOUGx1Zy1JbiBBY3Rpb25QAYMK/39R'
    b'AYEBUBWtU2V0IGFjdGlvbiBmb3IgZGV2aWNlIHdoZW4gcGx1Z2dlZCBpbiB0byBVU0IuQQ'
    b'e1UAWySW1tZWRpYXRlbHkgc3RvcCByZWNvcmRpbmcgYW5kIGFwcGVhciBhcyBVU0IgZHJp'
    b'dmVBB7NQBbBDb21wbGV0ZSByZWNvcmRpbmcgYmVmb3JlIGFwcGVhcmluZyBhcyBVU0IgZH'
    b'JpdmVBB7BQBa1JZ25vcmU6IHN0b3AgcmVjb3JkaW5nIHdoZW4gYnV0dG9uIGlzIHByZXNz'
    b'ZWRBB6VQBaJTdGFydCByZWNvcmRpbmcgd2hlbiBVU0IgY29ubmVjdGVkQCPnUAGDC/9/UB'
    b'XeRW50ZXIgbG9jYWwgdGltZXpvbmUncyBvZmZzZXQgZnJvbSBVVEMgdGltZS4gSW1wYWN0'
    b'cyB0aW1lc3RhbXAgaW5mb3JtYXRpb24gb24gcmVjb3JkaW5nIGZpbGVzLkAvgEAPgEBPgE'
    b'AoSOBQBYhUcmlnZ2Vyc0AHQNpQBYxUcmlnZ2VyIE1vZGVQAYMS/39RAYEAUBVAj0RlbGF5'
    b'IFRoZW4gVHJpZ2dlcjogV2FpdCBzcGVjaWZpZWQgdGltZSwgdGhlbiB3YWl0IGZvciB0cm'
    b'lnZ2VyCkRlbGF5IE9yIFRyaWdnZXI6IEFjcXVpcmUgYWZ0ZXIgd2FpdCBvciBvbiB0cmln'
    b'Z2VyLiBCYXR0ZXJ5IGxpZmUgbWF5IGJlIHJlZHVjZWQuQQeVUAWSRGVsYXkgVGhlbiBUcm'
    b'lnZ2VyQQeTUAWQRGVsYXkgT3IgVHJpZ2dlckAy9FAFjVN0YXJ0IGF0IFRpbWVQAYMP/39Q'
    b'FdtXYWl0IHVudGlsIHNldCB0aW1lIGJlZm9yZSBldmFsdWF0aW5nIG90aGVyIHRyaWdnZX'
    b'IgY29uZGl0aW9ucywgaW5jbHVkaW5nIGEgcmVjb3JkaW5nIGRlbGF5QBGuUAWUUmVjb3Jk'
    b'aW5nIFRpbWUgTGltaXRQAYMN/39RIYT////wUCWHU2Vjb25kc0ARQJBQBZhSZWNvcmRpbm'
    b'cgRGVsYXkvSW50ZXJ2YWxQAYMM/39RAYEAUCWHU2Vjb25kc1EhgwFRgFAV2FRpbWUgYmVm'
    b'b3JlIHN0YXJ0aW5nIGEgcmVjb3JkaW5nLCBhbmQgdGltZSBiZXR3ZWVuIHJlY29yZGluZ3'
    b'MgaWYgJ1JldHJpZ2dlcicgaXMgY2hlY2tlZC5AEa9QBZlSZWNvcmRpbmcgRmlsZSBTaXpl'
    b'IExpbWl0UAGDEf9/USGE////8FAlg0tpQkAQQJdQBYlSZXRyaWdnZXJQAYMO/39QFLBDb2'
    b'5maWdbMHhERkY3Rl09PW51bGwgYW5kIENvbmZpZ1sweDExRkY3Rl09PW51bGxQFc9XaGVu'
    b'IHNldCwgU2xhbSBTdGljayB3aWxsIHJlLWFybSBhZnRlciByZWNvcmRpbmcgdGltZSBvci'
    b'BzaXplIGxpbWl0IGlzIHJlYWNoZWQuQBBAqFAFnldhaXQgZm9yIEFsbCBTZW5zb3IgQ29u'
    b'ZGl0aW9uc1ABgxP/f1AV/ldoZW4gc2V0LCByZWNvcmRpbmcgd2lsbCBvbmx5IHN0YXJ0IH'
    b'doZW4gYWxsIHRyaWdnZXJzIGFyZSBtZXQsIG90aGVyd2lzZSByZWNvcmRpbmcgd2lsbCBz'
    b'dGFydCB3aGVuIGFueSBzZW5zb3IgY29uZGl0aW9uIGlzIG1ldEAYQO5QBZBQcmVzc3VyZS'
    b'BUcmlnZ2VyUAGDBQAkUQCBAECC5VAFlVByZXNzdXJlIFRyaWdnZXIsIExvd1ABgwMAJFEB'
    b'gwFfkFAlglBhUSGDAdTAUBWzU2V0IHRvIHN0YXJ0IHNhbXBsaW5nIHdoZW4gb3V0c2lkZS'
    b'BwcmVzc3VyZSB3aW5kb3cuQILmUAWWUHJlc3N1cmUgVHJpZ2dlciwgSGlnaFABgwQAJFEB'
    b'gwGtsFAlglBhUSGDAdTAUBWzU2V0IHRvIHN0YXJ0IHNhbXBsaW5nIHdoZW4gb3V0c2lkZS'
    b'BwcmVzc3VyZSB3aW5kb3cuQBhA+1AFk1RlbXBlcmF0dXJlIFRyaWdnZXJQAYMFASRRAIEA'
    b'QGPqUAWYVGVtcGVyYXR1cmUgVHJpZ2dlciwgTG93UAGDAwEkUQKB9lAlgUNREoHYUSKBUF'
    b'AVtlNldCB0byBzdGFydCBzYW1wbGluZyB3aGVuIG91dHNpZGUgdGVtcGVyYXR1cmUgd2lu'
    b'ZG93LkBj61AFmVRlbXBlcmF0dXJlIFRyaWdnZXIsIEhpZ2hQAYMEASRRAoEjUCWBQ1ESgd'
    b'hRIoFQUBW2U2V0IHRvIHN0YXJ0IHNhbXBsaW5nIHdoZW4gb3V0c2lkZSB0ZW1wZXJhdHVy'
    b'ZSB3aW5kb3cuQBhBp1AFmkFjY2VsZXJhdGlvbiBUcmlnZ2VyICgyNWcpUAGDBf8IUBGDB/'
    b'8gUQCBAFAkgFAUlUNvbmZpZ1sweDAxRkYwOF0gPT0gMEBDQKtRE4jAOQAAAAAAAFEjiEA5'
    b'AAAAAAAAUAWZQWNjZWxlcmF0aW9uIFRyaWdnZXIsIExvd1ABgwP/CFECgvmaUBXgSGlnaC'
    b'Bwb3dlciB0cmlnZ2VyIHdpdGggcHJlLXRyaWdnZXIgZGF0YS4gTm90IHJlY29tbWVuZGVk'
    b'IGZvciBsb25nIHdhaXRzIHdpdGhvdXQgZXh0ZXJuYWwgcG93ZXIuUgOIP0kAGQAZABlAQ0'
    b'CsUROIwDkAAAAAAABRI4hAOQAAAAAAAFAFmkFjY2VsZXJhdGlvbiBUcmlnZ2VyLCBIaWdo'
    b'UAGDBP8IUQKCBmZQFeBIaWdoIHBvd2VyIHRyaWdnZXIgd2l0aCBwcmUtdHJpZ2dlciBkYX'
    b'RhLiBOb3QgcmVjb21tZW5kZWQgZm9yIGxvbmcgd2FpdHMgd2l0aG91dCBleHRlcm5hbCBw'
    b'b3dlci5SA4g/SQAZABkAGUAYQZxQBZpBY2NlbGVyYXRpb24gVHJpZ2dlciAoMTZnKVABgw'
    b'f/IFAV1ExvdyBwb3dlciB0cmlnZ2VyIHVzaW5nIGRpZ2l0YWwgYWNjZWxlcm9tZXRlciB3'
    b'aXRoIERDIHJlc3BvbnNlLiBObyBwcmUtdHJpZ2dlciBkYXRhLlEAgQBQEYMF/whQJIBQFJ'
    b'RDb25maWdbMHgxZmYyMF0gPT0gMEBDQLFQBZZBY2NlbGVyYXRpb24gVGhyZXNob2xkUAGD'
    b'BP8gUQGBUFIDiD+wEBAQEBAQUSOIQDAAAAAAAABRE4BQFfJMb3cgcG93ZXIgdHJpZ2dlci'
    b'4gVGhlIG1pbmltdW0gYWNjZWxlcmF0aW9uIChwb3NpdGl2ZSBvciBuZWdhdGl2ZSkgdG8g'
    b'dHJpZ2dlciBhIHJlY29yZGluZy4gTXVzdCBiZSBncmVhdGVyIHRoYW4gMC5AJ8ZQAYMF/y'
    b'BRAYEHQQeRUAWOWCBBeGlzIFRyaWdnZXJBB5FQBY5ZIEF4aXMgVHJpZ2dlckEHkVAFjlog'
    b'QXhpcyBUcmlnZ2VyQA+AQE+AQChGlFAFjE1lYXN1cmVtZW50c0AIQkBQBZcyNWcgQWNjZW'
    b'xlcmF0aW9uIChDaCA4KVAkgEAnQIFRAYEHUAGDAf8IUBWgRW5hYmxlL0Rpc2FibGUgYWNj'
    b'ZWxlcmF0aW9uIGF4ZXNBB5lQBZZFbmFibGUgWCBBeGlzIChDaCA4LjApQQeZUAWWRW5hYm'
    b'xlIFkgQXhpcyAoQ2ggOC4xKUEHmVAFlkVuYWJsZSBaIEF4aXMgKENoIDguMilAEUCaUAWL'
    b'U2FtcGxlIFJhdGVQAYMC/whQFdhTZXQgbWFpbiBhY2NlbGVyYXRpb24gc2FtcGxlIHJhdG'
    b'UgZnJvbSAxMCB0byAyMDAwMCBIei4KSGlnaGVyIHJhdGUgcmVkdWNlcyBiYXR0ZXJ5IGxp'
    b'ZmUuUBSVQ29uZmlnWzB4MDFGRjA4XSA9PSAwUQGCE4hQJYJIelERgQpRIYJOIEARQPxQBa'
    b'NPdmVycmlkZSBBbnRpYWxpYXNpbmcgRmlsdGVyIEN1dG9mZlABgwj/CFEBggPoUCWCSHpR'
    b'IYITiFAVQKVEZWZhdWx0LCB3aGVuIG5vdCBjaGVja2VkLCBvZiBvbmUtZmlmdGggc2FtcG'
    b'xlIGZyZXF1ZW5jeS4gQ3V0LW9mZiBmcmVxdWVuY3kgaGFzIDI5JSBhdHRlbnVhdGlvbi4K'
    b'NXRoIG9yZGVyIEJ1dHRlcndvcnRoLiBTb21lIGF0dGVudWF0aW9uIGF0IDYwJSBvZiBjdX'
    b'Qtb2ZmIGZyZXF1ZW5jeS5QFJVDb25maWdbMHgwMUZGMDhdID09IDBACEC6UAWbMTZnIERD'
    b'IEFjY2VsZXJhdGlvbiAoQ2ggMzIpQCefUAGDAf8gUQGBAUEHklAFj0VuYWJsZSBBbGwgQX'
    b'hlc0AX91AFi1NhbXBsZSBSYXRlUAGDAv8gUQGCAZBQJYJIelAUk25vdCBDb25maWdbMHgx'
    b'ZmYyMF1BB4VRAYIMgEEHhVEBggZAQQeFUQGCAyBBB4VRAYIBkEEHhFEBgchBB4RRAYFkQQ'
    b'eEUQGBMkEHhFEBgRlBB4RRAYEMQAhBMFAFqENvbnRyb2wgUGFkIFRlbXBlcmF0dXJlL1By'
    b'ZXNzdXJlIChDaCA1OSlAJ0CbUQGBA1ABgwH/O1AVpUVuYWJsZS9EaXNhYmxlIHNlbnNvcn'
    b'Mgb24gY29udHJvbCBwYWRBB5xQBZlFbmFibGUgUHJlc3N1cmUgKENoIDU5LjApQQefUAWc'
    b'RW5hYmxlIFRlbXBlcmF0dXJlIChDaCA1OS4xKUEHpVAFokVuYWJsZSBSZWxhdGl2ZSBIdW'
    b'1pZGl0eSAoQ2ggNTkuMilAEeNQBYtTYW1wbGUgUmF0ZVABgwL/O1AUlENvbmZpZ1sweDFm'
    b'ZjNCXSA9PSAwUBWkU2V0IHNhbXBsZSBmcmVxdWVuY3kgZnJvbSAxIHRvIDEwIEh6UQGBCl'
    b'Algkh6URGBAVEhgQpACEHJUAWZSW5lcnRpYWwgTWVhc3VyZW1lbnQgVW5pdEAHQJJQBZBB'
    b'Y3F1aXNpdGlvbiBNb2RlUAGDAf8rUQGBEEEHilAFg09mZlEBgQBBB6hQBaFBYnNvbHV0ZS'
    b'BPcmllbnRhdGlvbiAoUXVhdGVybmlvbilRAYEIQQeoUAWhUmVsYXRpdmUgT3JpZW50YXRp'
    b'b24gKFF1YXRlcm5pb24pUQGBEEEHj1AFiFJvdGF0aW9uUQGBAkABQIZQBZVPcmllbnRhdG'
    b'lvbiBEYXRhIFJhdGVQAYMCCCtRAYFkUCWCSHpREYEBUSGByFAVvVNhbXBsZSByYXRlIGZv'
    b'ciBkaXJlY3Rpb25hbCBkYXRhIGZyb20gMSB0byAyMDAgSHouIENoYW5uZWwgNjVQFJRDb2'
    b'5maWdbMHgwMUZGMkJdIDwgOEABQIlQBZJSb3RhdGlvbiBEYXRhIFJhdGVQAYMCAitRAYFk'
    b'UCWCSHpREYEBUSGByFAVvlNldCBzYW1wbGUgcmF0ZSBmb3Igcm90YXRpb24gZGF0YSBmcm'
    b'9tIDEgdG8gMjAwIEh6LiBDaGFubmVsIDQ3UBSZQ29uZmlnWzB4MDFGRjJCXSAmIDIgPT0g'
    b'MEAI+VAFoENvbnRyb2wgUGFkIExpZ2h0IFNlbnNvciAoQ2ggNzYpQCfTUQGBAVABgwH/TF'
    b'AVo0VuYWJsZS9EaXNhYmxlIGxpZ2h0IHNlbnNvciBhdCA0IEh6QQegUAWdRW5hYmxlIExp'
    b'Z2h0IFNlbnNvciAoQ2ggNzYuMClAD4BAT4BKCIBKKIBKSIA='
)
