"""
Default ConfigUI for Sx-D8 data recorders 
"""

from base64 import b64decode

DEFAULT_CONFIG_UI = b64decode(
    b'GkXfo6lChoEBQveBAULygQRC84EIQoKObWlkZS5zcy5jb25maWdCh4ECQoWBAnd3EAAYIk'
    b'AoIAa3UAWHR2VuZXJhbEAFQHNQBYtEZXZpY2UgTmFtZVABgwj/f1EkgUBQFdhBIGN1c3Rv'
    b'bSBuYW1lIGZvciB0aGUgcmVjb3JkZXIuIE5vdCB0aGUgc2FtZSBhcyB0aGUgdm9sdW1lIG'
    b'xhYmVsLiA2NCBjaGFyYWN0ZXJzIG1heGltdW0uQAVAc1AFjERldmljZSBOb3Rlc1ABgwn/'
    b'f1EkggEAUBXSQ3VzdG9tIG5vdGVzIGFib3V0IHRoZSByZWNvcmRlciAocG9zaXRpb24sIH'
    b'VzZXIgSUQsIGV0Yy4pLiAyNTYgY2hhcmFjdGVycyBtYXhpbXVtLlE0gQNABUCZUAWVQ3Vz'
    b'dG9tIFJlY29yZGluZyBUYWdzUAGDF/9/UQSAUSSBQFAV8UtleXdvcmRzIGZvciBvcmdhbm'
    b'l6aW5nIGFuZCBpZGVudGlmeWluZyByZWNvcmRpbmdzLCBzZXBhcmF0ZWQgYnkgY29tbWEg'
    b'b3Igc3BhY2UuIExpbWl0IGlzIDIwIHRhZ3MsIDY0IGNoYXJhY3RlcnMuQAdBPFAFj0ZpbG'
    b'UgTmFtZSBTdHlsZVABgxb/f1EBgQFQFUD8VGltZS1CYXNlZCBmaWxlIG5hbWVzIHVzZSBh'
    b'IGRpcmVjdG9yeSBiYXNlZCBvbiB0aGUgZGF0ZSwgYW5kIGZpbGUgbmFtZSBiYXNlZCBvbi'
    b'B0aGUgc2Vjb25kcyBzaW5jZSBtaWRuaWdodC4KU2VyaWFsaXplZCBmaWxlIG5hbWVzIHVz'
    b'ZSB0aGUgc3BlY2lmaWVkIGRpcmVjdG9yeSBhbmQgZmlsZSBuYW1lIHByZWZpeCwgZm9sbG'
    b'93ZWQgYnkgYSBudW1iZXIuIApOdW1iZXIgaXMgcmVzZXQgd2hlbiBkaXJlY3Rvcnkgb3Ig'
    b'cHJlZml4IGNoYW5nZXMuQQeNUAWKVGltZSBCYXNlZEEHjVAFilNlcmlhbGl6ZWRABUB7UA'
    b'WTUmVjb3JkaW5nIERpcmVjdG9yeVABgxT/f1EEhlJFQ09SRFEkgRBQFJNDb25maWdbMHgx'
    b'NkZGN0ZdPT0wUBW5RGlyZWN0b3J5IGZvciBzZXJpYWxpemVkIHJlY29yZGluZ3MuIDE2IG'
    b'NoYXJhY3RlciBtYXhpbXVtQAVAo1AFlVJlY29yZGluZyBGaWxlIFByZWZpeFABgxX/f1Ek'
    b'gRBQFehQcmVmaXggZm9yIHNlcmlhbGl6ZWQgcmVjb3JkaW5nIG5hbWVzLiBJZiBibGFuay'
    b'wgZGV2aWNlIHNlcmlhbCBudW1iZXIgd2lsbCBiZSB1c2VkLiAxNiBjaGFyYWN0ZXIgbWF4'
    b'aW11bVAUk0NvbmZpZ1sweDE2RkY3Rl09PTBAF0EUUAWOUGx1Zy1JbiBBY3Rpb25QAYMK/3'
    b'9RAYEBUBWtU2V0IGFjdGlvbiBmb3IgZGV2aWNlIHdoZW4gcGx1Z2dlZCBpbiB0byBVU0Iu'
    b'QQe1UAWySW1tZWRpYXRlbHkgc3RvcCByZWNvcmRpbmcgYW5kIGFwcGVhciBhcyBVU0IgZH'
    b'JpdmVBB7NQBbBDb21wbGV0ZSByZWNvcmRpbmcgYmVmb3JlIGFwcGVhcmluZyBhcyBVU0Ig'
    b'ZHJpdmVBB7BQBa1JZ25vcmU6IHN0b3AgcmVjb3JkaW5nIHdoZW4gYnV0dG9uIGlzIHByZX'
    b'NzZWRBB6VQBaJTdGFydCByZWNvcmRpbmcgd2hlbiBVU0IgY29ubmVjdGVkQAdBLFAFi0J1'
    b'dHRvbiBNb2RlUAGDEP9/UQGBAFAVQMFPbmUgU2Vjb25kIFByZXNzIHdpbGwgZGlzYWJsZS'
    b'AzLXNlY29uZCBwcmVzcyBmb3IgYmF0dGVyeSBjaGVjay4KTk9URTogSWYgJ1N0YXJ0LU9u'
    b'bHknIGlzIHNlbGVjdGVkIGFuZCBubyByZWNvcmRpbmcgdGltZSBsaW1pdCBvciBtYXggZm'
    b'lsZSBzaXplIGlzIHNldCwgcmVjb3JkaW5ncyBjYW4gYmUgc3RvcHBlZCB3aXRoIFVTQiBw'
    b'bHVnLWluQQeXUAWUSW1tZWRpYXRlIFN0YXJ0L1N0b3BBB6JQBZ9PbmUgU2Vjb25kIFByZX'
    b'NzIGZvciBTdGFydC9TdG9wQQeNUAWKU3RhcnQtT25seUAjQGdQAYML/39QFd5FbnRlciBs'
    b'b2NhbCB0aW1lem9uZSdzIG9mZnNldCBmcm9tIFVUQyB0aW1lLiBJbXBhY3RzIHRpbWVzdG'
    b'FtcCBpbmZvcm1hdGlvbiBvbiByZWNvcmRpbmcgZmlsZXMuQC+AQA+AQE+AQCggCoNQBYhU'
    b'cmlnZ2Vyc0AHQNpQBYxUcmlnZ2VyIE1vZGVQAYMS/39RAYEAUBVAj0RlbGF5IFRoZW4gVH'
    b'JpZ2dlcjogV2FpdCBzcGVjaWZpZWQgdGltZSwgdGhlbiB3YWl0IGZvciB0cmlnZ2VyCkRl'
    b'bGF5IE9yIFRyaWdnZXI6IEFjcXVpcmUgYWZ0ZXIgd2FpdCBvciBvbiB0cmlnZ2VyLiBCYX'
    b'R0ZXJ5IGxpZmUgbWF5IGJlIHJlZHVjZWQuQQeVUAWSRGVsYXkgVGhlbiBUcmlnZ2VyQQeT'
    b'UAWQRGVsYXkgT3IgVHJpZ2dlckAyQHRQBY1TdGFydCBhdCBUaW1lUAGDD/9/UBXbV2FpdC'
    b'B1bnRpbCBzZXQgdGltZSBiZWZvcmUgZXZhbHVhdGluZyBvdGhlciB0cmlnZ2VyIGNvbmRp'
    b'dGlvbnMsIGluY2x1ZGluZyBhIHJlY29yZGluZyBkZWxheUARQJZQBZxQcmUtUmVjb3JkaW'
    b'5nIERlbGF5L0ludGVydmFsUAGDDP9/UQGBAFAlh1NlY29uZHNRIYMBUYBQFdpEZWxheSBi'
    b'ZWZvcmUgc3RhcnRpbmcgYSByZWNvcmRpbmcsIGluY2x1ZGluZyBiZXR3ZWVuIHJlY29yZG'
    b'luZ3MgaWYgJ1JldHJpZ2dlcicgaXMgY2hlY2tlZC5AEUAuUAWUUmVjb3JkaW5nIFRpbWUg'
    b'TGltaXRQAYMN/39RIYT////wUCWHU2Vjb25kc0ARQC9QBZlSZWNvcmRpbmcgRmlsZSBTaX'
    b'plIExpbWl0UAGDEf9/USGE////8FAlg0tpQkAQQJJQBYlSZXRyaWdnZXJQAYMO/39QFLBD'
    b'b25maWdbMHhERkY3Rl09PW51bGwgYW5kIENvbmZpZ1sweDExRkY3Rl09PW51bGxQFcpXaG'
    b'VuIHNldCwgZW5EQVEgd2lsbCByZS1hcm0gYWZ0ZXIgcmVjb3JkaW5nIHRpbWUgb3Igc2l6'
    b'ZSBsaW1pdCBpcyByZWFjaGVkLkAQQKhQBZ5XYWl0IGZvciBBbGwgU2Vuc29yIENvbmRpdG'
    b'lvbnNQAYMT/39QFf5XaGVuIHNldCwgcmVjb3JkaW5nIHdpbGwgb25seSBzdGFydCB3aGVu'
    b'IGFsbCB0cmlnZ2VycyBhcmUgbWV0LCBvdGhlcndpc2UgcmVjb3JkaW5nIHdpbGwgc3Rhcn'
    b'Qgd2hlbiBhbnkgc2Vuc29yIGNvbmRpdGlvbiBpcyBtZXRAGEELUAWZQ3RybCBQYWQgUHJl'
    b'c3N1cmUgVHJpZ2dlclABgwUAJ1EAgQBAgkBuUAWeQ3RybCBQYWQgUHJlc3N1cmUgVHJpZ2'
    b'dlciwgTG93UAGDAwAnUQGDAV+QUCWCUGFRIYMB1MBQFbNTZXQgdG8gc3RhcnQgc2FtcGxp'
    b'bmcgd2hlbiBvdXRzaWRlIHByZXNzdXJlIHdpbmRvdy5AgkBvUAWfQ3RybCBQYWQgUHJlc3'
    b'N1cmUgVHJpZ2dlciwgSGlnaFABgwQAJ1EBgwGtsFAlglBhUSGDAdTAUBWzU2V0IHRvIHN0'
    b'YXJ0IHNhbXBsaW5nIHdoZW4gb3V0c2lkZSBwcmVzc3VyZSB3aW5kb3cuQBhBdlAFmUludG'
    b'VybmFsIFByZXNzdXJlIFRyaWdnZXJQAYMFACRRAIEAUBToKENvbmZpZ1sweDFmZjE0XSBh'
    b'bmQgKENvbmZpZ1sweDFmZjE0XSAgJiAxID09IDApKSBvciAoQ29uZmlnWzB4MDFGRjI0XS'
    b'BhbmQgKENvbmZpZ1sweDAxRkYyNF0gICYgMSA9PSAwKSlAgkBuUAWeSW50ZXJuYWwgUHJl'
    b'c3N1cmUgVHJpZ2dlciwgTG93UAGDAwAkUQGDAV+QUCWCUGFRIYMB1MBQFbNTZXQgdG8gc3'
    b'RhcnQgc2FtcGxpbmcgd2hlbiBvdXRzaWRlIHByZXNzdXJlIHdpbmRvdy5AgkBvUAWfSW50'
    b'ZXJuYWwgUHJlc3N1cmUgVHJpZ2dlciwgSGlnaFABgwQAJFEBgwGtsFAlglBhUSGDAdTAUB'
    b'WzU2V0IHRvIHN0YXJ0IHNhbXBsaW5nIHdoZW4gb3V0c2lkZSBwcmVzc3VyZSB3aW5kb3cu'
    b'QBhBGFAFnEN0cmwgUGFkIFRlbXBlcmF0dXJlIFRyaWdnZXJQAYMFASdRAIEAQGNAc1AFoU'
    b'N0cmwgUGFkIFRlbXBlcmF0dXJlIFRyaWdnZXIsIExvd1ABgwMBJ1ECgfZQJYFDURKB2FEi'
    b'gVBQFbZTZXQgdG8gc3RhcnQgc2FtcGxpbmcgd2hlbiBvdXRzaWRlIHRlbXBlcmF0dXJlIH'
    b'dpbmRvdy5AY0B0UAWiQ3RybCBQYWQgVGVtcGVyYXR1cmUgVHJpZ2dlciwgSGlnaFABgwQB'
    b'J1ECgSNQJYFDURKB2FEigVBQFbZTZXQgdG8gc3RhcnQgc2FtcGxpbmcgd2hlbiBvdXRzaW'
    b'RlIHRlbXBlcmF0dXJlIHdpbmRvdy5AGEGDUAWcSW50ZXJuYWwgVGVtcGVyYXR1cmUgVHJp'
    b'Z2dlclABgwUBJFEAgQBQFOgoQ29uZmlnWzB4MWZmMTRdIGFuZCAoQ29uZmlnWzB4MWZmMT'
    b'RdICAmIDIgPT0gMCkpIG9yIChDb25maWdbMHgwMUZGMjRdIGFuZCAoQ29uZmlnWzB4MDFG'
    b'RjI0XSAgJiAyID09IDApKUBjQHNQBaFJbnRlcm5hbCBUZW1wZXJhdHVyZSBUcmlnZ2VyLC'
    b'BMb3dQAYMDASRRAoH2UCWBQ1ESgdhRIoFQUBW2U2V0IHRvIHN0YXJ0IHNhbXBsaW5nIHdo'
    b'ZW4gb3V0c2lkZSB0ZW1wZXJhdHVyZSB3aW5kb3cuQGNAdFAFokludGVybmFsIFRlbXBlcm'
    b'F0dXJlIFRyaWdnZXIsIEhpZ2hQAYMEASRRAoEjUCWBQ1ESgdhRIoFQUBW2U2V0IHRvIHN0'
    b'YXJ0IHNhbXBsaW5nIHdoZW4gb3V0c2lkZSB0ZW1wZXJhdHVyZSB3aW5kb3cuQBhBq1AFmU'
    b'FjY2VsZXJhdGlvbiBUcmlnZ2VyICg4ZylQAYMH/1BQFdRMb3cgcG93ZXIgdHJpZ2dlciB1'
    b'c2luZyBkaWdpdGFsIGFjY2VsZXJvbWV0ZXIgd2l0aCBEQyByZXNwb25zZS4gTm8gcHJlLX'
    b'RyaWdnZXIgZGF0YS5RAIEAUBGDBf8IUBGDB/8gUCSAUBSUQ29uZmlnWzB4MWZmNTBdID09'
    b'IDBAQ0C6UAWWQWNjZWxlcmF0aW9uIFRocmVzaG9sZFABgwT/UFEBgiAAUgOIPyAAEAAQAB'
    b'BRI4hAIAAAAAAAAFETiAAAAAAAAAAAUBXyTG93IHBvd2VyIHRyaWdnZXIuIFRoZSBtaW5p'
    b'bXVtIGFjY2VsZXJhdGlvbiAocG9zaXRpdmUgb3IgbmVnYXRpdmUpIHRvIHRyaWdnZXIgYS'
    b'ByZWNvcmRpbmcuIE11c3QgYmUgZ3JlYXRlciB0aGFuIDAuQCdARlABgwX/UFEBgQdBB5FQ'
    b'BY5YIEF4aXMgVHJpZ2dlckEHkVAFjlkgQXhpcyBUcmlnZ2VyQQeRUAWOWiBBeGlzIFRyaW'
    b'dnZXJAD4BAT4BAKCAG0FAFjE1lYXN1cmVtZW50c0AIQRxQBZo4ZyBEQyBBY2NlbGVyYXRp'
    b'b24gKENoIDgwKUAnQB9QAYMB/1BRAYEBQQeSUAWPRW5hYmxlIEFsbCBBeGVzQBdA2FAFi1'
    b'NhbXBsZSBSYXRlUAGDAv9QUQGCAfRQJYJIelAV3kxvdyBwYXNzIGZpbHRlciBpcyBzZXQg'
    b'dG8gMjUlIG9mIGRhdGEgcmF0ZSwgc28gYSBkYXRhIHJhdGUgb2YgMjAwMEh6IGhhcyBhIE'
    b'xQIGZpbHRlciBhdCA1MDAgSHpQFJNub3QgQ29uZmlnWzB4MWZmNTBdQQeFUQGCD6BBB4VR'
    b'AYIH0EEHhVEBggPoQQeFUQGCAfRBB4RRAYH6QQeEUQGBfUEHhFEBgT9BB4RRAYEgQQeEUQ'
    b'GBEEAIQdVQBaFCSEkxNjBCIEluZXJ0aWFsIE1lYXN1cmVtZW50IFVuaXRAB0CWUAWQQWNx'
    b'dWlzaXRpb24gTW9kZVABgwH/K1AlgSBRAYEQQQeKUAWDT2ZmUQGBAEEHqFAFoUFic29sdX'
    b'RlIE9yaWVudGF0aW9uIChRdWF0ZXJuaW9uKVEBgQhBB6hQBaFSZWxhdGl2ZSBPcmllbnRh'
    b'dGlvbiAoUXVhdGVybmlvbilRAYEQQQePUAWIUm90YXRpb25RAYECQAFAhlAFlU9yaWVudG'
    b'F0aW9uIERhdGEgUmF0ZVABgwIIK1EBgWRQJYJIelERgQFRIYHIUBW9U2FtcGxlIHJhdGUg'
    b'Zm9yIGRpcmVjdGlvbmFsIGRhdGEgZnJvbSAxIHRvIDIwMCBIei4gQ2hhbm5lbCA2NVAUlE'
    b'NvbmZpZ1sweDAxRkYyQl0gPCA4QAFAiVAFklJvdGF0aW9uIERhdGEgUmF0ZVABgwICK1EB'
    b'gWRQJYJIelERgQFRIYHIUBW+U2V0IHNhbXBsZSByYXRlIGZvciByb3RhdGlvbiBkYXRhIG'
    b'Zyb20gMSB0byAyMDAgSHouIENoYW5uZWwgNDdQFJlDb25maWdbMHgwMUZGMkJdICYgMiA9'
    b'PSAwQAhBSFAFsUNvbnRyb2wgUGFkIFRlbXBlcmF0dXJlL1ByZXNzdXJlL0h1bWlkaXR5IC'
    b'hDaCA1OSlAJ0CgUQGBA1ABgwH/O1AVqkVuYWJsZS9EaXNhYmxlIENvbnRyb2wgUGFkIFNl'
    b'bnNvciBDaGFubmVsc0EHnFAFmUVuYWJsZSBQcmVzc3VyZSAoQ2ggNTkuMClBB59QBZxFbm'
    b'FibGUgVGVtcGVyYXR1cmUgKENoIDU5LjEpQQelUAWiRW5hYmxlIFJlbGF0aXZlIEh1bWlk'
    b'aXR5IChDaCA1OS4yKUARQGxQBZRDdHJsIFBhZCBTYW1wbGUgUmF0ZVABgwL/O1AUlENvbm'
    b'ZpZ1sweDFmZjNCXSA9PSAwUBWkU2V0IHNhbXBsZSBmcmVxdWVuY3kgZnJvbSAxIHRvIDEw'
    b'IEh6UQGBClAlgkh6URGBAVEhgQpACEFCUAWuSW50ZXJuYWwgVGVtcGVyYXR1cmUvUHJlc3'
    b'N1cmUvSHVtaWRpdHkgKENoIDIwKUAnQJ1RAYEDUAGDAf8UUBWnRW5hYmxlL0Rpc2FibGUg'
    b'SW50ZXJuYWwgU2Vuc29yIENoYW5uZWxzQQecUAWZRW5hYmxlIFByZXNzdXJlIChDaCAyMC'
    b'4wKUEHn1AFnEVuYWJsZSBUZW1wZXJhdHVyZSAoQ2ggMjAuMSlBB6VQBaJFbmFibGUgUmVs'
    b'YXRpdmUgSHVtaWRpdHkgKENoIDIwLjIpQBFAbFAFlEludGVybmFsIFNhbXBsZSBSYXRlUA'
    b'GDAv8UUBSUQ29uZmlnWzB4MWZmMTRdID09IDBQFaRTZXQgc2FtcGxlIGZyZXF1ZW5jeSBm'
    b'cm9tIDEgdG8gMTAgSHpRAYEKUCWCSHpREYEBUSGBCkAIQHZQBaBDb250cm9sIFBhZCBMaW'
    b'dodCBTZW5zb3IgKENoIDc2KUAnQE9QAYMB/0xQFaNFbmFibGUvRGlzYWJsZSBsaWdodCBz'
    b'ZW5zb3IgYXQgNCBIekEHoFAFnUVuYWJsZSBMaWdodCBTZW5zb3IgKENoIDc2LjApQAhAsl'
    b'AFmEJNSTI3MCBHeXJvc2NvcGUgKENoIDg0KUAnQB9QAYMB/1RRAYEAQQeSUAWPRW5hYmxl'
    b'IEFsbCBBeGVzQBdAcFAFi1NhbXBsZSBSYXRlUAGDAv9UUQGCAZBQJYJIelAUk25vdCBDb2'
    b'5maWdbMHgxZmY1NF1BB4VRAYIMgEEHhVEBggZAQQeFUQGCAyBBB4VRAYIBkEEHhFEBgchB'
    b'B4RRAYFkQQeEUQGBMkEHhFEBgRlAD4BAT4BKCIBKKIBKSIA='
)
