"""
Default ConfigUI for S5-E25D40 data recorders 
"""

from base64 import b64decode

DEFAULT_CONFIG_UI = b64decode(
    b'd3dVhUAoRZNQBYdHZW5lcmFsQAXzUAWLRGV2aWNlIE5hbWVQAYMI/39RJIFAUBXYQSBjdX'
    b'N0b20gbmFtZSBmb3IgdGhlIHJlY29yZGVyLiBOb3QgdGhlIHNhbWUgYXMgdGhlIHZvbHVt'
    b'ZSBsYWJlbC4gNjQgY2hhcmFjdGVycyBtYXhpbXVtLkAF81AFjERldmljZSBOb3Rlc1ABgw'
    b'n/f1EkggEAUBXSQ3VzdG9tIG5vdGVzIGFib3V0IHRoZSByZWNvcmRlciAocG9zaXRpb24s'
    b'IHVzZXIgSUQsIGV0Yy4pLiAyNTYgY2hhcmFjdGVycyBtYXhpbXVtLlE0gQNABftQBZNSZW'
    b'NvcmRpbmcgRGlyZWN0b3J5UAGDFP9/UQSGUkVDT1JEUSSBEFAUk0NvbmZpZ1sweDE2RkY3'
    b'Rl09PTBQFblEaXJlY3RvcnkgZm9yIHNlcmlhbGl6ZWQgcmVjb3JkaW5ncy4gMTYgY2hhcm'
    b'FjdGVyIG1heGltdW1ABUCjUAWVUmVjb3JkaW5nIEZpbGUgUHJlZml4UAGDFf9/USSBEFAV'
    b'6FByZWZpeCBmb3Igc2VyaWFsaXplZCByZWNvcmRpbmcgbmFtZXMuIElmIGJsYW5rLCBkZX'
    b'ZpY2Ugc2VyaWFsIG51bWJlciB3aWxsIGJlIHVzZWQuIDE2IGNoYXJhY3RlciBtYXhpbXVt'
    b'UBSTQ29uZmlnWzB4MTZGRjdGXT09MEAHQTxQBY9GaWxlIE5hbWUgU3R5bGVQAYMW/39RAY'
    b'EBUBVA/FRpbWUtQmFzZWQgZmlsZSBuYW1lcyB1c2UgYSBkaXJlY3RvcnkgYmFzZWQgb24g'
    b'dGhlIGRhdGUsIGFuZCBmaWxlIG5hbWUgYmFzZWQgb24gdGhlIHNlY29uZHMgc2luY2UgbW'
    b'lkbmlnaHQuClNlcmlhbGl6ZWQgZmlsZSBuYW1lcyB1c2UgdGhlIHNwZWNpZmllZCBkaXJl'
    b'Y3RvcnkgYW5kIGZpbGUgbmFtZSBwcmVmaXgsIGZvbGxvd2VkIGJ5IGEgbnVtYmVyLiAKTn'
    b'VtYmVyIGlzIHJlc2V0IHdoZW4gZGlyZWN0b3J5IG9yIHByZWZpeCBjaGFuZ2VzLkEHjVAF'
    b'ilRpbWUgQmFzZWRBB41QBYpTZXJpYWxpemVkQAdAqVAFi0J1dHRvbiBNb2RlUAGDEP9/UQ'
    b'GBAFAVv09uZSBTZWNvbmQgUHJlc3Mgd2lsbCBkaXNhYmxlIDMtc2Vjb25kIHByZXNzIGZv'
    b'ciBiYXR0ZXJ5IGNoZWNrLkEHl1AFlEltbWVkaWF0ZSBTdGFydC9TdG9wQQeiUAWfT25lIF'
    b'NlY29uZCBQcmVzcyBmb3IgU3RhcnQvU3RvcEEHjVAFilN0YXJ0LU9ubHlAF0EUUAWOUGx1'
    b'Zy1JbiBBY3Rpb25QAYMK/39RAYEBUBWtU2V0IGFjdGlvbiBmb3IgZGV2aWNlIHdoZW4gcG'
    b'x1Z2dlZCBpbiB0byBVU0IuQQe1UAWySW1tZWRpYXRlbHkgc3RvcCByZWNvcmRpbmcgYW5k'
    b'IGFwcGVhciBhcyBVU0IgZHJpdmVBB7NQBbBDb21wbGV0ZSByZWNvcmRpbmcgYmVmb3JlIG'
    b'FwcGVhcmluZyBhcyBVU0IgZHJpdmVBB7BQBa1JZ25vcmU6IHN0b3AgcmVjb3JkaW5nIHdo'
    b'ZW4gYnV0dG9uIGlzIHByZXNzZWRBB6VQBaJTdGFydCByZWNvcmRpbmcgd2hlbiBVU0IgY2'
    b'9ubmVjdGVkQCPnUAGDC/9/UBXeRW50ZXIgbG9jYWwgdGltZXpvbmUncyBvZmZzZXQgZnJv'
    b'bSBVVEMgdGltZS4gSW1wYWN0cyB0aW1lc3RhbXAgaW5mb3JtYXRpb24gb24gcmVjb3JkaW'
    b'5nIGZpbGVzLkAvgEAPgEBPgEAoSOdQBYhUcmlnZ2Vyc0AHQNpQBYxUcmlnZ2VyIE1vZGVQ'
    b'AYMS/39RAYEAUBVAj0RlbGF5IFRoZW4gVHJpZ2dlcjogV2FpdCBzcGVjaWZpZWQgdGltZS'
    b'wgdGhlbiB3YWl0IGZvciB0cmlnZ2VyCkRlbGF5IE9yIFRyaWdnZXI6IEFjcXVpcmUgYWZ0'
    b'ZXIgd2FpdCBvciBvbiB0cmlnZ2VyLiBCYXR0ZXJ5IGxpZmUgbWF5IGJlIHJlZHVjZWQuQQ'
    b'eVUAWSRGVsYXkgVGhlbiBUcmlnZ2VyQQeTUAWQRGVsYXkgT3IgVHJpZ2dlckAy9FAFjVN0'
    b'YXJ0IGF0IFRpbWVQAYMP/39QFdtXYWl0IHVudGlsIHNldCB0aW1lIGJlZm9yZSBldmFsdW'
    b'F0aW5nIG90aGVyIHRyaWdnZXIgY29uZGl0aW9ucywgaW5jbHVkaW5nIGEgcmVjb3JkaW5n'
    b'IGRlbGF5QBGuUAWUUmVjb3JkaW5nIFRpbWUgTGltaXRQAYMN/39RIYT////wUCWHU2Vjb2'
    b'5kc0ARQJBQBZhSZWNvcmRpbmcgRGVsYXkvSW50ZXJ2YWxQAYMM/39RAYEAUCWHU2Vjb25k'
    b'c1EhgwFRgFAV2FRpbWUgYmVmb3JlIHN0YXJ0aW5nIGEgcmVjb3JkaW5nLCBhbmQgdGltZS'
    b'BiZXR3ZWVuIHJlY29yZGluZ3MgaWYgJ1JldHJpZ2dlcicgaXMgY2hlY2tlZC5AEa9QBZlS'
    b'ZWNvcmRpbmcgRmlsZSBTaXplIExpbWl0UAGDEf9/USGE////8FAlg0tpQkAQQJdQBYlSZX'
    b'RyaWdnZXJQAYMO/39QFLBDb25maWdbMHhERkY3Rl09PW51bGwgYW5kIENvbmZpZ1sweDEx'
    b'RkY3Rl09PW51bGxQFc9XaGVuIHNldCwgU2xhbSBTdGljayB3aWxsIHJlLWFybSBhZnRlci'
    b'ByZWNvcmRpbmcgdGltZSBvciBzaXplIGxpbWl0IGlzIHJlYWNoZWQuQBBAqFAFnldhaXQg'
    b'Zm9yIEFsbCBTZW5zb3IgQ29uZGl0aW9uc1ABgxP/f1AV/ldoZW4gc2V0LCByZWNvcmRpbm'
    b'cgd2lsbCBvbmx5IHN0YXJ0IHdoZW4gYWxsIHRyaWdnZXJzIGFyZSBtZXQsIG90aGVyd2lz'
    b'ZSByZWNvcmRpbmcgd2lsbCBzdGFydCB3aGVuIGFueSBzZW5zb3IgY29uZGl0aW9uIGlzIG'
    b'1ldEAYQO5QBZBQcmVzc3VyZSBUcmlnZ2VyUAGDBQAkUQCBAECC5VAFlVByZXNzdXJlIFRy'
    b'aWdnZXIsIExvd1ABgwMAJFEBgwFfkFAlglBhUSGDAdTAUBWzU2V0IHRvIHN0YXJ0IHNhbX'
    b'BsaW5nIHdoZW4gb3V0c2lkZSBwcmVzc3VyZSB3aW5kb3cuQILmUAWWUHJlc3N1cmUgVHJp'
    b'Z2dlciwgSGlnaFABgwQAJFEBgwGtsFAlglBhUSGDAdTAUBWzU2V0IHRvIHN0YXJ0IHNhbX'
    b'BsaW5nIHdoZW4gb3V0c2lkZSBwcmVzc3VyZSB3aW5kb3cuQBhA+1AFk1RlbXBlcmF0dXJl'
    b'IFRyaWdnZXJQAYMFASRRAIEAQGPqUAWYVGVtcGVyYXR1cmUgVHJpZ2dlciwgTG93UAGDAw'
    b'EkUQKB9lAlgUNREoHYUSKBUFAVtlNldCB0byBzdGFydCBzYW1wbGluZyB3aGVuIG91dHNp'
    b'ZGUgdGVtcGVyYXR1cmUgd2luZG93LkBj61AFmVRlbXBlcmF0dXJlIFRyaWdnZXIsIEhpZ2'
    b'hQAYMEASRRAoEjUCWBQ1ESgdhRIoFQUBW2U2V0IHRvIHN0YXJ0IHNhbXBsaW5nIHdoZW4g'
    b'b3V0c2lkZSB0ZW1wZXJhdHVyZSB3aW5kb3cuQBhBp1AFmkFjY2VsZXJhdGlvbiBUcmlnZ2'
    b'VyICgyNWcpUAGDBf8IUBGDB/8gUQCBAFAkgFAUlUNvbmZpZ1sweDAxRkYwOF0gPT0gMEBD'
    b'QKtRE4jAOQAAAAAAAFEjiEA5AAAAAAAAUAWZQWNjZWxlcmF0aW9uIFRyaWdnZXIsIExvd1'
    b'ABgwP/CFECgvmaUBXgSGlnaCBwb3dlciB0cmlnZ2VyIHdpdGggcHJlLXRyaWdnZXIgZGF0'
    b'YS4gTm90IHJlY29tbWVuZGVkIGZvciBsb25nIHdhaXRzIHdpdGhvdXQgZXh0ZXJuYWwgcG'
    b'93ZXIuUgOIP0kAGQAZABlAQ0CsUROIwDkAAAAAAABRI4hAOQAAAAAAAFAFmkFjY2VsZXJh'
    b'dGlvbiBUcmlnZ2VyLCBIaWdoUAGDBP8IUQKCBmZQFeBIaWdoIHBvd2VyIHRyaWdnZXIgd2'
    b'l0aCBwcmUtdHJpZ2dlciBkYXRhLiBOb3QgcmVjb21tZW5kZWQgZm9yIGxvbmcgd2FpdHMg'
    b'd2l0aG91dCBleHRlcm5hbCBwb3dlci5SA4g/SQAZABkAGUAYQaNQBZpBY2NlbGVyYXRpb2'
    b'4gVHJpZ2dlciAoNDBnKVABgwf/UFAV1ExvdyBwb3dlciB0cmlnZ2VyIHVzaW5nIGRpZ2l0'
    b'YWwgYWNjZWxlcm9tZXRlciB3aXRoIERDIHJlc3BvbnNlLiBObyBwcmUtdHJpZ2dlciBkYX'
    b'RhLlEAgQBQEYMF/whQEYMH/yBQJIBQFJRDb25maWdbMHgxZmY1MF0gPT0gMEBDQLJQBZZB'
    b'Y2NlbGVyYXRpb24gVGhyZXNob2xkUAGDBP9QUQGCIABSA4g/RAAUABQAFFEjiEBEAAAAAA'
    b'AAUROAUBXyTG93IHBvd2VyIHRyaWdnZXIuIFRoZSBtaW5pbXVtIGFjY2VsZXJhdGlvbiAo'
    b'cG9zaXRpdmUgb3IgbmVnYXRpdmUpIHRvIHRyaWdnZXIgYSByZWNvcmRpbmcuIE11c3QgYm'
    b'UgZ3JlYXRlciB0aGFuIDAuQCfGUAGDBf9QUQGBB0EHkVAFjlggQXhpcyBUcmlnZ2VyQQeR'
    b'UAWOWSBBeGlzIFRyaWdnZXJBB5FQBY5aIEF4aXMgVHJpZ2dlckAPgEBPgEAoRvZQBYxNZW'
    b'FzdXJlbWVudHNACEJAUAWXMjVnIEFjY2VsZXJhdGlvbiAoQ2ggOClQJIBAJ0CBUQGBB1AB'
    b'gwH/CFAVoEVuYWJsZS9EaXNhYmxlIGFjY2VsZXJhdGlvbiBheGVzQQeZUAWWRW5hYmxlIF'
    b'ggQXhpcyAoQ2ggOC4wKUEHmVAFlkVuYWJsZSBZIEF4aXMgKENoIDguMSlBB5lQBZZFbmFi'
    b'bGUgWiBBeGlzIChDaCA4LjIpQBFAmlAFi1NhbXBsZSBSYXRlUAGDAv8IUBXYU2V0IG1haW'
    b'4gYWNjZWxlcmF0aW9uIHNhbXBsZSByYXRlIGZyb20gMTAgdG8gMjAwMDAgSHouCkhpZ2hl'
    b'ciByYXRlIHJlZHVjZXMgYmF0dGVyeSBsaWZlLlAUlUNvbmZpZ1sweDAxRkYwOF0gPT0gMF'
    b'EBghOIUCWCSHpREYEKUSGCTiBAEUD8UAWjT3ZlcnJpZGUgQW50aWFsaWFzaW5nIEZpbHRl'
    b'ciBDdXRvZmZQAYMI/whRAYID6FAlgkh6USGCYahQFUClRGVmYXVsdCwgd2hlbiBub3QgY2'
    b'hlY2tlZCwgb2Ygb25lLWZpZnRoIHNhbXBsZSBmcmVxdWVuY3kuIEN1dC1vZmYgZnJlcXVl'
    b'bmN5IGhhcyAyOSUgYXR0ZW51YXRpb24uCjV0aCBvcmRlciBCdXR0ZXJ3b3J0aC4gU29tZS'
    b'BhdHRlbnVhdGlvbiBhdCA2MCUgb2YgY3V0LW9mZiBmcmVxdWVuY3kuUBSVQ29uZmlnWzB4'
    b'MDFGRjA4XSA9PSAwQAhBHFAFmzQwZyBEQyBBY2NlbGVyYXRpb24gKENoIDgwKUAnn1ABgw'
    b'H/UFEBgQFBB5JQBY9FbmFibGUgQWxsIEF4ZXNAF0DYUAWLU2FtcGxlIFJhdGVQAYMC/1BR'
    b'AYIB9FAlgkh6UBXeTG93IHBhc3MgZmlsdGVyIGlzIHNldCB0byAyNSUgb2YgZGF0YSByYX'
    b'RlLCBzbyBhIGRhdGEgcmF0ZSBvZiAyMDAwSHogaGFzIGEgTFAgZmlsdGVyIGF0IDUwMCBI'
    b'elAUk25vdCBDb25maWdbMHgxZmY1MF1BB4VRAYIPoEEHhVEBggfQQQeFUQGCA+hBB4VRAY'
    b'IB9EEHhFEBgfpBB4RRAYF9QQeEUQGBP0EHhFEBgSBBB4RRAYEQQAhBMFAFqENvbnRyb2wg'
    b'UGFkIFRlbXBlcmF0dXJlL1ByZXNzdXJlIChDaCA1OSlAJ0CbUQGBA1ABgwH/O1AVpUVuYW'
    b'JsZS9EaXNhYmxlIHNlbnNvcnMgb24gY29udHJvbCBwYWRBB5xQBZlFbmFibGUgUHJlc3N1'
    b'cmUgKENoIDU5LjApQQefUAWcRW5hYmxlIFRlbXBlcmF0dXJlIChDaCA1OS4xKUEHpVAFok'
    b'VuYWJsZSBSZWxhdGl2ZSBIdW1pZGl0eSAoQ2ggNTkuMilAEeNQBYtTYW1wbGUgUmF0ZVAB'
    b'gwL/O1AUlENvbmZpZ1sweDFmZjNCXSA9PSAwUBWkU2V0IHNhbXBsZSBmcmVxdWVuY3kgZn'
    b'JvbSAxIHRvIDEwIEh6UQGBClAlgkh6URGBAVEhgQpACEHNUAWZSW5lcnRpYWwgTWVhc3Vy'
    b'ZW1lbnQgVW5pdEAHQJZQBZBBY3F1aXNpdGlvbiBNb2RlUAGDAf8rUCWBIFEBgRBBB4pQBY'
    b'NPZmZRAYEAQQeoUAWhQWJzb2x1dGUgT3JpZW50YXRpb24gKFF1YXRlcm5pb24pUQGBCEEH'
    b'qFAFoVJlbGF0aXZlIE9yaWVudGF0aW9uIChRdWF0ZXJuaW9uKVEBgRBBB49QBYhSb3RhdG'
    b'lvblEBgQJAAUCGUAWVT3JpZW50YXRpb24gRGF0YSBSYXRlUAGDAggrUQGBZFAlgkh6URGB'
    b'AVEhgchQFb1TYW1wbGUgcmF0ZSBmb3IgZGlyZWN0aW9uYWwgZGF0YSBmcm9tIDEgdG8gMj'
    b'AwIEh6LiBDaGFubmVsIDY1UBSUQ29uZmlnWzB4MDFGRjJCXSA8IDhAAUCJUAWSUm90YXRp'
    b'b24gRGF0YSBSYXRlUAGDAgIrUQGBZFAlgkh6URGBAVEhgchQFb5TZXQgc2FtcGxlIHJhdG'
    b'UgZm9yIHJvdGF0aW9uIGRhdGEgZnJvbSAxIHRvIDIwMCBIei4gQ2hhbm5lbCA0N1AUmUNv'
    b'bmZpZ1sweDAxRkYyQl0gJiAyID09IDBACPVQBaBDb250cm9sIFBhZCBMaWdodCBTZW5zb3'
    b'IgKENoIDc2KUAnz1ABgwH/TFAVo0VuYWJsZS9EaXNhYmxlIGxpZ2h0IHNlbnNvciBhdCA0'
    b'IEh6QQegUAWdRW5hYmxlIExpZ2h0IFNlbnNvciAoQ2ggNzYuMClAD4BAT4BKCIBKKIBKSI'
    b'A='
)
