"""
Default ConfigUI for S4-E2000D40 data recorders 
"""

from base64 import b64decode

DEFAULT_CONFIG_UI = b64decode(
    b'd3dWPkAoRjBQBYdHZW5lcmFsQAXzUAWLRGV2aWNlIE5hbWVQAYMI/39RJIFAUBXYQSBjdX'
    b'N0b20gbmFtZSBmb3IgdGhlIHJlY29yZGVyLiBOb3QgdGhlIHNhbWUgYXMgdGhlIHZvbHVt'
    b'ZSBsYWJlbC4gNjQgY2hhcmFjdGVycyBtYXhpbXVtLkAF81AFjERldmljZSBOb3Rlc1ABgw'
    b'n/f1EkggEAUBXSQ3VzdG9tIG5vdGVzIGFib3V0IHRoZSByZWNvcmRlciAocG9zaXRpb24s'
    b'IHVzZXIgSUQsIGV0Yy4pLiAyNTYgY2hhcmFjdGVycyBtYXhpbXVtLlE0gQNABUCZUAWVQ3'
    b'VzdG9tIFJlY29yZGluZyBUYWdzUAGDF/9/UQSAUSSBQFAV8UtleXdvcmRzIGZvciBvcmdh'
    b'bml6aW5nIGFuZCBpZGVudGlmeWluZyByZWNvcmRpbmdzLCBzZXBhcmF0ZWQgYnkgY29tbW'
    b'Egb3Igc3BhY2UuIExpbWl0IGlzIDIwIHRhZ3MsIDY0IGNoYXJhY3RlcnMuQAX7UAWTUmVj'
    b'b3JkaW5nIERpcmVjdG9yeVABgxT/f1EEhlJFQ09SRFEkgRBQFJNDb25maWdbMHgxNkZGN0'
    b'ZdPT0wUBW5RGlyZWN0b3J5IGZvciBzZXJpYWxpemVkIHJlY29yZGluZ3MuIDE2IGNoYXJh'
    b'Y3RlciBtYXhpbXVtQAVAo1AFlVJlY29yZGluZyBGaWxlIFByZWZpeFABgxX/f1EkgRBQFe'
    b'hQcmVmaXggZm9yIHNlcmlhbGl6ZWQgcmVjb3JkaW5nIG5hbWVzLiBJZiBibGFuaywgZGV2'
    b'aWNlIHNlcmlhbCBudW1iZXIgd2lsbCBiZSB1c2VkLiAxNiBjaGFyYWN0ZXIgbWF4aW11bV'
    b'AUk0NvbmZpZ1sweDE2RkY3Rl09PTBAB0E8UAWPRmlsZSBOYW1lIFN0eWxlUAGDFv9/UQGB'
    b'AVAVQPxUaW1lLUJhc2VkIGZpbGUgbmFtZXMgdXNlIGEgZGlyZWN0b3J5IGJhc2VkIG9uIH'
    b'RoZSBkYXRlLCBhbmQgZmlsZSBuYW1lIGJhc2VkIG9uIHRoZSBzZWNvbmRzIHNpbmNlIG1p'
    b'ZG5pZ2h0LgpTZXJpYWxpemVkIGZpbGUgbmFtZXMgdXNlIHRoZSBzcGVjaWZpZWQgZGlyZW'
    b'N0b3J5IGFuZCBmaWxlIG5hbWUgcHJlZml4LCBmb2xsb3dlZCBieSBhIG51bWJlci4gCk51'
    b'bWJlciBpcyByZXNldCB3aGVuIGRpcmVjdG9yeSBvciBwcmVmaXggY2hhbmdlcy5BB41QBY'
    b'pUaW1lIEJhc2VkQQeNUAWKU2VyaWFsaXplZEAHQKlQBYtCdXR0b24gTW9kZVABgxD/f1EB'
    b'gQBQFb9PbmUgU2Vjb25kIFByZXNzIHdpbGwgZGlzYWJsZSAzLXNlY29uZCBwcmVzcyBmb3'
    b'IgYmF0dGVyeSBjaGVjay5BB5dQBZRJbW1lZGlhdGUgU3RhcnQvU3RvcEEHolAFn09uZSBT'
    b'ZWNvbmQgUHJlc3MgZm9yIFN0YXJ0L1N0b3BBB41QBYpTdGFydC1Pbmx5QBdBFFAFjlBsdW'
    b'ctSW4gQWN0aW9uUAGDCv9/UQGBAVAVrVNldCBhY3Rpb24gZm9yIGRldmljZSB3aGVuIHBs'
    b'dWdnZWQgaW4gdG8gVVNCLkEHtVAFskltbWVkaWF0ZWx5IHN0b3AgcmVjb3JkaW5nIGFuZC'
    b'BhcHBlYXIgYXMgVVNCIGRyaXZlQQezUAWwQ29tcGxldGUgcmVjb3JkaW5nIGJlZm9yZSBh'
    b'cHBlYXJpbmcgYXMgVVNCIGRyaXZlQQewUAWtSWdub3JlOiBzdG9wIHJlY29yZGluZyB3aG'
    b'VuIGJ1dHRvbiBpcyBwcmVzc2VkQQelUAWiU3RhcnQgcmVjb3JkaW5nIHdoZW4gVVNCIGNv'
    b'bm5lY3RlZEAj51ABgwv/f1AV3kVudGVyIGxvY2FsIHRpbWV6b25lJ3Mgb2Zmc2V0IGZyb2'
    b'0gVVRDIHRpbWUuIEltcGFjdHMgdGltZXN0YW1wIGluZm9ybWF0aW9uIG9uIHJlY29yZGlu'
    b'ZyBmaWxlcy5AL4BAD4BAT4BAKEjpUAWIVHJpZ2dlcnNAB0DaUAWMVHJpZ2dlciBNb2RlUA'
    b'GDEv9/UQGBAFAVQI9EZWxheSBUaGVuIFRyaWdnZXI6IFdhaXQgc3BlY2lmaWVkIHRpbWUs'
    b'IHRoZW4gd2FpdCBmb3IgdHJpZ2dlcgpEZWxheSBPciBUcmlnZ2VyOiBBY3F1aXJlIGFmdG'
    b'VyIHdhaXQgb3Igb24gdHJpZ2dlci4gQmF0dGVyeSBsaWZlIG1heSBiZSByZWR1Y2VkLkEH'
    b'lVAFkkRlbGF5IFRoZW4gVHJpZ2dlckEHk1AFkERlbGF5IE9yIFRyaWdnZXJAMvRQBY1TdG'
    b'FydCBhdCBUaW1lUAGDD/9/UBXbV2FpdCB1bnRpbCBzZXQgdGltZSBiZWZvcmUgZXZhbHVh'
    b'dGluZyBvdGhlciB0cmlnZ2VyIGNvbmRpdGlvbnMsIGluY2x1ZGluZyBhIHJlY29yZGluZy'
    b'BkZWxheUARrlAFlFJlY29yZGluZyBUaW1lIExpbWl0UAGDDf9/USGE////8FAlh1NlY29u'
    b'ZHNAEUCQUAWYUmVjb3JkaW5nIERlbGF5L0ludGVydmFsUAGDDP9/UQGBAFAlh1NlY29uZH'
    b'NRIYMBUYBQFdhUaW1lIGJlZm9yZSBzdGFydGluZyBhIHJlY29yZGluZywgYW5kIHRpbWUg'
    b'YmV0d2VlbiByZWNvcmRpbmdzIGlmICdSZXRyaWdnZXInIGlzIGNoZWNrZWQuQBGvUAWZUm'
    b'Vjb3JkaW5nIEZpbGUgU2l6ZSBMaW1pdFABgxH/f1EhhP////BQJYNLaUJAEECXUAWJUmV0'
    b'cmlnZ2VyUAGDDv9/UBSwQ29uZmlnWzB4REZGN0ZdPT1udWxsIGFuZCBDb25maWdbMHgxMU'
    b'ZGN0ZdPT1udWxsUBXPV2hlbiBzZXQsIFNsYW0gU3RpY2sgd2lsbCByZS1hcm0gYWZ0ZXIg'
    b'cmVjb3JkaW5nIHRpbWUgb3Igc2l6ZSBsaW1pdCBpcyByZWFjaGVkLkAQQKhQBZ5XYWl0IG'
    b'ZvciBBbGwgU2Vuc29yIENvbmRpdGlvbnNQAYMT/39QFf5XaGVuIHNldCwgcmVjb3JkaW5n'
    b'IHdpbGwgb25seSBzdGFydCB3aGVuIGFsbCB0cmlnZ2VycyBhcmUgbWV0LCBvdGhlcndpc2'
    b'UgcmVjb3JkaW5nIHdpbGwgc3RhcnQgd2hlbiBhbnkgc2Vuc29yIGNvbmRpdGlvbiBpcyBt'
    b'ZXRAGEDuUAWQUHJlc3N1cmUgVHJpZ2dlclABgwUAJFEAgQBAguVQBZVQcmVzc3VyZSBUcm'
    b'lnZ2VyLCBMb3dQAYMDACRRAYMBX5BQJYJQYVEhgwHUwFAVs1NldCB0byBzdGFydCBzYW1w'
    b'bGluZyB3aGVuIG91dHNpZGUgcHJlc3N1cmUgd2luZG93LkCC5lAFllByZXNzdXJlIFRyaW'
    b'dnZXIsIEhpZ2hQAYMEACRRAYMBrbBQJYJQYVEhgwHUwFAVs1NldCB0byBzdGFydCBzYW1w'
    b'bGluZyB3aGVuIG91dHNpZGUgcHJlc3N1cmUgd2luZG93LkAYQPtQBZNUZW1wZXJhdHVyZS'
    b'BUcmlnZ2VyUAGDBQEkUQCBAEBj6lAFmFRlbXBlcmF0dXJlIFRyaWdnZXIsIExvd1ABgwMB'
    b'JFECgfZQJYFDURKB2FEigVBQFbZTZXQgdG8gc3RhcnQgc2FtcGxpbmcgd2hlbiBvdXRzaW'
    b'RlIHRlbXBlcmF0dXJlIHdpbmRvdy5AY+tQBZlUZW1wZXJhdHVyZSBUcmlnZ2VyLCBIaWdo'
    b'UAGDBAEkUQKBI1AlgUNREoHYUSKBUFAVtlNldCB0byBzdGFydCBzYW1wbGluZyB3aGVuIG'
    b'91dHNpZGUgdGVtcGVyYXR1cmUgd2luZG93LkAYQalQBZxBY2NlbGVyYXRpb24gVHJpZ2dl'
    b'ciAoMjAwMGcpUAGDBf8IUBGDB/8gUQCBAFAkgFAUlUNvbmZpZ1sweDAxRkYwOF0gPT0gME'
    b'BDQKtQBZlBY2NlbGVyYXRpb24gVHJpZ2dlciwgTG93UAGDA/8IUQKC+ZpRE4jAn0AAAAAA'
    b'AFEjiECfQAAAAAAAUBXgSGlnaCBwb3dlciB0cmlnZ2VyIHdpdGggcHJlLXRyaWdnZXIgZG'
    b'F0YS4gTm90IHJlY29tbWVuZGVkIGZvciBsb25nIHdhaXRzIHdpdGhvdXQgZXh0ZXJuYWwg'
    b'cG93ZXIuUgOIP69AH0AfSC5AQ0CsUAWaQWNjZWxlcmF0aW9uIFRyaWdnZXIsIEhpZ2hQAY'
    b'ME/whRAoIGZlETiMCfQAAAAAAAUSOIQJ9AAAAAAABQFeBIaWdoIHBvd2VyIHRyaWdnZXIg'
    b'd2l0aCBwcmUtdHJpZ2dlciBkYXRhLiBOb3QgcmVjb21tZW5kZWQgZm9yIGxvbmcgd2FpdH'
    b'Mgd2l0aG91dCBleHRlcm5hbCBwb3dlci5SA4g/r0AfQB9ILkAYQaNQBZpBY2NlbGVyYXRp'
    b'b24gVHJpZ2dlciAoNDBnKVABgwf/UFAV1ExvdyBwb3dlciB0cmlnZ2VyIHVzaW5nIGRpZ2'
    b'l0YWwgYWNjZWxlcm9tZXRlciB3aXRoIERDIHJlc3BvbnNlLiBObyBwcmUtdHJpZ2dlciBk'
    b'YXRhLlEAgQBQEYMF/whQEYMH/yBQJIBQFJRDb25maWdbMHgxZmY1MF0gPT0gMEBDQLJQBZ'
    b'ZBY2NlbGVyYXRpb24gVGhyZXNob2xkUAGDBP9QUQGCIABSA4g/RAAUABQAFFEjiEBEAAAA'
    b'AAAAUROAUBXyTG93IHBvd2VyIHRyaWdnZXIuIFRoZSBtaW5pbXVtIGFjY2VsZXJhdGlvbi'
    b'AocG9zaXRpdmUgb3IgbmVnYXRpdmUpIHRvIHRyaWdnZXIgYSByZWNvcmRpbmcuIE11c3Qg'
    b'YmUgZ3JlYXRlciB0aGFuIDAuQCfGUAGDBf9QUQGBB0EHkVAFjlggQXhpcyBUcmlnZ2VyQQ'
    b'eRUAWOWSBBeGlzIFRyaWdnZXJBB5FQBY5aIEF4aXMgVHJpZ2dlckAPgEBPgEAoRxBQBYxN'
    b'ZWFzdXJlbWVudHNACEI+UAWZMjAwMGcgQWNjZWxlcmF0aW9uIChDaCA4KVAkgEAn/lEBgQ'
    b'dQAYMB/whQFaBFbmFibGUvRGlzYWJsZSBhY2NlbGVyYXRpb24gYXhlc0EHmFAFkUVuYWJs'
    b'ZSBYIChDaCA4LjApUQGBAEEHmFAFkUVuYWJsZSBZIChDaCA4LjEpUQGBAUEHmFAFkUVuYW'
    b'JsZSBaIChDaCA4LjIpUQGBAkARQJpQBYtTYW1wbGUgUmF0ZVABgwL/CFAV2FNldCBtYWlu'
    b'IGFjY2VsZXJhdGlvbiBzYW1wbGUgcmF0ZSBmcm9tIDEwIHRvIDIwMDAwIEh6LgpIaWdoZX'
    b'IgcmF0ZSByZWR1Y2VzIGJhdHRlcnkgbGlmZS5QFJVDb25maWdbMHgwMUZGMDhdID09IDBR'
    b'AYITiFAlgkh6URGBClEhgk4gQBFA/FAFo092ZXJyaWRlIEFudGlhbGlhc2luZyBGaWx0ZX'
    b'IgQ3V0b2ZmUAGDCP8IUQGCA+hQJYJIelEhgmGoUBVApURlZmF1bHQsIHdoZW4gbm90IGNo'
    b'ZWNrZWQsIG9mIG9uZS1maWZ0aCBzYW1wbGUgZnJlcXVlbmN5LiBDdXQtb2ZmIGZyZXF1ZW'
    b'5jeSBoYXMgMjklIGF0dGVudWF0aW9uLgo1dGggb3JkZXIgQnV0dGVyd29ydGguIFNvbWUg'
    b'YXR0ZW51YXRpb24gYXQgNjAlIG9mIGN1dC1vZmYgZnJlcXVlbmN5LlAUlUNvbmZpZ1sweD'
    b'AxRkYwOF0gPT0gMEAIQRxQBZs0MGcgREMgQWNjZWxlcmF0aW9uIChDaCA4MClAJ59QAYMB'
    b'/1BRAYEBQQeSUAWPRW5hYmxlIEFsbCBBeGVzQBdA2FAFi1NhbXBsZSBSYXRlUAGDAv9QUQ'
    b'GCAfRQJYJIelAV3kxvdyBwYXNzIGZpbHRlciBpcyBzZXQgdG8gMjUlIG9mIGRhdGEgcmF0'
    b'ZSwgc28gYSBkYXRhIHJhdGUgb2YgMjAwMEh6IGhhcyBhIExQIGZpbHRlciBhdCA1MDAgSH'
    b'pQFJNub3QgQ29uZmlnWzB4MWZmNTBdQQeFUQGCD6BBB4VRAYIH0EEHhVEBggPoQQeFUQGC'
    b'AfRBB4RRAYH6QQeEUQGBfUEHhFEBgT9BB4RRAYEgQQeEUQGBEEAIQTBQBahDb250cm9sIF'
    b'BhZCBUZW1wZXJhdHVyZS9QcmVzc3VyZSAoQ2ggNTkpQCdAm1EBgQNQAYMB/ztQFaVFbmFi'
    b'bGUvRGlzYWJsZSBzZW5zb3JzIG9uIGNvbnRyb2wgcGFkQQecUAWZRW5hYmxlIFByZXNzdX'
    b'JlIChDaCA1OS4wKUEHn1AFnEVuYWJsZSBUZW1wZXJhdHVyZSAoQ2ggNTkuMSlBB6VQBaJF'
    b'bmFibGUgUmVsYXRpdmUgSHVtaWRpdHkgKENoIDU5LjIpQBHjUAWLU2FtcGxlIFJhdGVQAY'
    b'MC/ztQFJRDb25maWdbMHgxZmYzQl0gPT0gMFAVpFNldCBzYW1wbGUgZnJlcXVlbmN5IGZy'
    b'b20gMSB0byAxMCBIelEBgQpQJYJIelERgQFRIYEKQAhBzVAFmUluZXJ0aWFsIE1lYXN1cm'
    b'VtZW50IFVuaXRAB0CWUAWQQWNxdWlzaXRpb24gTW9kZVABgwH/K1AlgSBRAYEQQQeKUAWD'
    b'T2ZmUQGBAEEHqFAFoUFic29sdXRlIE9yaWVudGF0aW9uIChRdWF0ZXJuaW9uKVEBgQhBB6'
    b'hQBaFSZWxhdGl2ZSBPcmllbnRhdGlvbiAoUXVhdGVybmlvbilRAYEQQQePUAWIUm90YXRp'
    b'b25RAYECQAFAhlAFlU9yaWVudGF0aW9uIERhdGEgUmF0ZVABgwIIK1EBgWRQJYJIelERgQ'
    b'FRIYHIUBW9U2FtcGxlIHJhdGUgZm9yIGRpcmVjdGlvbmFsIGRhdGEgZnJvbSAxIHRvIDIw'
    b'MCBIei4gQ2hhbm5lbCA2NVAUlENvbmZpZ1sweDAxRkYyQl0gPCA4QAFAiVAFklJvdGF0aW'
    b'9uIERhdGEgUmF0ZVABgwICK1EBgWRQJYJIelERgQFRIYHIUBW+U2V0IHNhbXBsZSByYXRl'
    b'IGZvciByb3RhdGlvbiBkYXRhIGZyb20gMSB0byAyMDAgSHouIENoYW5uZWwgNDdQFJlDb2'
    b'5maWdbMHgwMUZGMkJdICYgMiA9PSAwQAhAkFAFoENvbnRyb2wgUGFkIExpZ2h0IFNlbnNv'
    b'ciAoQ2ggNzYpQCfqUAGDAf9MUBW+RW5hYmxlL0Rpc2FibGUgbGlnaHQgc2Vuc29yIGF0ID'
    b'QgSHogLSBOT1RFOiBESVNBQkxFRCBGT1IgQUxQSEFBB6BQBZ1FbmFibGUgTGlnaHQgU2Vu'
    b'c29yIChDaCA3Ni4wKUAPgEBPgEoIgEoogEpIgA=='
)
