"""
Default ConfigUI for W8-E25D40 data recorders 
"""

from base64 import b64decode

DEFAULT_CONFIG_UI = b64decode(
    b'd3dZGkAoSDxQBYdHZW5lcmFsQAXzUAWLRGV2aWNlIE5hbWVQAYMI/39RJIFAUBXYQSBjdX'
    b'N0b20gbmFtZSBmb3IgdGhlIHJlY29yZGVyLiBOb3QgdGhlIHNhbWUgYXMgdGhlIHZvbHVt'
    b'ZSBsYWJlbC4gNjQgY2hhcmFjdGVycyBtYXhpbXVtLkAF81AFjERldmljZSBOb3Rlc1ABgw'
    b'n/f1EkggEAUBXSQ3VzdG9tIG5vdGVzIGFib3V0IHRoZSByZWNvcmRlciAocG9zaXRpb24s'
    b'IHVzZXIgSUQsIGV0Yy4pLiAyNTYgY2hhcmFjdGVycyBtYXhpbXVtLlE0gQNABUCZUAWVQ3'
    b'VzdG9tIFJlY29yZGluZyBUYWdzUAGDF/9/UQSAUSSBQFAV8UtleXdvcmRzIGZvciBvcmdh'
    b'bml6aW5nIGFuZCBpZGVudGlmeWluZyByZWNvcmRpbmdzLCBzZXBhcmF0ZWQgYnkgY29tbW'
    b'Egb3Igc3BhY2UuIExpbWl0IGlzIDIwIHRhZ3MsIDY0IGNoYXJhY3RlcnMuQAX7UAWTUmVj'
    b'b3JkaW5nIERpcmVjdG9yeVABgxT/f1EEhlJFQ09SRFEkgRBQFJNDb25maWdbMHgxNkZGN0'
    b'ZdPT0wUBW5RGlyZWN0b3J5IGZvciBzZXJpYWxpemVkIHJlY29yZGluZ3MuIDE2IGNoYXJh'
    b'Y3RlciBtYXhpbXVtQAVAo1AFlVJlY29yZGluZyBGaWxlIFByZWZpeFABgxX/f1EkgRBQFe'
    b'hQcmVmaXggZm9yIHNlcmlhbGl6ZWQgcmVjb3JkaW5nIG5hbWVzLiBJZiBibGFuaywgZGV2'
    b'aWNlIHNlcmlhbCBudW1iZXIgd2lsbCBiZSB1c2VkLiAxNiBjaGFyYWN0ZXIgbWF4aW11bV'
    b'AUk0NvbmZpZ1sweDE2RkY3Rl09PTBAB0E8UAWPRmlsZSBOYW1lIFN0eWxlUAGDFv9/UQGB'
    b'AVAVQPxUaW1lLUJhc2VkIGZpbGUgbmFtZXMgdXNlIGEgZGlyZWN0b3J5IGJhc2VkIG9uIH'
    b'RoZSBkYXRlLCBhbmQgZmlsZSBuYW1lIGJhc2VkIG9uIHRoZSBzZWNvbmRzIHNpbmNlIG1p'
    b'ZG5pZ2h0LgpTZXJpYWxpemVkIGZpbGUgbmFtZXMgdXNlIHRoZSBzcGVjaWZpZWQgZGlyZW'
    b'N0b3J5IGFuZCBmaWxlIG5hbWUgcHJlZml4LCBmb2xsb3dlZCBieSBhIG51bWJlci4gCk51'
    b'bWJlciBpcyByZXNldCB3aGVuIGRpcmVjdG9yeSBvciBwcmVmaXggY2hhbmdlcy5BB41QBY'
    b'pUaW1lIEJhc2VkQQeNUAWKU2VyaWFsaXplZEAHQKlQBYtCdXR0b24gTW9kZVABgxD/f1EB'
    b'gQBQFb9PbmUgU2Vjb25kIFByZXNzIHdpbGwgZGlzYWJsZSAzLXNlY29uZCBwcmVzcyBmb3'
    b'IgYmF0dGVyeSBjaGVjay5BB5dQBZRJbW1lZGlhdGUgU3RhcnQvU3RvcEEHolAFn09uZSBT'
    b'ZWNvbmQgUHJlc3MgZm9yIFN0YXJ0L1N0b3BBB41QBYpTdGFydC1Pbmx5QBdBFFAFjlBsdW'
    b'ctSW4gQWN0aW9uUAGDCv9/UQGBAVAVrVNldCBhY3Rpb24gZm9yIGRldmljZSB3aGVuIHBs'
    b'dWdnZWQgaW4gdG8gVVNCLkEHtVAFskltbWVkaWF0ZWx5IHN0b3AgcmVjb3JkaW5nIGFuZC'
    b'BhcHBlYXIgYXMgVVNCIGRyaXZlQQezUAWwQ29tcGxldGUgcmVjb3JkaW5nIGJlZm9yZSBh'
    b'cHBlYXJpbmcgYXMgVVNCIGRyaXZlQQewUAWtSWdub3JlOiBzdG9wIHJlY29yZGluZyB3aG'
    b'VuIGJ1dHRvbiBpcyBwcmVzc2VkQQelUAWiU3RhcnQgcmVjb3JkaW5nIHdoZW4gVVNCIGNv'
    b'bm5lY3RlZEAj51ABgwv/f1AV3kVudGVyIGxvY2FsIHRpbWV6b25lJ3Mgb2Zmc2V0IGZyb2'
    b'0gVVRDIHRpbWUuIEltcGFjdHMgdGltZXN0YW1wIGluZm9ybWF0aW9uIG9uIHJlY29yZGlu'
    b'ZyBmaWxlcy5AL4BAGEIIUAWMRW5hYmxlIFdpLUZpUAGDGP9/UQGBAUAn7FABgxn/f1EBgQ'
    b'FBB6lQBaZVcGxvYWQgcmVjb3JkaW5nIHRvIGNsb3VkIGFmdGVyIGZpbmlzaFAVs1NlbGVj'
    b'dCB0byB1cGxvYWQgZWFjaCBmaWxlIHdoZW4gcmVjb3JkaW5nIGNvbXBsZXRlc0AnQLZQAY'
    b'Ma/39RAYEAQQejUAWgRGVsZXRlIGZyb20gc3RvcmFnZSBhZnRlciB1cGxvYWRQFUCCUmVj'
    b'b3JkaW5nIGZpbGUgd2lsbCBiZSBkZWxldGVkIGFmdGVyIGEgc3VjY2Vzc2Z1bCB1cGxvYW'
    b'QsIGFuZCBtb3ZlZCB0byBhIHN1YmZvbGRlciBsYWJlbGVkICdmYWlsZWQnIGluIHRoZSBj'
    b'YXNlIG9mIGEgZmFpbGVkIHVwbG9hZEAnQMJQAYMd/39RAYEAQQepUAWmS2VlcCB0aGUgV2'
    b'ktRmkgbW9kdWxlIG9uIGFuZCBjb25uZWN0ZWRQFUCISWYgY2hlY2tlZCwgdGhlIFdpLUZp'
    b'IG1vZHVsZSB3aWxsIHN0YXkgb24gYW5kIGNvbm5lY3RlZC4gIEFsbG93cyBmb3IgZmFzdG'
    b'VyIHVwbG9hZCB0aW1lcyB3aXRoIHRoZSBleHBlbnNlIG9mIGluY3JlYXNlZCBwb3dlciBj'
    b'b25zdW1wdGlvbkAPgEBPgEAoSOdQBYhUcmlnZ2Vyc0AHQNpQBYxUcmlnZ2VyIE1vZGVQAY'
    b'MS/39RAYEAUBVAj0RlbGF5IFRoZW4gVHJpZ2dlcjogV2FpdCBzcGVjaWZpZWQgdGltZSwg'
    b'dGhlbiB3YWl0IGZvciB0cmlnZ2VyCkRlbGF5IE9yIFRyaWdnZXI6IEFjcXVpcmUgYWZ0ZX'
    b'Igd2FpdCBvciBvbiB0cmlnZ2VyLiBCYXR0ZXJ5IGxpZmUgbWF5IGJlIHJlZHVjZWQuQQeV'
    b'UAWSRGVsYXkgVGhlbiBUcmlnZ2VyQQeTUAWQRGVsYXkgT3IgVHJpZ2dlckAy9FAFjVN0YX'
    b'J0IGF0IFRpbWVQAYMP/39QFdtXYWl0IHVudGlsIHNldCB0aW1lIGJlZm9yZSBldmFsdWF0'
    b'aW5nIG90aGVyIHRyaWdnZXIgY29uZGl0aW9ucywgaW5jbHVkaW5nIGEgcmVjb3JkaW5nIG'
    b'RlbGF5QBGuUAWUUmVjb3JkaW5nIFRpbWUgTGltaXRQAYMN/39RIYT////wUCWHU2Vjb25k'
    b'c0ARQJBQBZhSZWNvcmRpbmcgRGVsYXkvSW50ZXJ2YWxQAYMM/39RAYEAUCWHU2Vjb25kc1'
    b'EhgwFRgFAV2FRpbWUgYmVmb3JlIHN0YXJ0aW5nIGEgcmVjb3JkaW5nLCBhbmQgdGltZSBi'
    b'ZXR3ZWVuIHJlY29yZGluZ3MgaWYgJ1JldHJpZ2dlcicgaXMgY2hlY2tlZC5AEa9QBZlSZW'
    b'NvcmRpbmcgRmlsZSBTaXplIExpbWl0UAGDEf9/USGE////8FAlg0tpQkAQQJdQBYlSZXRy'
    b'aWdnZXJQAYMO/39QFLBDb25maWdbMHhERkY3Rl09PW51bGwgYW5kIENvbmZpZ1sweDExRk'
    b'Y3Rl09PW51bGxQFc9XaGVuIHNldCwgU2xhbSBTdGljayB3aWxsIHJlLWFybSBhZnRlciBy'
    b'ZWNvcmRpbmcgdGltZSBvciBzaXplIGxpbWl0IGlzIHJlYWNoZWQuQBBAqFAFnldhaXQgZm'
    b'9yIEFsbCBTZW5zb3IgQ29uZGl0aW9uc1ABgxP/f1AV/ldoZW4gc2V0LCByZWNvcmRpbmcg'
    b'd2lsbCBvbmx5IHN0YXJ0IHdoZW4gYWxsIHRyaWdnZXJzIGFyZSBtZXQsIG90aGVyd2lzZS'
    b'ByZWNvcmRpbmcgd2lsbCBzdGFydCB3aGVuIGFueSBzZW5zb3IgY29uZGl0aW9uIGlzIG1l'
    b'dEAYQO5QBZBQcmVzc3VyZSBUcmlnZ2VyUAGDBQAkUQCBAECC5VAFlVByZXNzdXJlIFRyaW'
    b'dnZXIsIExvd1ABgwMAJFEBgwFfkFAlglBhUSGDAdTAUBWzU2V0IHRvIHN0YXJ0IHNhbXBs'
    b'aW5nIHdoZW4gb3V0c2lkZSBwcmVzc3VyZSB3aW5kb3cuQILmUAWWUHJlc3N1cmUgVHJpZ2'
    b'dlciwgSGlnaFABgwQAJFEBgwGtsFAlglBhUSGDAdTAUBWzU2V0IHRvIHN0YXJ0IHNhbXBs'
    b'aW5nIHdoZW4gb3V0c2lkZSBwcmVzc3VyZSB3aW5kb3cuQBhA+1AFk1RlbXBlcmF0dXJlIF'
    b'RyaWdnZXJQAYMFASRRAIEAQGPqUAWYVGVtcGVyYXR1cmUgVHJpZ2dlciwgTG93UAGDAwEk'
    b'UQKB9lAlgUNREoHYUSKBUFAVtlNldCB0byBzdGFydCBzYW1wbGluZyB3aGVuIG91dHNpZG'
    b'UgdGVtcGVyYXR1cmUgd2luZG93LkBj61AFmVRlbXBlcmF0dXJlIFRyaWdnZXIsIEhpZ2hQ'
    b'AYMEASRRAoEjUCWBQ1ESgdhRIoFQUBW2U2V0IHRvIHN0YXJ0IHNhbXBsaW5nIHdoZW4gb3'
    b'V0c2lkZSB0ZW1wZXJhdHVyZSB3aW5kb3cuQBhBp1AFmkFjY2VsZXJhdGlvbiBUcmlnZ2Vy'
    b'ICgyNWcpUAGDBf8IUBGDB/8gUQCBAFAkgFAUlUNvbmZpZ1sweDAxRkYwOF0gPT0gMEBDQK'
    b'tRE4jAOQAAAAAAAFEjiEA5AAAAAAAAUAWZQWNjZWxlcmF0aW9uIFRyaWdnZXIsIExvd1AB'
    b'gwP/CFECgvmaUBXgSGlnaCBwb3dlciB0cmlnZ2VyIHdpdGggcHJlLXRyaWdnZXIgZGF0YS'
    b'4gTm90IHJlY29tbWVuZGVkIGZvciBsb25nIHdhaXRzIHdpdGhvdXQgZXh0ZXJuYWwgcG93'
    b'ZXIuUgOIP0kAGQAZABlAQ0CsUROIwDkAAAAAAABRI4hAOQAAAAAAAFAFmkFjY2VsZXJhdG'
    b'lvbiBUcmlnZ2VyLCBIaWdoUAGDBP8IUQKCBmZQFeBIaWdoIHBvd2VyIHRyaWdnZXIgd2l0'
    b'aCBwcmUtdHJpZ2dlciBkYXRhLiBOb3QgcmVjb21tZW5kZWQgZm9yIGxvbmcgd2FpdHMgd2'
    b'l0aG91dCBleHRlcm5hbCBwb3dlci5SA4g/SQAZABkAGUAYQaNQBZpBY2NlbGVyYXRpb24g'
    b'VHJpZ2dlciAoNDBnKVABgwf/UFAV1ExvdyBwb3dlciB0cmlnZ2VyIHVzaW5nIGRpZ2l0YW'
    b'wgYWNjZWxlcm9tZXRlciB3aXRoIERDIHJlc3BvbnNlLiBObyBwcmUtdHJpZ2dlciBkYXRh'
    b'LlEAgQBQEYMF/whQEYMH/yBQJIBQFJRDb25maWdbMHgxZmY1MF0gPT0gMEBDQLJQBZZBY2'
    b'NlbGVyYXRpb24gVGhyZXNob2xkUAGDBP9QUQGCIABSA4g/RAAUABQAFFEjiEBEAAAAAAAA'
    b'UROAUBXyTG93IHBvd2VyIHRyaWdnZXIuIFRoZSBtaW5pbXVtIGFjY2VsZXJhdGlvbiAocG'
    b'9zaXRpdmUgb3IgbmVnYXRpdmUpIHRvIHRyaWdnZXIgYSByZWNvcmRpbmcuIE11c3QgYmUg'
    b'Z3JlYXRlciB0aGFuIDAuQCfGUAGDBf9QUQGBB0EHkVAFjlggQXhpcyBUcmlnZ2VyQQeRUA'
    b'WOWSBBeGlzIFRyaWdnZXJBB5FQBY5aIEF4aXMgVHJpZ2dlckAPgEBPgEAoR+JQBYxNZWFz'
    b'dXJlbWVudHNACEJaUAWXMjVnIEFjY2VsZXJhdGlvbiAoQ2ggOClQJIBAJ0CbUQGBD1ABgw'
    b'H/CFAVoEVuYWJsZS9EaXNhYmxlIGFjY2VsZXJhdGlvbiBheGVzQQeYUAWRRW5hYmxlIFgg'
    b'KENoIDguMClRAYEAQQeYUAWRRW5hYmxlIFkgKENoIDguMSlRAYEBQQeYUAWRRW5hYmxlIF'
    b'ogKENoIDguMilRAYECQQeaUAWTRW5hYmxlIE1pYyAoQ2ggOC4zKVEBgQNAEUCaUAWLU2Ft'
    b'cGxlIFJhdGVQAYMC/whQFdhTZXQgbWFpbiBhY2NlbGVyYXRpb24gc2FtcGxlIHJhdGUgZn'
    b'JvbSAxMCB0byAyMDAwMCBIei4KSGlnaGVyIHJhdGUgcmVkdWNlcyBiYXR0ZXJ5IGxpZmUu'
    b'UBSVQ29uZmlnWzB4MDFGRjA4XSA9PSAwUQGCE4hQJYJIelERgQpRIYJOIEARQPxQBaNPdm'
    b'VycmlkZSBBbnRpYWxpYXNpbmcgRmlsdGVyIEN1dG9mZlABgwj/CFEBggPoUCWCSHpRIYJh'
    b'qFAVQKVEZWZhdWx0LCB3aGVuIG5vdCBjaGVja2VkLCBvZiBvbmUtZmlmdGggc2FtcGxlIG'
    b'ZyZXF1ZW5jeS4gQ3V0LW9mZiBmcmVxdWVuY3kgaGFzIDI5JSBhdHRlbnVhdGlvbi4KNXRo'
    b'IG9yZGVyIEJ1dHRlcndvcnRoLiBTb21lIGF0dGVudWF0aW9uIGF0IDYwJSBvZiBjdXQtb2'
    b'ZmIGZyZXF1ZW5jeS5QFJVDb25maWdbMHgwMUZGMDhdID09IDBACEEcUAWbNDBnIERDIEFj'
    b'Y2VsZXJhdGlvbiAoQ2ggODApQCefUAGDAf9QUQGBAUEHklAFj0VuYWJsZSBBbGwgQXhlc0'
    b'AXQNhQBYtTYW1wbGUgUmF0ZVABgwL/UFEBggH0UCWCSHpQFd5Mb3cgcGFzcyBmaWx0ZXIg'
    b'aXMgc2V0IHRvIDI1JSBvZiBkYXRhIHJhdGUsIHNvIGEgZGF0YSByYXRlIG9mIDIwMDBIei'
    b'BoYXMgYSBMUCBmaWx0ZXIgYXQgNTAwIEh6UBSTbm90IENvbmZpZ1sweDFmZjUwXUEHhVEB'
    b'gg+gQQeFUQGCB9BBB4VRAYID6EEHhVEBggH0QQeEUQGB+kEHhFEBgX1BB4RRAYE/QQeEUQ'
    b'GBIEEHhFEBgRBACEEwUAWoQ29udHJvbCBQYWQgVGVtcGVyYXR1cmUvUHJlc3N1cmUgKENo'
    b'IDU5KUAnQJtRAYEDUAGDAf87UBWlRW5hYmxlL0Rpc2FibGUgc2Vuc29ycyBvbiBjb250cm'
    b'9sIHBhZEEHnFAFmUVuYWJsZSBQcmVzc3VyZSAoQ2ggNTkuMClBB59QBZxFbmFibGUgVGVt'
    b'cGVyYXR1cmUgKENoIDU5LjEpQQelUAWiRW5hYmxlIFJlbGF0aXZlIEh1bWlkaXR5IChDaC'
    b'A1OS4yKUAR41AFi1NhbXBsZSBSYXRlUAGDAv87UBSUQ29uZmlnWzB4MWZmM0JdID09IDBQ'
    b'FaRTZXQgc2FtcGxlIGZyZXF1ZW5jeSBmcm9tIDEgdG8gMTAgSHpRAYEKUCWCSHpREYEBUS'
    b'GBCkAIQc1QBZlJbmVydGlhbCBNZWFzdXJlbWVudCBVbml0QAdAllAFkEFjcXVpc2l0aW9u'
    b'IE1vZGVQAYMB/ytQJYEgUQGBEEEHilAFg09mZlEBgQBBB6hQBaFBYnNvbHV0ZSBPcmllbn'
    b'RhdGlvbiAoUXVhdGVybmlvbilRAYEIQQeoUAWhUmVsYXRpdmUgT3JpZW50YXRpb24gKFF1'
    b'YXRlcm5pb24pUQGBEEEHj1AFiFJvdGF0aW9uUQGBAkABQIZQBZVPcmllbnRhdGlvbiBEYX'
    b'RhIFJhdGVQAYMCCCtRAYFkUCWCSHpREYEBUSGByFAVvVNhbXBsZSByYXRlIGZvciBkaXJl'
    b'Y3Rpb25hbCBkYXRhIGZyb20gMSB0byAyMDAgSHouIENoYW5uZWwgNjVQFJRDb25maWdbMH'
    b'gwMUZGMkJdIDwgOEABQIlQBZJSb3RhdGlvbiBEYXRhIFJhdGVQAYMCAitRAYFkUCWCSHpR'
    b'EYEBUSGByFAVvlNldCBzYW1wbGUgcmF0ZSBmb3Igcm90YXRpb24gZGF0YSBmcm9tIDEgdG'
    b'8gMjAwIEh6LiBDaGFubmVsIDQ3UBSZQ29uZmlnWzB4MDFGRjJCXSAmIDIgPT0gMEAIQJBQ'
    b'BaBDb250cm9sIFBhZCBMaWdodCBTZW5zb3IgKENoIDc2KUAn6lABgwH/TFAVvkVuYWJsZS'
    b'9EaXNhYmxlIGxpZ2h0IHNlbnNvciBhdCA0IEh6IC0gTk9URTogRElTQUJMRUQgRk9SIEFM'
    b'UEhBQQegUAWdRW5hYmxlIExpZ2h0IFNlbnNvciAoQ2ggNzYuMClACECyUAWTQk1HMjUwIE'
    b'd5cm8gKENoIDg0KUAnn1ABgwH/VFEBgQBBB5JQBY9FbmFibGUgQWxsIEF4ZXNAF/dQBYtT'
    b'YW1wbGUgUmF0ZVABgwL/VFEBggGQUCWCSHpQFJNub3QgQ29uZmlnWzB4MWZmNTRdQQeFUQ'
    b'GCDIBBB4VRAYIGQEEHhVEBggMgQQeFUQGCAZBBB4RRAYHIQQeEUQGBZEEHhFEBgTJBB4RR'
    b'AYEZQQeEUQGBDEAPgEBPgEoIgEoogEpIgA=='
)
