"""
Default ConfigUI for LOG-0004-500G-DC data recorders 
"""

from base64 import b64decode

DEFAULT_CONFIG_UI = b64decode(
    b'd3dVDEAoRYFQBYdHZW5lcmFsQAXzUAWLRGV2aWNlIE5hbWVQAYMI/39RJIFAUBXYQSBjdX'
    b'N0b20gbmFtZSBmb3IgdGhlIHJlY29yZGVyLiBOb3QgdGhlIHNhbWUgYXMgdGhlIHZvbHVt'
    b'ZSBsYWJlbC4gNjQgY2hhcmFjdGVycyBtYXhpbXVtLkAF81AFjERldmljZSBOb3Rlc1ABgw'
    b'n/f1EkggEAUBXSQ3VzdG9tIG5vdGVzIGFib3V0IHRoZSByZWNvcmRlciAocG9zaXRpb24s'
    b'IHVzZXIgSUQsIGV0Yy4pLiAyNTYgY2hhcmFjdGVycyBtYXhpbXVtLlE0gQNABfpQBZNSZW'
    b'NvcmRpbmcgRGlyZWN0b3J5UAGDFP9/UQSGUkVDT1JEUSSBCFAUk0NvbmZpZ1sweDE2RkY3'
    b'Rl09PTBQFbhEaXJlY3RvcnkgZm9yIHNlcmlhbGl6ZWQgcmVjb3JkaW5ncy4gOCBjaGFyYW'
    b'N0ZXIgbWF4aW11bUAFQKJQBZVSZWNvcmRpbmcgRmlsZSBQcmVmaXhQAYMV/39RJIEIUBXn'
    b'UHJlZml4IGZvciBzZXJpYWxpemVkIHJlY29yZGluZyBuYW1lcy4gSWYgYmxhbmssIGRldm'
    b'ljZSBzZXJpYWwgbnVtYmVyIHdpbGwgYmUgdXNlZC4gOCBjaGFyYWN0ZXIgbWF4aW11bVAU'
    b'k0NvbmZpZ1sweDE2RkY3Rl09PTBAB0E8UAWPRmlsZSBOYW1lIFN0eWxlUAGDFv9/UQGBAF'
    b'AVQPxUaW1lLUJhc2VkIGZpbGUgbmFtZXMgdXNlIGEgZGlyZWN0b3J5IGJhc2VkIG9uIHRo'
    b'ZSBkYXRlLCBhbmQgZmlsZSBuYW1lIGJhc2VkIG9uIHRoZSBzZWNvbmRzIHNpbmNlIG1pZG'
    b'5pZ2h0LgpTZXJpYWxpemVkIGZpbGUgbmFtZXMgdXNlIHRoZSBzcGVjaWZpZWQgZGlyZWN0'
    b'b3J5IGFuZCBmaWxlIG5hbWUgcHJlZml4LCBmb2xsb3dlZCBieSBhIG51bWJlci4gCk51bW'
    b'JlciBpcyByZXNldCB3aGVuIGRpcmVjdG9yeSBvciBwcmVmaXggY2hhbmdlcy5BB41QBYpU'
    b'aW1lIEJhc2VkQQeNUAWKU2VyaWFsaXplZEAHQJlQBYtCdXR0b24gTW9kZVABgxD/f1EBgQ'
    b'BQFb9PbmUgU2Vjb25kIFByZXNzIHdpbGwgZGlzYWJsZSAzLXNlY29uZCBwcmVzcyBmb3Ig'
    b'YmF0dGVyeSBjaGVjay5BB5dQBZRJbW1lZGlhdGUgU3RhcnQvU3RvcEEHolAFn09uZSBTZW'
    b'NvbmQgUHJlc3MgZm9yIFN0YXJ0L1N0b3BAF0EUUAWOUGx1Zy1JbiBBY3Rpb25QAYMK/39R'
    b'AYEBUBWtU2V0IGFjdGlvbiBmb3IgZGV2aWNlIHdoZW4gcGx1Z2dlZCBpbiB0byBVU0IuQQ'
    b'e1UAWySW1tZWRpYXRlbHkgc3RvcCByZWNvcmRpbmcgYW5kIGFwcGVhciBhcyBVU0IgZHJp'
    b'dmVBB7NQBbBDb21wbGV0ZSByZWNvcmRpbmcgYmVmb3JlIGFwcGVhcmluZyBhcyBVU0IgZH'
    b'JpdmVBB7BQBa1JZ25vcmU6IHN0b3AgcmVjb3JkaW5nIHdoZW4gYnV0dG9uIGlzIHByZXNz'
    b'ZWRBB6VQBaJTdGFydCByZWNvcmRpbmcgd2hlbiBVU0IgY29ubmVjdGVkQCPnUAGDC/9/UB'
    b'XeRW50ZXIgbG9jYWwgdGltZXpvbmUncyBvZmZzZXQgZnJvbSBVVEMgdGltZS4gSW1wYWN0'
    b'cyB0aW1lc3RhbXAgaW5mb3JtYXRpb24gb24gcmVjb3JkaW5nIGZpbGVzLkAvgEAPgEBPgE'
    b'AoSOFQBYhUcmlnZ2Vyc0AHQNpQBYxUcmlnZ2VyIE1vZGVQAYMS/39RAYEAUBVAj0RlbGF5'
    b'IFRoZW4gVHJpZ2dlcjogV2FpdCBzcGVjaWZpZWQgdGltZSwgdGhlbiB3YWl0IGZvciB0cm'
    b'lnZ2VyCkRlbGF5IE9yIFRyaWdnZXI6IEFjcXVpcmUgYWZ0ZXIgd2FpdCBvciBvbiB0cmln'
    b'Z2VyLiBCYXR0ZXJ5IGxpZmUgbWF5IGJlIHJlZHVjZWQuQQeVUAWSRGVsYXkgVGhlbiBUcm'
    b'lnZ2VyQQeTUAWQRGVsYXkgT3IgVHJpZ2dlckAy9FAFjVN0YXJ0IGF0IFRpbWVQAYMP/39Q'
    b'FdtXYWl0IHVudGlsIHNldCB0aW1lIGJlZm9yZSBldmFsdWF0aW5nIG90aGVyIHRyaWdnZX'
    b'IgY29uZGl0aW9ucywgaW5jbHVkaW5nIGEgcmVjb3JkaW5nIGRlbGF5QBGuUAWUUmVjb3Jk'
    b'aW5nIFRpbWUgTGltaXRQAYMN/39RIYT////wUCWHU2Vjb25kc0ARQJBQBZhSZWNvcmRpbm'
    b'cgRGVsYXkvSW50ZXJ2YWxQAYMM/39RAYEAUCWHU2Vjb25kc1EhgwFRgFAV2FRpbWUgYmVm'
    b'b3JlIHN0YXJ0aW5nIGEgcmVjb3JkaW5nLCBhbmQgdGltZSBiZXR3ZWVuIHJlY29yZGluZ3'
    b'MgaWYgJ1JldHJpZ2dlcicgaXMgY2hlY2tlZC5AEa9QBZlSZWNvcmRpbmcgRmlsZSBTaXpl'
    b'IExpbWl0UAGDEf9/USGE////8FAlg0tpQkAQQJdQBYlSZXRyaWdnZXJQAYMO/39QFLBDb2'
    b'5maWdbMHhERkY3Rl09PW51bGwgYW5kIENvbmZpZ1sweDExRkY3Rl09PW51bGxQFc9XaGVu'
    b'IHNldCwgU2xhbSBTdGljayB3aWxsIHJlLWFybSBhZnRlciByZWNvcmRpbmcgdGltZSBvci'
    b'BzaXplIGxpbWl0IGlzIHJlYWNoZWQuQBBAqFAFnldhaXQgZm9yIEFsbCBTZW5zb3IgQ29u'
    b'ZGl0aW9uc1ABgxP/f1AV/ldoZW4gc2V0LCByZWNvcmRpbmcgd2lsbCBvbmx5IHN0YXJ0IH'
    b'doZW4gYWxsIHRyaWdnZXJzIGFyZSBtZXQsIG90aGVyd2lzZSByZWNvcmRpbmcgd2lsbCBz'
    b'dGFydCB3aGVuIGFueSBzZW5zb3IgY29uZGl0aW9uIGlzIG1ldEAYQO5QBZBQcmVzc3VyZS'
    b'BUcmlnZ2VyUAGDBQAkUQCBAECC5VAFlVByZXNzdXJlIFRyaWdnZXIsIExvd1ABgwMAJFEB'
    b'gwFfkFAlglBhUSGDAdTAUBWzU2V0IHRvIHN0YXJ0IHNhbXBsaW5nIHdoZW4gb3V0c2lkZS'
    b'BwcmVzc3VyZSB3aW5kb3cuQILmUAWWUHJlc3N1cmUgVHJpZ2dlciwgSGlnaFABgwQAJFEB'
    b'gwGtsFAlglBhUSGDAdTAUBWzU2V0IHRvIHN0YXJ0IHNhbXBsaW5nIHdoZW4gb3V0c2lkZS'
    b'BwcmVzc3VyZSB3aW5kb3cuQBhA+1AFk1RlbXBlcmF0dXJlIFRyaWdnZXJQAYMFASRRAIEA'
    b'QGPqUAWYVGVtcGVyYXR1cmUgVHJpZ2dlciwgTG93UAGDAwEkUQKB9lAlgUNREoHYUSKBUF'
    b'AVtlNldCB0byBzdGFydCBzYW1wbGluZyB3aGVuIG91dHNpZGUgdGVtcGVyYXR1cmUgd2lu'
    b'ZG93LkBj61AFmVRlbXBlcmF0dXJlIFRyaWdnZXIsIEhpZ2hQAYMEASRRAoEjUCWBQ1ESgd'
    b'hRIoFQUBW2U2V0IHRvIHN0YXJ0IHNhbXBsaW5nIHdoZW4gb3V0c2lkZSB0ZW1wZXJhdHVy'
    b'ZSB3aW5kb3cuQBhBqFAFm0FjY2VsZXJhdGlvbiBUcmlnZ2VyICg1MDBnKVABgwX/CFARgw'
    b'f/IFEAgQBQJIBQFJVDb25maWdbMHgwMUZGMDhdID09IDBAQ0CrUROIwH9AAAAAAABRI4hA'
    b'f0AAAAAAAFAFmUFjY2VsZXJhdGlvbiBUcmlnZ2VyLCBMb3dQAYMD/whRAoL5mlAV4EhpZ2'
    b'ggcG93ZXIgdHJpZ2dlciB3aXRoIHByZS10cmlnZ2VyIGRhdGEuIE5vdCByZWNvbW1lbmRl'
    b'ZCBmb3IgbG9uZyB3YWl0cyB3aXRob3V0IGV4dGVybmFsIHBvd2VyLlIDiD+PPHYmnaAlQE'
    b'NArFETiMB/QAAAAAAAUSOIQH9AAAAAAABQBZpBY2NlbGVyYXRpb24gVHJpZ2dlciwgSGln'
    b'aFABgwT/CFECggZmUBXgSGlnaCBwb3dlciB0cmlnZ2VyIHdpdGggcHJlLXRyaWdnZXIgZG'
    b'F0YS4gTm90IHJlY29tbWVuZGVkIGZvciBsb25nIHdhaXRzIHdpdGhvdXQgZXh0ZXJuYWwg'
    b'cG93ZXIuUgOIP488diadoCVAGEGcUAWaQWNjZWxlcmF0aW9uIFRyaWdnZXIgKDE2ZylQAY'
    b'MH/yBQFdRMb3cgcG93ZXIgdHJpZ2dlciB1c2luZyBkaWdpdGFsIGFjY2VsZXJvbWV0ZXIg'
    b'd2l0aCBEQyByZXNwb25zZS4gTm8gcHJlLXRyaWdnZXIgZGF0YS5RAIEAUBGDBf8IUCSAUB'
    b'SUQ29uZmlnWzB4MWZmMjBdID09IDBAQ0CxUAWWQWNjZWxlcmF0aW9uIFRocmVzaG9sZFAB'
    b'gwT/IFEBgVBSA4g/sBAQEBAQEFEjiEAwAAAAAAAAUROAUBXyTG93IHBvd2VyIHRyaWdnZX'
    b'IuIFRoZSBtaW5pbXVtIGFjY2VsZXJhdGlvbiAocG9zaXRpdmUgb3IgbmVnYXRpdmUpIHRv'
    b'IHRyaWdnZXIgYSByZWNvcmRpbmcuIE11c3QgYmUgZ3JlYXRlciB0aGFuIDAuQCfGUAGDBf'
    b'8gUQGBB0EHkVAFjlggQXhpcyBUcmlnZ2VyQQeRUAWOWSBBeGlzIFRyaWdnZXJBB5FQBY5a'
    b'IEF4aXMgVHJpZ2dlckAPgEBPgEAoRpVQBYxNZWFzdXJlbWVudHNACEJBUAWYNTAwZyBBY2'
    b'NlbGVyYXRpb24gKENoIDgpUCSAQCdAgVEBgQdQAYMB/whQFaBFbmFibGUvRGlzYWJsZSBh'
    b'Y2NlbGVyYXRpb24gYXhlc0EHmVAFlkVuYWJsZSBYIEF4aXMgKENoIDguMClBB5lQBZZFbm'
    b'FibGUgWSBBeGlzIChDaCA4LjEpQQeZUAWWRW5hYmxlIFogQXhpcyAoQ2ggOC4yKUARQJpQ'
    b'BYtTYW1wbGUgUmF0ZVABgwL/CFAV2FNldCBtYWluIGFjY2VsZXJhdGlvbiBzYW1wbGUgcm'
    b'F0ZSBmcm9tIDEwIHRvIDIwMDAwIEh6LgpIaWdoZXIgcmF0ZSByZWR1Y2VzIGJhdHRlcnkg'
    b'bGlmZS5QFJVDb25maWdbMHgwMUZGMDhdID09IDBRAYITiFAlgkh6URGBClEhgk4gQBFA/F'
    b'AFo092ZXJyaWRlIEFudGlhbGlhc2luZyBGaWx0ZXIgQ3V0b2ZmUAGDCP8IUQGCA+hQJYJI'
    b'elEhghOIUBVApURlZmF1bHQsIHdoZW4gbm90IGNoZWNrZWQsIG9mIG9uZS1maWZ0aCBzYW'
    b'1wbGUgZnJlcXVlbmN5LiBDdXQtb2ZmIGZyZXF1ZW5jeSBoYXMgMjklIGF0dGVudWF0aW9u'
    b'Lgo1dGggb3JkZXIgQnV0dGVyd29ydGguIFNvbWUgYXR0ZW51YXRpb24gYXQgNjAlIG9mIG'
    b'N1dC1vZmYgZnJlcXVlbmN5LlAUlUNvbmZpZ1sweDAxRkYwOF0gPT0gMEAIQLpQBZsxNmcg'
    b'REMgQWNjZWxlcmF0aW9uIChDaCAzMilAJ59QAYMB/yBRAYEBQQeSUAWPRW5hYmxlIEFsbC'
    b'BBeGVzQBf3UAWLU2FtcGxlIFJhdGVQAYMC/yBRAYIBkFAlgkh6UBSTbm90IENvbmZpZ1sw'
    b'eDFmZjIwXUEHhVEBggyAQQeFUQGCBkBBB4VRAYIDIEEHhVEBggGQQQeEUQGByEEHhFEBgW'
    b'RBB4RRAYEyQQeEUQGBGUEHhFEBgQxACEEwUAWoQ29udHJvbCBQYWQgVGVtcGVyYXR1cmUv'
    b'UHJlc3N1cmUgKENoIDU5KUAnQJtRAYEDUAGDAf87UBWlRW5hYmxlL0Rpc2FibGUgc2Vuc2'
    b'9ycyBvbiBjb250cm9sIHBhZEEHnFAFmUVuYWJsZSBQcmVzc3VyZSAoQ2ggNTkuMClBB59Q'
    b'BZxFbmFibGUgVGVtcGVyYXR1cmUgKENoIDU5LjEpQQelUAWiRW5hYmxlIFJlbGF0aXZlIE'
    b'h1bWlkaXR5IChDaCA1OS4yKUAR41AFi1NhbXBsZSBSYXRlUAGDAv87UBSUQ29uZmlnWzB4'
    b'MWZmM0JdID09IDBQFaRTZXQgc2FtcGxlIGZyZXF1ZW5jeSBmcm9tIDEgdG8gMTAgSHpRAY'
    b'EKUCWCSHpREYEBUSGBCkAIQclQBZlJbmVydGlhbCBNZWFzdXJlbWVudCBVbml0QAdAklAF'
    b'kEFjcXVpc2l0aW9uIE1vZGVQAYMB/ytRAYEQQQeKUAWDT2ZmUQGBAEEHqFAFoUFic29sdX'
    b'RlIE9yaWVudGF0aW9uIChRdWF0ZXJuaW9uKVEBgQhBB6hQBaFSZWxhdGl2ZSBPcmllbnRh'
    b'dGlvbiAoUXVhdGVybmlvbilRAYEQQQePUAWIUm90YXRpb25RAYECQAFAhlAFlU9yaWVudG'
    b'F0aW9uIERhdGEgUmF0ZVABgwIIK1EBgWRQJYJIelERgQFRIYHIUBW9U2FtcGxlIHJhdGUg'
    b'Zm9yIGRpcmVjdGlvbmFsIGRhdGEgZnJvbSAxIHRvIDIwMCBIei4gQ2hhbm5lbCA2NVAUlE'
    b'NvbmZpZ1sweDAxRkYyQl0gPCA4QAFAiVAFklJvdGF0aW9uIERhdGEgUmF0ZVABgwICK1EB'
    b'gWRQJYJIelERgQFRIYHIUBW+U2V0IHNhbXBsZSByYXRlIGZvciByb3RhdGlvbiBkYXRhIG'
    b'Zyb20gMSB0byAyMDAgSHouIENoYW5uZWwgNDdQFJlDb25maWdbMHgwMUZGMkJdICYgMiA9'
    b'PSAwQAj5UAWgQ29udHJvbCBQYWQgTGlnaHQgU2Vuc29yIChDaCA3NilAJ9NRAYEBUAGDAf'
    b'9MUBWjRW5hYmxlL0Rpc2FibGUgbGlnaHQgc2Vuc29yIGF0IDQgSHpBB6BQBZ1FbmFibGUg'
    b'TGlnaHQgU2Vuc29yIChDaCA3Ni4wKUAPgEBPgEoIgEoogEpIgA=='
)
