"""
Default ConfigUI for Sx-D16 data recorders 
"""

from base64 import b64decode

DEFAULT_CONFIG_UI = b64decode(
    b'GkXfo6lChoEBQveBAULygQRC84EIQoKObWlkZS5zcy5jb25maWdCh4ECQoWBAnd3EAATk0'
    b'AoIAYKUAWHR2VuZXJhbEAFQHNQBYtEZXZpY2UgTmFtZVABgwj/f1EkgUBQFdhBIGN1c3Rv'
    b'bSBuYW1lIGZvciB0aGUgcmVjb3JkZXIuIE5vdCB0aGUgc2FtZSBhcyB0aGUgdm9sdW1lIG'
    b'xhYmVsLiA2NCBjaGFyYWN0ZXJzIG1heGltdW0uQAVAc1AFjERldmljZSBOb3Rlc1ABgwn/'
    b'f1EkggEAUBXSQ3VzdG9tIG5vdGVzIGFib3V0IHRoZSByZWNvcmRlciAocG9zaXRpb24sIH'
    b'VzZXIgSUQsIGV0Yy4pLiAyNTYgY2hhcmFjdGVycyBtYXhpbXVtLlE0gQNAB0E8UAWPRmls'
    b'ZSBOYW1lIFN0eWxlUAGDFv9/UQGBAFAVQPxUaW1lLUJhc2VkIGZpbGUgbmFtZXMgdXNlIG'
    b'EgZGlyZWN0b3J5IGJhc2VkIG9uIHRoZSBkYXRlLCBhbmQgZmlsZSBuYW1lIGJhc2VkIG9u'
    b'IHRoZSBzZWNvbmRzIHNpbmNlIG1pZG5pZ2h0LgpTZXJpYWxpemVkIGZpbGUgbmFtZXMgdX'
    b'NlIHRoZSBzcGVjaWZpZWQgZGlyZWN0b3J5IGFuZCBmaWxlIG5hbWUgcHJlZml4LCBmb2xs'
    b'b3dlZCBieSBhIG51bWJlci4gCk51bWJlciBpcyByZXNldCB3aGVuIGRpcmVjdG9yeSBvci'
    b'BwcmVmaXggY2hhbmdlcy5BB41QBYpUaW1lIEJhc2VkQQeNUAWKU2VyaWFsaXplZEAFQHtQ'
    b'BZNSZWNvcmRpbmcgRGlyZWN0b3J5UAGDFP9/UQSGUkVDT1JEUSSBEFAUk0NvbmZpZ1sweD'
    b'E2RkY3Rl09PTBQFblEaXJlY3RvcnkgZm9yIHNlcmlhbGl6ZWQgcmVjb3JkaW5ncy4gMTYg'
    b'Y2hhcmFjdGVyIG1heGltdW1ABUCjUAWVUmVjb3JkaW5nIEZpbGUgUHJlZml4UAGDFf9/US'
    b'SBEFAV6FByZWZpeCBmb3Igc2VyaWFsaXplZCByZWNvcmRpbmcgbmFtZXMuIElmIGJsYW5r'
    b'LCBkZXZpY2Ugc2VyaWFsIG51bWJlciB3aWxsIGJlIHVzZWQuIDE2IGNoYXJhY3RlciBtYX'
    b'hpbXVtUBSTQ29uZmlnWzB4MTZGRjdGXT09MEAXQRRQBY5QbHVnLUluIEFjdGlvblABgwr/'
    b'f1EBgQFQFa1TZXQgYWN0aW9uIGZvciBkZXZpY2Ugd2hlbiBwbHVnZ2VkIGluIHRvIFVTQi'
    b'5BB7VQBbJJbW1lZGlhdGVseSBzdG9wIHJlY29yZGluZyBhbmQgYXBwZWFyIGFzIFVTQiBk'
    b'cml2ZUEHs1AFsENvbXBsZXRlIHJlY29yZGluZyBiZWZvcmUgYXBwZWFyaW5nIGFzIFVTQi'
    b'Bkcml2ZUEHsFAFrUlnbm9yZTogc3RvcCByZWNvcmRpbmcgd2hlbiBidXR0b24gaXMgcHJl'
    b'c3NlZEEHpVAFolN0YXJ0IHJlY29yZGluZyB3aGVuIFVTQiBjb25uZWN0ZWRAB0EcUAWLQn'
    b'V0dG9uIE1vZGVQAYMQ/39RAYEAUBVAwU9uZSBTZWNvbmQgUHJlc3Mgd2lsbCBkaXNhYmxl'
    b'IDMtc2Vjb25kIHByZXNzIGZvciBiYXR0ZXJ5IGNoZWNrLgpOT1RFOiBJZiAnU3RhcnQtT2'
    b'5seScgaXMgc2VsZWN0ZWQgYW5kIG5vIHJlY29yZGluZyB0aW1lIGxpbWl0IG9yIG1heCBm'
    b'aWxlIHNpemUgaXMgc2V0LCByZWNvcmRpbmdzIGNhbiBiZSBzdG9wcGVkIHdpdGggVVNCIH'
    b'BsdWctaW5BB5dQBZRJbW1lZGlhdGUgU3RhcnQvU3RvcEEHolAFn09uZSBTZWNvbmQgUHJl'
    b'c3MgZm9yIFN0YXJ0L1N0b3BAI0BnUAGDC/9/UBXeRW50ZXIgbG9jYWwgdGltZXpvbmUncy'
    b'BvZmZzZXQgZnJvbSBVVEMgdGltZS4gSW1wYWN0cyB0aW1lc3RhbXAgaW5mb3JtYXRpb24g'
    b'b24gcmVjb3JkaW5nIGZpbGVzLkAvgEAPgEBPgEAoIAgeUAWIVHJpZ2dlcnNAB0DaUAWMVH'
    b'JpZ2dlciBNb2RlUAGDEv9/UQGBAFAVQI9EZWxheSBUaGVuIFRyaWdnZXI6IFdhaXQgc3Bl'
    b'Y2lmaWVkIHRpbWUsIHRoZW4gd2FpdCBmb3IgdHJpZ2dlcgpEZWxheSBPciBUcmlnZ2VyOi'
    b'BBY3F1aXJlIGFmdGVyIHdhaXQgb3Igb24gdHJpZ2dlci4gQmF0dGVyeSBsaWZlIG1heSBi'
    b'ZSByZWR1Y2VkLkEHlVAFkkRlbGF5IFRoZW4gVHJpZ2dlckEHk1AFkERlbGF5IE9yIFRyaW'
    b'dnZXJAMkB0UAWNU3RhcnQgYXQgVGltZVABgw//f1AV21dhaXQgdW50aWwgc2V0IHRpbWUg'
    b'YmVmb3JlIGV2YWx1YXRpbmcgb3RoZXIgdHJpZ2dlciBjb25kaXRpb25zLCBpbmNsdWRpbm'
    b'cgYSByZWNvcmRpbmcgZGVsYXlAEUAuUAWUUmVjb3JkaW5nIFRpbWUgTGltaXRQAYMN/39R'
    b'IYT////wUCWHU2Vjb25kc0ARQJJQBZhSZWNvcmRpbmcgRGVsYXkvSW50ZXJ2YWxQAYMM/3'
    b'9RAYEAUCWHU2Vjb25kc1EhgwFRgFAV2kRlbGF5IGJlZm9yZSBzdGFydGluZyBhIHJlY29y'
    b'ZGluZywgaW5jbHVkaW5nIGJldHdlZW4gcmVjb3JkaW5ncyBpZiAnUmV0cmlnZ2VyJyBpcy'
    b'BjaGVja2VkLkARQC9QBZlSZWNvcmRpbmcgRmlsZSBTaXplIExpbWl0UAGDEf9/USGE////'
    b'8FAlg0tpQkAQQJJQBYlSZXRyaWdnZXJQAYMO/39QFLBDb25maWdbMHhERkY3Rl09PW51bG'
    b'wgYW5kIENvbmZpZ1sweDExRkY3Rl09PW51bGxQFcpXaGVuIHNldCwgZW5EQVEgd2lsbCBy'
    b'ZS1hcm0gYWZ0ZXIgcmVjb3JkaW5nIHRpbWUgb3Igc2l6ZSBsaW1pdCBpcyByZWFjaGVkLk'
    b'AQQKhQBZ5XYWl0IGZvciBBbGwgU2Vuc29yIENvbmRpdGlvbnNQAYMT/39QFf5XaGVuIHNl'
    b'dCwgcmVjb3JkaW5nIHdpbGwgb25seSBzdGFydCB3aGVuIGFsbCB0cmlnZ2VycyBhcmUgbW'
    b'V0LCBvdGhlcndpc2UgcmVjb3JkaW5nIHdpbGwgc3RhcnQgd2hlbiBhbnkgc2Vuc29yIGNv'
    b'bmRpdGlvbiBpcyBtZXRAGEFbUAWQUHJlc3N1cmUgVHJpZ2dlclABgwUAJFEAgQBQFOgoQ2'
    b'9uZmlnWzB4MWZmMTRdIGFuZCAoQ29uZmlnWzB4MWZmMTRdICAmIDEgPT0gMCkpIG9yIChD'
    b'b25maWdbMHgwMUZGMjRdIGFuZCAoQ29uZmlnWzB4MDFGRjI0XSAgJiAxID09IDApKUCCQG'
    b'VQBZVQcmVzc3VyZSBUcmlnZ2VyLCBMb3dQAYMDACRRAYMBX5BQJYJQYVEhgwHUwFAVs1Nl'
    b'dCB0byBzdGFydCBzYW1wbGluZyB3aGVuIG91dHNpZGUgcHJlc3N1cmUgd2luZG93LkCCQG'
    b'ZQBZZQcmVzc3VyZSBUcmlnZ2VyLCBIaWdoUAGDBAAkUQGDAa2wUCWCUGFRIYMB1MBQFbNT'
    b'ZXQgdG8gc3RhcnQgc2FtcGxpbmcgd2hlbiBvdXRzaWRlIHByZXNzdXJlIHdpbmRvdy5AGE'
    b'FoUAWTVGVtcGVyYXR1cmUgVHJpZ2dlclABgwUBJFEAgQBQFOgoQ29uZmlnWzB4MWZmMTRd'
    b'IGFuZCAoQ29uZmlnWzB4MWZmMTRdICAmIDIgPT0gMCkpIG9yIChDb25maWdbMHgwMUZGMj'
    b'RdIGFuZCAoQ29uZmlnWzB4MDFGRjI0XSAgJiAyID09IDApKUBjQGpQBZhUZW1wZXJhdHVy'
    b'ZSBUcmlnZ2VyLCBMb3dQAYMDASRRAoH2UCWBQ1ESgdhRIoFQUBW2U2V0IHRvIHN0YXJ0IH'
    b'NhbXBsaW5nIHdoZW4gb3V0c2lkZSB0ZW1wZXJhdHVyZSB3aW5kb3cuQGNAa1AFmVRlbXBl'
    b'cmF0dXJlIFRyaWdnZXIsIEhpZ2hQAYMEASRRAoEjUCWBQ1ESgdhRIoFQUBW2U2V0IHRvIH'
    b'N0YXJ0IHNhbXBsaW5nIHdoZW4gb3V0c2lkZSB0ZW1wZXJhdHVyZSB3aW5kb3cuQBhBq1AF'
    b'mkFjY2VsZXJhdGlvbiBUcmlnZ2VyICgxNmcpUAGDB/8gUBXUTG93IHBvd2VyIHRyaWdnZX'
    b'IgdXNpbmcgZGlnaXRhbCBhY2NlbGVyb21ldGVyIHdpdGggREMgcmVzcG9uc2UuIE5vIHBy'
    b'ZS10cmlnZ2VyIGRhdGEuUQCBAFARgwX/CFARgwf/UFAkgFAUlENvbmZpZ1sweDFmZjIwXS'
    b'A9PSAwQENAuVAFlkFjY2VsZXJhdGlvbiBUaHJlc2hvbGRQAYME/yBRAYFQUgOIP7AQEBAQ'
    b'EBBRI4hAMAAAAAAAAFETiAAAAAAAAAAAUBXyTG93IHBvd2VyIHRyaWdnZXIuIFRoZSBtaW'
    b'5pbXVtIGFjY2VsZXJhdGlvbiAocG9zaXRpdmUgb3IgbmVnYXRpdmUpIHRvIHRyaWdnZXIg'
    b'YSByZWNvcmRpbmcuIE11c3QgYmUgZ3JlYXRlciB0aGFuIDAuQCdARlABgwX/IFEBgQdBB5'
    b'FQBY5YIEF4aXMgVHJpZ2dlckEHkVAFjlkgQXhpcyBUcmlnZ2VyQQeRUAWOWiBBeGlzIFRy'
    b'aWdnZXJAD4BAT4BAKCAFU1AFjE1lYXN1cmVtZW50c0AIQLxQBZsxNmcgREMgQWNjZWxlcm'
    b'F0aW9uIChDaCAzMilAJ0AfUAGDAf8gUQGBAUEHklAFj0VuYWJsZSBBbGwgQXhlc0AXQHdQ'
    b'BYtTYW1wbGUgUmF0ZVABgwL/IFEBggGQUCWCSHpQFJNub3QgQ29uZmlnWzB4MWZmMjBdQQ'
    b'eFUQGCDIBBB4VRAYIGQEEHhVEBggMgQQeFUQGCAZBBB4RRAYHIQQeEUQGBZEEHhFEBgTJB'
    b'B4RRAYEZQQeEUQGBDEAIQTZQBahDb250cm9sIFBhZCBUZW1wZXJhdHVyZS9QcmVzc3VyZS'
    b'AoQ2ggNTkpQCdAoFEBgQNQAYMB/ztQFapFbmFibGUvRGlzYWJsZSBDb250cm9sIFBhZCBT'
    b'ZW5zb3IgQ2hhbm5lbHNBB5xQBZlFbmFibGUgUHJlc3N1cmUgKENoIDU5LjApQQefUAWcRW'
    b'5hYmxlIFRlbXBlcmF0dXJlIChDaCA1OS4xKUEHpVAFokVuYWJsZSBSZWxhdGl2ZSBIdW1p'
    b'ZGl0eSAoQ2ggNTkuMilAEUBjUAWLU2FtcGxlIFJhdGVQAYMC/ztQFJRDb25maWdbMHgxZm'
    b'YzQl0gPT0gMFAVpFNldCBzYW1wbGUgZnJlcXVlbmN5IGZyb20gMSB0byAxMCBIelEBgQpQ'
    b'JYJIelERgQFRIYEKQAhBzVAFmUluZXJ0aWFsIE1lYXN1cmVtZW50IFVuaXRAB0CWUAWQQW'
    b'NxdWlzaXRpb24gTW9kZVABgwH/K1AlgSBRAYEQQQeKUAWDT2ZmUQGBAEEHqFAFoUFic29s'
    b'dXRlIE9yaWVudGF0aW9uIChRdWF0ZXJuaW9uKVEBgQhBB6hQBaFSZWxhdGl2ZSBPcmllbn'
    b'RhdGlvbiAoUXVhdGVybmlvbilRAYEQQQePUAWIUm90YXRpb25RAYECQAFAhlAFlU9yaWVu'
    b'dGF0aW9uIERhdGEgUmF0ZVABgwIIK1EBgWRQJYJIelERgQFRIYHIUBW9U2FtcGxlIHJhdG'
    b'UgZm9yIGRpcmVjdGlvbmFsIGRhdGEgZnJvbSAxIHRvIDIwMCBIei4gQ2hhbm5lbCA2NVAU'
    b'lENvbmZpZ1sweDAxRkYyQl0gPCA4QAFAiVAFklJvdGF0aW9uIERhdGEgUmF0ZVABgwICK1'
    b'EBgWRQJYJIelERgQFRIYHIUBW+U2V0IHNhbXBsZSByYXRlIGZvciByb3RhdGlvbiBkYXRh'
    b'IGZyb20gMSB0byAyMDAgSHouIENoYW5uZWwgNDdQFJlDb25maWdbMHgwMUZGMkJdICYgMi'
    b'A9PSAwQAhA8VAFpUludGVybmFsIFRlbXBlcmF0dXJlL1ByZXNzdXJlIChDaCAzNilAJ0DF'
    b'UQGBA1ABgwH/JFAV90VuYWJsZS9EaXNhYmxlIHNsb3dlciBpbnRlcm5hbCBlbnZpcm9ubW'
    b'VudGFsIHNlbnNvcnMuIE5PVEU6IFRlbXBlcmF0dXJlIGlzIHJlcXVpcmVkIGZvciBtYWlu'
    b'IGFjY2VsZXJvbWV0ZXIgbWVhc3VyZW1lbnRzQQecUAWZRW5hYmxlIFByZXNzdXJlIChDaC'
    b'AzNi4wKUEHn1AFnEVuYWJsZSBUZW1wZXJhdHVyZSAoQ2ggMzYuMSlACEB6UAWgQ29udHJv'
    b'bCBQYWQgTGlnaHQgU2Vuc29yIChDaCA3NilAJ0BTUAGDAf9MUQGBAVAVo0VuYWJsZS9EaX'
    b'NhYmxlIGxpZ2h0IHNlbnNvciBhdCA0IEh6QQegUAWdRW5hYmxlIExpZ2h0IFNlbnNvciAo'
    b'Q2ggNzYuMClAD4BAT4BKCIBKKIBKSIA='
)
